@@ -35,6 +35,7 @@ $tableversioni = $PHPR_TAB_PRE."versioni";
 $tableutenti = $PHPR_TAB_PRE."utenti";
 $tablecontratti = $PHPR_TAB_PRE."contratti";
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
+$tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
 
 if (defined("C_UTENTE_BACKUP_ESTERNO") and C_UTENTE_BACKUP_ESTERNO != "" and $utente_backup == C_UTENTE_BACKUP_ESTERNO) $id_utente = "b";
@@ -320,11 +321,11 @@ fwrite($file,"</backup>");
 flock($file,3);
 fclose($file);
 @chmod(C_DATI_PATH."/hoteld_backup.php", 0640);
-unlock_tabelle($tabelle_lock);
 echo mex("File creato",$pag).".<br>
 <!-- Backup_created -->";
-} # fine if (@fopen(C_DATI_PATH."/hoteld_backup.php","w+"))
+} # fine if ($file)
 else echo mex("Non ho il permesso di scrittura sul file",$pag).".<br>";
+unlock_tabelle($tabelle_lock);
 } # fine if ($backup_contratti != "SI")
 
 
@@ -355,7 +356,7 @@ fwrite($file,"<?php exit(); ?>
 ");
 fwrite($file,"<database>
 ");
-dump_tabella("contratti",$file);
+dump_tabella("contratti",$file,"",1);
 echo "<br>";
 fwrite($file,"</database>
 </backup>");
