@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2015 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -604,23 +604,58 @@ fwrite($fileaperto,"<?php \necho \"\n");
 $zeri = (string) "0000000000000000000000000000";
 $lettere = (string) "abcdefghijklmnopqrstuvwxyz";
 $pos_lettera = 0;
+$pos_lettera_tot = 0;
+$suff_lettera = "";
 $num_dorm = $numappartamenti;
+if ($lista_camere_letti) {
+$lista_camere_letti = explode(",",",$lista_camere_letti");
+$num_camera_l = 1;
+} # fine if ($lista_camere_letti)
+else $num_camera_l = 0;
+$app_vicini_vett = array();
 if (!$numletti) $num_app_max = $numappartamenti;
+else {
+if ($num_camera_l) $num_app_max = $numappartamenti + count($lista_camere_letti) - 1;
 else $num_app_max = $numappartamenti + ceil((double) $numletti / 26);
+} # fine else if (!$numletti)
 if (C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and $num_app_max < 10) $num_app_max = 10;
-for ( $num = 1; $num <= ($numappartamenti + $numletti) ; $num = $num + 1) {
+
+for ($num = 1 ; $num <= ($numappartamenti + $numletti) ; $num = $num + 1) {
 $numapp = "numapp" . $num;
 $numapp = $$numapp;
 if (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO") {
 if ($num <= $numappartamenti) $numapp = (string) substr($zeri,0,(strlen($num_app_max) - strlen($num))).$num;
 else {
-if ($pos_lettera == 0) {
+if ($pos_lettera_tot == 0) {
 $num_dorm++;
 $num_dorm = (string) substr($zeri,0,(strlen($num_app_max) - strlen($num_dorm))).$num_dorm;
-} # fine if ($pos_lettera == 0)
-$numapp = $num_dorm.substr($lettere,$pos_lettera,1);
+if ($num_camera_l and $lista_camere_letti[$num_camera_l] > 26) $suff_lettera = "a";
+} # fine if ($pos_lettera_tot == 0)
+$numapp = $num_dorm.$suff_lettera.substr($lettere,$pos_lettera,1);
+if ($num_camera_l) {
+$app_vicini_vett['pos'][$num] = $numapp;
+if ($pos_lettera > 0) {
+if ($pos_lettera > 1) {
+$app_vicini_vett[($num - 2)] .= ",$numapp";
+$app_vicini_vett[$num] .= ",".$app_vicini_vett['pos'][($num - 2)];
+} # fine if ($pos_lettera > 1)
+$app_vicini_vett[($num - 1)] .= ",$numapp";
+$app_vicini_vett[$num] .= ",".$app_vicini_vett['pos'][($num - 1)];
+} # fine if ($pos_lettera > 0)
+} # fine if ($num_camera_l)
 $pos_lettera++;
-if ($pos_lettera == 26) $pos_lettera = 0;
+$pos_lettera_tot++;
+if (($pos_lettera == 26 and !$num_camera_l) or ($num_camera_l and $pos_lettera_tot == $lista_camere_letti[$num_camera_l])) {
+$pos_lettera = 0;
+$pos_lettera_tot = 0;
+$suff_lettera = "";
+if ($num_camera_l) $num_camera_l++;
+} # fine if (($pos_lettera == 26 and !$num_camera_l) or ($num_camera_l and...
+if ($pos_lettera >= 26) {
+$pos_lettera = 0;
+if (!$suff_lettera) $suff_lettera = "a";
+else $suff_lettera = substr(strstr($lettere,$suff_lettera),1,1);
+} # fine if ($pos_lettera >= 26)
 } # fine else if ($num <= $numappartamenti)
 } # fine if (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO")
 $numapp = str_replace (",","",$numapp);
@@ -660,11 +695,12 @@ esegui_query("update $tableappartamenti set app_vicini = '$app_vicini' where ida
 } # fine if ($app_vicini and assegna_vicini_nc != "SI")
 if ($num > $numappartamenti) esegui_query("update $tableappartamenti set letto = '1' where idappartamenti = '$numapp'");
 } # fine for $num
+
 fwrite($fileaperto,"\"; \n?>");
 fclose($fileaperto);
 if ($assegna_vicini_nc == "SI") {
 $appart = esegui_query("select * from $tableappartamenti");
-for ( $num1 = 0; $num1 < $numappartamenti; $num1 = $num1 + 1) {
+for ($num1 = 0 ; $num1 < $numappartamenti ; $num1 = $num1 + 1) {
 $idapp = risul_query($appart,$num1,'idappartamenti');
 $nc = risul_query($appart,$num1,'numcasa');
 $np = risul_query($appart,$num1,'numpiano');
@@ -683,6 +719,14 @@ else { $app_vicini = $app_vicini . "," . $id_av; }
 esegui_query("update $tableappartamenti set app_vicini = '$app_vicini' where idappartamenti = '$idapp'");
 } # fine for $num1
 } # fine if ($assegna_vicini_nc == "SI")
+if ($num_camera_l) {
+for ($num = 1 ; $num <= ($numappartamenti + $numletti) ; $num = $num + 1) {
+if ($app_vicini_vett[$num]) {
+$app_vicini = substr($app_vicini_vett[$num],1);
+esegui_query("update $tableappartamenti set app_vicini = '$app_vicini' where idappartamenti = '".$app_vicini_vett['pos'][$num]."'");
+} # fine if ($app_vicini_vett[$num])
+} # fine for $num
+} # fine if ($num_camera_l)
 
 if (C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and @is_file(C_DATI_PATH."/ini.php")) {
 include(C_DATI_PATH."/ini.php");
