@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -262,7 +262,6 @@ $num_da_assegnare = risul_query($regola_esistente,0,'motivazione3');
 if (substr($num_da_assegnare,0,1) == "v") $num_da_assegnare = substr($num_da_assegnare,1);
 } # fine elseif ($num_regole_esistente)
 if ($num_da_assegnare and $num_da_assegnare > $num_app_reali and $inserire != "NO") {
-echo "$num_da_assegnare - $num_app_reali QUI<br>";
 $inserire = "NO";
 echo "<br><span class=\"colwarn\">".mex("Numero di appartamenti",'unit.php')."</span> ".mex("da assegnare troppo alto, supera quello presente nella lista",$pag).".<br><br>";
 } # fine if ($num_da_assegnare and $num_da_assegnare > $num_app_reali and...
@@ -285,12 +284,27 @@ if ($v_apti != "v") $v_apti = "";
 
 if ($inserire != "NO") {
 if ($num_regole_esistente != 0) {
-if ($regola_2b) esegui_query("update $tableregole set motivazione2 = '$lista_app', iddatainizio = $num_giorni_ini, iddatafine = $num_giorni_fine where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
+if ($regola_2b) {
+esegui_query("update $tableregole set motivazione2 = '$lista_app', iddatainizio = $num_giorni_ini, iddatafine = $num_giorni_fine where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
+$lista_app_norm = risul_query($regola_esistente,0,'motivazione');
+$lista_app_ecc = $lista_app;
+} # fine if ($regola_2b)
 else {
 esegui_query("update $tableregole set motivazione = '$lista_app' where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
 if ($num_apti > 1) esegui_query("update $tableregole set motivazione3 = '$v_apti$num_apti' where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
 else esegui_query("update $tableregole set motivazione3 = NULL where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
+$lista_app_norm = $lista_app;
+$lista_app_ecc = risul_query($regola_esistente,0,'motivazione2');
 } # fine else if ($regola_2b)
+if ($lista_app_norm and $lista_app_ecc) {
+$vett_app = explode(",",$lista_app_norm);
+$num_app = count($vett_app);
+$app_mancanti_da_ecc = "";
+for ($num1 = 0 ; $num1 < $num_app ; $num1 = $num1 + 1) {
+if (str_replace(",".$vett_app[$num1].",","",",$lista_app_ecc,") == ",$lista_app_ecc,") $app_mancanti_da_ecc .= ", ".$vett_app[$num1];
+} # fine for $num1
+if ($app_mancanti_da_ecc) echo "<br><b class=\"colwarn\">".mex("Attenzione",$pag)."</b>: ".mex("ci sono appartamenti",'unit.php')." (<b>".substr($app_mancanti_da_ecc,2)."</b>) ".mex("della regola 2 mancanti nella eccezione alla regola",$pag).".<br>";
+} # fine if ($lista_app_norm and $lista_app_ecc)
 echo "<br>".mex("La regola di assegnazione",$pag)." 2 ".mex("è stata modificata",$pag).".<br><br>";
 } # fine if ($num_regole_esistente != 0)
 else {
@@ -371,17 +385,45 @@ $inserire = "NO";
 echo mex("Si deve inserire il numero di persone da associare",$pag).".<br>";
 } # fine if (!$num_persone or controlla_num_pos($num_persone) != "SI")
 if ($inserire != "NO") {
+$regola2_esistente = esegui_query("select * from $tableregole where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
+if (numlin_query($regola2_esistente)) {
+$lista_app2 = risul_query($regola2_esistente,0,'motivazione');
+$lista_app2_ecc = risul_query($regola2_esistente,0,'motivazione2');
+if ($lista_app2_ecc) {
+if ($lista_app2) $lista_app2 .= ",";
+$lista_app2 .= $lista_app2_ecc;
+} # fine if ($lista_app2_ecc)
+$vett_app2 = explode(",",$lista_app2);
+$num_app2 = count($vett_app2);
+$app_trovato = array();
+$app_piccoli = "";
+$app_compatibile = 0;
+for ($num1 = 0 ; $num1 < $num_app2 ; $num1++) {
+if (!$app_trovato[$vett_app2[$num1]]) {
+$app_trovato[$vett_app2[$num1]] = 1;
+$app = esegui_query("select * from $tableappartamenti where idappartamenti = '".aggslashdb($vett_app2[$num1])."' ");
+if (numlin_query($app)) {
+$pers_max = risul_query($app,0,'maxoccupanti');
+if ($pers_max < $num_persone) $app_piccoli .= ", ".$vett_app2[$num1];
+else $app_compatibile = 1;
+} # fine if (numlin_query($app))
+} # fine if (!$app_trovato[$vett_app2[$num1]])
+} # fine for $num1
+if (!$app_compatibile) echo "<br><b class=\"colwarn\">".mex("Attenzione",$pag)."</b>: ".lcfirst(mex("Non ci sono appartamenti con le caratteristiche richieste",'unit.php'))." ".mex("nella regola di assegnazione 2 di questa tariffa",$pag).".<br>";
+elseif ($app_piccoli) echo "<br><b class=\"colwarn\">".mex("Attenzione",$pag)."</b>: ".mex("ci sono appartamenti",'unit.php')." (<b>".substr($app_piccoli,2)."</b>) ".mex("nella regola 2 di questa tariffa che non possono ospitare",$pag)." $num_persone ".mex("persone",$pag).".<br>";
+} # fine if (numlin_query($regola2_esistente))
 if ($num_regole_esistente != 0) {
 esegui_query("update $tableregole set iddatainizio = '".aggslashdb($num_persone)."' where tariffa_per_persone = '".aggslashdb($tipotariffa)."'");
-echo mex("La regola di assegnazione",$pag)." 4 ".mex("è stata modificata",$pag).".<br>";
+echo "<br>".mex("La regola di assegnazione",$pag)." 4 ".mex("è stata modificata",$pag).".<br><br>";
 } # fine if ($num_regole_esistente != 0)
 else {
 $idregole = esegui_query("select max(idregole) from $tableregole");
 $idregole = risul_query($idregole,0,0);
 $idregole = $idregole + 1;
 esegui_query("insert into $tableregole (idregole,tariffa_per_persone,iddatainizio) values ('$idregole','".aggslashdb($tipotariffa)."', '".aggslashdb($num_persone)."')");
-echo mex("La regola di assegnazione",$pag)." 4 ".mex("è stata inserita",$pag).".<br>";
+echo "<br>".mex("La regola di assegnazione",$pag)." 4 ".mex("è stata inserita",$pag).".<br><br>";
 } # fine else if ($num_regole_esistente != 0)
+$aggiorna_ic_tar = 1;
 } # fine if ($inserire != "NO")
 } # fine if ($regola_4)
 
@@ -629,7 +671,6 @@ elemento = elemento.offsetParent;
 tab_app.style.visibility = 'visible';
 tab_app.innerHTML = '<table border=1 cellspacing=0 cellpadding=2 style=\"margin-left: '+(iLeft - 10)+'px; background-color: $t1color; text-align: center;\">\
 ";
-$app = esegui_query("select * from $tableappartamenti");
 $appartamenti = esegui_query("select * from $tableappartamenti order by idappartamenti");
 $num_appartamenti = numlin_query($appartamenti);
 $num_col = 4;
@@ -897,7 +938,7 @@ echo "}
 -->
 </script>
 
-<div style=\"text-align: center;\">".mex("Regola di assegnazione",$pag)." <b>4</b>.</div><br>
+<div style=\"text-align: center;\" id=\"hreg4\">".mex("Regola di assegnazione",$pag)." <b>4</b>.</div><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -928,6 +969,17 @@ txt_box.disabled = true;
 <button class=\"irul\" type=\"submit\" name=\"regola_4\" value=\"1\"><div>".mex("Inserisci o modifica la regola",$pag)." 4</div></button>
 </div></div></form><hr style=\"width: 95%\">";
 
+if ($tipotariffa_regola4 and preg_replace("/tariffa[0-9]+/","",$tipotariffa_regola4) == "") {
+echo "<script type=\"text/javascript\">
+<!--
+var sel_tr4 = document.getElementById(\"t4\");
+sel_tr4.value = '$tipotariffa_regola4';
+aggiorna_val_reg4();
+-->
+</script>
+";
+} # fine if ($tipotariffa_regola4 and...
+
 echo "<table><tr><td style=\"height: 6px;\"></td></tr></table>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"creaprezzi.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
