@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -78,8 +78,10 @@ ${"prima_pass".$id} = aggslashdb(${"prima_pass".$id});
 $nome = risul_query($lista_utenti,$num1,'nome_utente');
 if (htmlspecialchars(${"nome".$id}) != ${"nome".$id}) ${"nome".$id} = $nome;
 $tipo_pass = risul_query($lista_utenti,$num1,'tipo_pass');
+$cambia_nome = 0;
 if ($nome != ${"nome".$id} and str_replace("&","",${"nome".$id}) == ${"nome".$id}) {
 $cambiato = "SI";
+$cambia_nome = 1;
 echo mex("Il <b>nome</b> dell'utente",$pag)." <b>$id</b> ".mex("verrà cambiato da",$pag)." <i>$nome</i> ".mex("a",$pag)." <i>".${"nome".$id}."</i>.<br>";
 echo "<input type=\"hidden\" name=\"nome$id\" value=\"".${"nome".$id}."\">";
 } # fine if ($nome != ${"nome".$id} and...
@@ -88,7 +90,9 @@ if ($n_tipo_pass != "5" and $n_tipo_pass != "t") $n_tipo_pass = "n";
 if (C_DISABILITA_PASS_ADMIN == "NO" and $id == 1 and $tipo_pass != "n" and $n_tipo_pass == "n") $n_tipo_pass = $tipo_pass;
 if ($tipo_pass != $n_tipo_pass) {
 $cambiato = "SI";
-echo mex("Il <b>login</b> dell'utente",$pag)." <b>$id</b> ".mex("verrà cambiato da",$pag)." <i>";
+echo mex("Il <b>login</b> dell'utente",$pag)." <b>$id</b>";
+if (!$cambia_nome) echo " (<em>$nome</em>)";
+echo " ".mex("verrà cambiato da",$pag)." <i>";
 switch ($tipo_pass) {
 case "t":	echo mex("password conservata in chiaro",$pag); break;
 case "5":	echo mex("password conservata criptata con md5",$pag); break;
@@ -228,7 +232,7 @@ $nuovo_id = risul_query($nuovo_id,0,0) + 1;
 $nomi_contr = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'nomi_contratti' and idutente = '1' ");
 $nomi_contr = risul_query($nomi_contr,0,'valpersonalizza');
 esegui_query("insert into $tableutenti (idutenti,nome_utente,tipo_pass,datainserimento,hostinserimento) values ('$nuovo_id','$nome','n','$datainserimento','$HOSTNAME')");
-esegui_query("insert into $tableprivilegi (idutente,anno,casse_consentite,priv_mod_pers,priv_ins_clienti,prefisso_clienti,priv_messaggi,priv_inventario) values ('$nuovo_id','1','n,','nnnn','nnnss','n,','nn','nnnnnnnnn')");
+esegui_query("insert into $tableprivilegi (idutente,anno,casse_consentite,priv_mod_pers,priv_ins_clienti,prefisso_clienti,priv_messaggi,priv_inventario) values ('$nuovo_id','1','n,','nnnnn','nnnss','n,','nn','nnnnnnnnn')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('col_tab_tutte_prenota','$nuovo_id','nu#@&cg#@&in#@&fi#@&tc#@&ca#@&pa#@&ap#@&pe#@&co')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('rig_tab_tutte_prenota','$nuovo_id','to#@&ta#@&ca#@&pc')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('dati_struttura','$nuovo_id','#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&')");
@@ -466,6 +470,19 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.ph
 } # fine if ($modifica_gruppi)
 
 
+if ($cancella or $importa_priv) {
+function cancella_relazioni_utente ($tablerelutenti,$idrelutenti,$tablerel,$idrel) {
+$relazioni = esegui_query("select $idrel from $tablerel");
+$num_rel = numlin_query($relazioni);
+for ($num1 = 0 ; $num1 < $num_rel ; $num1++) {
+$relazione = aggslashdb(risul_query($relazioni,$num1,$idrel));
+$rel_esist = esegui_query("select $idrelutenti from $tablerelutenti where $idrelutenti = '$relazione' ");
+if (numlin_query($rel_esist) == 0) esegui_query("delete from $tablerel where $idrel = '$relazione' ");
+} # fine for $num1
+} # fine function cancella_relazioni_utente
+} # fine if ($cancella or $importa_priv)
+
+
 if ($cancella) {
 if ($id_utente_canc == 1) $id_utente_canc = 0;
 $id_utente_canc = aggslashdb($id_utente_canc);
@@ -520,15 +537,6 @@ esegui_query("delete from $tableprivilegi where idutente = '$id_utente_canc' ");
 esegui_query("delete from $tablerelutenti where idutente = '$id_utente_canc' ");
 esegui_query("delete from $tablerelgruppi where idutente = '$id_utente_canc' ");
 esegui_query("delete from $tablepersonalizza where idutente = '$id_utente_canc' ");
-function cancella_relazioni_utente ($tablerelutenti,$idrelutenti,$tablerel,$idrel) {
-$relazioni = esegui_query("select $idrel from $tablerel");
-$num_rel = numlin_query($relazioni);
-for ($num1 = 0 ; $num1 < $num_rel ; $num1++) {
-$relazione = aggslashdb(risul_query($relazioni,$num1,$idrel));
-$rel_esist = esegui_query("select $idrelutenti from $tablerelutenti where $idrelutenti = '$relazione' ");
-if (numlin_query($rel_esist) == 0) esegui_query("delete from $tablerel where $idrel = '$relazione' ");
-} # fine for $num1
-} # fine function cancella_relazioni_utente
 cancella_relazioni_utente($tablerelgruppi,"idgruppo",$tablegruppi,"idgruppi");
 cancella_relazioni_utente($tablerelutenti,"idnazione",$tablenazioni,"idnazioni");
 cancella_relazioni_utente($tablerelutenti,"idregione",$tableregioni,"idregioni");
@@ -573,8 +581,8 @@ $id_utente_importa = aggslashdb($id_utente_importa);
 $id_utente_esporta = aggslashdb($id_utente_esporta);
 include("./includes/funzioni_menu.php");
 include(C_DATI_PATH."/lingua.php");
-$tabelle_lock = array($tablepersonalizza,$tableprivilegi);
-$altre_tab_lock = array($tableanni,$tableutenti,$tablerelgruppi);
+$tabelle_lock = array($tablepersonalizza,$tablegruppi,$tableprivilegi,$tablerelgruppi);
+$altre_tab_lock = array($tableanni,$tableutenti);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 unset($id_utenti_importa);
 if (substr($id_utente_importa,0,2) == "gr") {
@@ -591,7 +599,7 @@ $utente_imp = esegui_query("select * from $tableutenti where idutenti = '$id_ute
 $utente_esp = esegui_query("select * from $tableutenti where idutenti = '$id_utente_esporta' ");
 if (numlin_query($utente_imp) == 1 and numlin_query($utente_esp) == 1) {
 
-if ($tipo_importa == "pers" or $tipo_importa == "priv_pers") {
+if ($tipo_importa == "pers" or $tipo_importa == "priv_pers" or $tipo_importa == "pers_grup" or $tipo_importa == "priv_pers_grup") {
 esegui_query("delete from $tablepersonalizza where idutente = '$id_utente_importa' and idpersonalizza NOT $LIKE 'giorno_vedi_ini_sett%' ");
 $pers = esegui_query("select * from $tablepersonalizza where idutente = '$id_utente_esporta' and idpersonalizza NOT $LIKE 'giorno_vedi_ini_sett%' ");
 $num_pers = numlin_query($pers);
@@ -612,9 +620,9 @@ else $valpersonalizza_num = "";
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente$valpersonalizza$valpersonalizza_num) values ('$e_idpersonalizza','$id_utente_importa'$e_valpersonalizza$e_valpersonalizza_num) ");
 } # fine for $num1
 $pers_importate = "SI";
-} # fine if ($tipo_importa == "pers" or $tipo_importa == "priv_pers")
+} # fine if ($tipo_importa == "pers" or $tipo_importa == "priv_pers" or $tipo_importa == "pers_grup" or $tipo_importa == "pers_grup")
 
-if ($tipo_importa == "priv" or $tipo_importa == "priv_pers") {
+if ($tipo_importa == "priv" or $tipo_importa == "priv_pers" or $tipo_importa == "priv_grup" or $tipo_importa == "priv_pers_grup") {
 esegui_query("delete from $tableprivilegi where idutente = '$id_utente_importa' ");
 $priv = esegui_query("select * from $tableprivilegi where idutente = '$id_utente_esporta' ");
 $num_priv = numlin_query($priv);
@@ -655,13 +663,26 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 } # fine if ($e_anno != 1)
 } # fine for $num1
 $priv_importati = "SI";
-} # fine if ($tipo_importa == "priv" or $tipo_importa == "priv_pers")
+} # fine if ($tipo_importa == "priv" or $tipo_importa == "priv_pers" or $tipo_importa == "priv_grup" or $tipo_importa == "priv_pers_grup")
+
+if ($tipo_importa == "grup" or $tipo_importa == "priv_grup" or $tipo_importa == "pers_grup" or $tipo_importa == "priv_pers_grup") {
+esegui_query("delete from $tablerelgruppi where idutente = '$id_utente_importa' ");
+$grup= esegui_query("select * from $tablerelgruppi where idutente = '$id_utente_esporta' ");
+$num_grup = numlin_query($grup);
+for ($num1 = 0 ; $num1 < $num_grup ; $num1++) {
+$idgruppo_imp = risul_query($grup,$num1,'idgruppo');
+esegui_query("insert into $tablerelgruppi (idutente,idgruppo) values ('$id_utente_importa','$idgruppo_imp') ");
+} # fine for $num1
+cancella_relazioni_utente($tablerelgruppi,"idgruppo",$tablegruppi,"idgruppi");
+$grup_importati = "SI";
+} # fine if ($tipo_importa == "grup" or $tipo_importa == "priv_grup" or $tipo_importa == "pers_grup" or $tipo_importa == "priv_pers_grup")
 
 } # fine if (numlin_query($utente_imp) == 1 and numlin_query($utente_esp) == 1)
 } # fine if ($id_utente_importa >= 2 and...
 } # fine for $num_imp
 if ($priv_importati == "SI") echo "<b>".mex("Privilegi importati",$pag).".</b><br>";
 if ($pers_importate == "SI") echo "<b>".mex("Personalizzazioni importate",$pag).".</b><br>";
+if ($grup_importati == "SI") echo "<b>".mex("Gruppi importati",$pag).".</b><br>";
 unlock_tabelle($tabelle_lock);
 } # fine if ($importa_priv)
 
@@ -787,9 +808,13 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.ph
 <input type=\"hidden\" name=\"importa_priv\" value=\"SI\">
 ".mex("Importa",$pag)."
  <select name=\"tipo_importa\">
+<option value=\"priv_pers_grup\"> ".mex("privilegi, personalizzazioni e gruppi",$pag)."</option>
 <option value=\"priv_pers\"> ".mex("privilegi e personalizzazioni",$pag)."</option>
+<option value=\"priv_grup\"> ".mex("privilegi e gruppi",$pag)."</option>
+<option value=\"pers_grup\"> ".mex("personalizzazioni e gruppi",$pag)."</option>
 <option value=\"priv\"> ".mex("solo i privilegi",$pag)."</option>
 <option value=\"pers\"> ".mex("solo le personalizzazioni",$pag)."</option>
+<option value=\"grup\"> ".mex("solo i gruppi",$pag)."</option>
 </select>
  <select name=\"id_utente_importa\">";
 echo str_replace("\">","\">".mex("dell'utente",$pag)." ",$option_select_utenti);
