@@ -95,10 +95,15 @@ define('C_DISABILITA_COD_EMAIL_MODELLI',"NO");
 define('C_PASSWORD_BOOKINGCOM_IC',"");
 define('C_ORGANIZZAZIONE_VENERE_IC',"");
 define('C_API_KEY_BBLIVERATE_IC',"");
+define('C_URL_MOD_EXT_CARTE_CREDITO',"");
+define('C_IP_MOD_EXT_CARTE_CREDITO',"");
+define('C_GIORNI_SCADENZA_PASS_CC',"90");
+define('C_NUM_ULTIME_PASS_CC_PROIBITE',"4");
 define('C_FILE_TITOLO_PERS',"");
 define('C_FILE_CSS_PERS',"");
 define('C_FILE_MOB_CSS_PERS',"");
 define('C_FILE_DOMINIO',"");
+define('C_DOMINIO_ADMIN_DIR',"");
 
 # Restrizioni per la demo amministratore
 define('C_RESTRIZIONI_DEMO_ADMIN',"NO");
