@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -53,8 +53,8 @@ $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',2.21);
-define('C_PHPR_VERSIONE_TXT',"2.2.1");
+define('C_PHPR_VERSIONE_NUM',2.22);
+define('C_PHPR_VERSIONE_TXT',"2.2.2");
 
 if (!function_exists('utf8_encode')) {
 function utf8_encode ($testo) { return ($testo); }
@@ -69,9 +69,9 @@ if ($id_sessione) $anno = substr($id_sessione,0,4);
 else {
 if (!defined('C_GIORNI_NUOVO_ANNO')) include("./costanti.php");
 $anno = date("Y",(time() + (C_DIFF_ORE * 3600) - (C_GIORNI_NUOVO_ANNO * 86400)));
-# Se ci troviamo nel periodo di C_GIORNI_NUOVO_ANNO ma il nuovo anno è già stato creato
+# Se ci troviamo nel periodo di C_GIORNI_NUOVO_ANNO ma il nuovo anno è già stato creato o non c'è nessuno dei 2
 if ($anno_corrente != $anno) {
-if (@is_file(C_DATI_PATH."/selectperiodi$anno_corrente.1.php")) $anno = $anno_corrente;
+if (@is_file(C_DATI_PATH."/selectperiodi$anno_corrente.1.php") or !@is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) $anno = $anno_corrente;
 } # fine if ($anno_corrente != $anno)
 } # fine else if ($id_sessione)
 } # fine if (!$anno)
@@ -416,7 +416,7 @@ $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
 $sec_log_sbagliati = 5;
 $limite_login_sbagliati = date("Y-m-d H:i:s",(time() - $sec_log_sbagliati + (C_DIFF_ORE * 3600)));
-$ultimo_login_sbagliato = esegui_query("select ultimo_accesso from $tabletransazioni where tipo_transazione = 'err_l' and ultimo_accesso >= '$limite_login_sbagliati'");
+$ultimo_login_sbagliato = esegui_query("select ultimo_accesso from $tabletransazioni where tipo_transazione = 'err_l' and dati_transazione1 = '$nome_utente_phpr' and ultimo_accesso >= '$limite_login_sbagliati'");
 if (numlin_query($ultimo_login_sbagliato) > 0) {
 $mostra_form_login = "SI";
 $messaggio_errore .= mex("Dopo un login <div style=\"display: inline; color: red;\">errato</div> si devono attendere","funzioni.php")." $sec_log_sbagliati ".mex("secondi","funzioni.php").".<br><br>";
@@ -428,13 +428,18 @@ $minuti_durata_sessione = esegui_query("select valpersonalizza_num from $tablepe
 $minuti_durata_sessione = risul_query($minuti_durata_sessione,0,'valpersonalizza_num');
 $limite_transazioni_vecchie = date("Y-m-d H:i:s",(time() - ($minuti_durata_sessione * 60) + (C_DIFF_ORE * 3600)));
 esegui_query("delete from $tabletransazioni where ultimo_accesso <= '$limite_transazioni_vecchie'");
-$login_sbagliati = esegui_query("select tipo_transazione from $tabletransazioni where tipo_transazione = 'err_l' and dati_transazione1 = '$nome_utente_phpr'");
+$login_sbagliati = esegui_query("select tipo_transazione from $tabletransazioni where tipo_transazione = 'err_l' and dati_transazione1 = '$nome_utente_phpr' ");
 $login_sbagliati = numlin_query($login_sbagliati);
 if ($login_sbagliati >= $num_log_sbagliati) {
 $messaggio_errore .= mex("Numero eccesivo di login <div style=\"display: inline; color: red;\">errati</div> negli ultimi","funzioni.php")." $minuti_durata_sessione ".mex("minuti","funzioni.php").".<br><br>";
 if (defined("C_HTML_POST_LOGIN") and C_HTML_POST_LOGIN != "") $messaggio_errore .= mex("È possibile reimpostare la password dal proprio account di hosting","funzioni.php").".".C_HTML_POST_LOGIN;
 } # fine if ($login_sbagliati >= $num_log_sbagliati)
 else {
+if ($pag != "inizio.php" and !@is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) {
+$mostra_form_login = "SI";
+$pag = "inizio.php";
+} # fine if ($pag != "inizio.php" and !@is_file(C_DATI_PATH."/selectperiodi$anno.1.php"))
+else {
 
 $utente = esegui_query("select * from $tableutenti where nome_utente = '$nome_utente_phpr'");
 if (numlin_query($utente) == 1) {
@@ -496,6 +501,7 @@ $id_transazione = $adesso.$val_casuale.$versione_transazione;
 esegui_query("insert into $tabletransazioni (idtransazioni,tipo_transazione,dati_transazione1,dati_transazione2,ultimo_accesso) values ('$id_transazione','err_l','$nome_utente_phpr','$REMOTE_ADDR','$ultimo_accesso')");
 } # fine if ($login_fallito == "SI")
 
+} # fine else if ($pag != "inizio.php" and !@is_file(C_DATI_PATH."/selectperiodi$anno.1.php")
 } # fine else if ($login_sbagliati >= $num_log_sbagliati)
 } # fine else if (numlin_query($ultimo_login_sbagliato) > 0)
 unlock_tabelle($tabelle_lock);
@@ -829,7 +835,7 @@ $partial_dates = 0;
 if (!$standalone_dates_menu) $current_dates_menu = 1;
 else $current_dates_menu = 0;
 if (substr($file,0,(strlen(C_DATI_PATH) + 15)) == C_DATI_PATH."/selperiodimenu" and $mos_tut_dat == "SI" and $modifica_pers != "NO") include(C_DATI_PATH."/selectperiodi".substr($file,(strlen(C_DATI_PATH) + 15)));
-else include("$file");
+else include($file);
 } # fine if ($last_dates_menu != $file)
 else if (!$standalone_dates_menu) $current_dates_menu++;
 
