@@ -175,6 +175,7 @@ esegui_query("insert into $tableanni (idanni,tipo_periodi) values ('$anno','$tip
 
 esegui_query("insert into $tablecosti (idcosti) values ('0')");
 esegui_query("insert into $tablesoldi (idsoldi,motivazione,soldi_prima) values ('1','soldi_prenotazioni_cancellate','0')");
+esegui_query("delete from $tablepersonalizza where idpersonalizza = 'visto_messaggio_periodi' ");
 
 // trovo il primo giorno di inizio/fine dell'anno (nel caso di periodi settimanali)
 $numgiorno = 1;
@@ -511,41 +512,6 @@ esegui_query("update $tablesoldi set idsoldi = '$idsoldi_corr' where idsoldi = '
 } # fine if ($nuovo_idprenota[$motiv[3]])
 } # fine for $num1
 
-$costi_importati = esegui_query("select * from $tablecosti_prec where datainserimento >= '$data_inizio_periodi' and  tipo_costo is not NULL order by idcosti");
-$num_costi_importati = numlin_query($costi_importati);
-$idcosti_corr = 0;
-for ($num1 = 0 ; $num1 < $num_costi_importati ; $num1++) {
-$idcosti_corr++;
-$idcosti_prec = risul_query($costi_importati,$num1,'idcosti');
-esegui_query("insert into $tablecosti select $col_tablecosti from $tablecosti_prec where idcosti = '$idcosti_prec' ");
-esegui_query("delete from $tablecosti_prec where idcosti = '$idcosti_prec' ");
-esegui_query("update $tablecosti set idcosti = '$idcosti_corr' where idcosti = '$idcosti_prec' ");
-} # fine for $num1
-$costo_cassa = 0;
-$data_lim = ($anno + 1)."-01-01 00:00:00";
-$costi_cassa = esegui_query("select * from $tablecosti where tipo_costo = 'e' and provenienza_costo = 'p' and datainserimento < '$data_lim' ");
-$num_costi_cassa = numlin_query($costi_cassa);
-for ($num2 = 0 ; $num2 < $num_costi_cassa ; $num2++) $costo_cassa = $costo_cassa + risul_query($costi_cassa,$num2,'val_costo');
-if ($costo_cassa) esegui_query("update $tablecosti set val_costo = '$costo_cassa' where idcosti = '0' ");
-unset($cassa_prec);
-$costi_non_importati = esegui_query("select * from $tablecosti_prec where tipo_costo is not NULL order by idcosti");
-$num_costi_non_importati = numlin_query($costi_non_importati);
-for ($num1 = 0 ; $num1 < $num_costi_non_importati ; $num1++) {
-$tipo_costo = risul_query($costi_non_importati,$num1,'tipo_costo');
-$val_costo = risul_query($costi_non_importati,$num1,'val_costo');
-$utente_costo = risul_query($costi_non_importati,$num1,'utente_inserimento');
-if ($tipo_costo == "e") $cassa_prec[$utente_costo] = $cassa_prec[$utente_costo] + (double) $val_costo;
-else $cassa_prec[$utente_costo] = $cassa_prec[$utente_costo] - (double) $val_costo;
-} # fine for $num1
-if (@is_array($cassa_prec)) {
-$datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
-reset($cassa_prec);
-while (list($utente_costo,$val_costo) = each($cassa_prec)) {
-$idcosti_corr++;
-esegui_query("insert into $tablecosti (idcosti,nome_costo,val_costo,persona_costo,tipo_costo,datainserimento,hostinserimento,utente_inserimento) values ('$idcosti_corr','$anno_prec','$val_costo','','e','$datainserimento','$HOSTNAME','$utente_costo') ");
-} # fine (list($utente_costo,$val_costo) = each($cassa_prec))
-} # fine if (@is_array($cassa_prec))
-
 # aggiorno i messaggi con prenotazioni del nuovo anno già inserite, quelli da inserire sono aggiornati con i modelli internet
 $messaggi_importati = esegui_query("select * from $tablemessaggi where stato = 'ins' and dati_messaggio18 = '$anno_prec' ");
 $num_messaggi_importati = numlin_query($messaggi_importati);
@@ -594,10 +560,10 @@ $nomi_contr_ut[$idutente_contr][$dati_nome_contratto[0]] = $dati_nome_contratto[
 } # fine for $num1
 unset($prefissi_contr);
 for ($num1 = 0 ; $num1 < $num_dirs_salva ; $num1++) {
-$dir_salva = risul_query($dirs_salva,0,'testo');
+$dir_salva = risul_query($dirs_salva,$num1,'testo');
 if ($dir_salva == "~") $dir_salva = $dir_salva_home;
 if (defined('C_CARTELLA_CREA_MODELLI') and C_CARTELLA_CREA_MODELLI != "") $dir_salva = C_CARTELLA_CREA_MODELLI."/".str_replace("..","",$dir_salva);
-if (!@is_dir($dir_salva)) $dir_salva = "";
+if (@is_dir($dir_salva)) {
 $num_contr = risul_query($dirs_salva,0,'numero');
 $tipo_contratto = esegui_query("select tipo from ".$PHPR_TAB_PRE."contratti where numero = '$num_contr' and tipo $LIKE 'contr%' ");
 $tipo_contratto = risul_query($tipo_contratto,0,'tipo');
@@ -607,7 +573,7 @@ if ($tipo_contratto == "contrtxt") $suff_file = "txt";
 $filelock_contr = fopen($dir_salva."/crea_contr.lock","w+");
 flock($filelock_contr,2);
 for ($num2 = 0 ; $num2 < $num_utenti ; $num2++) {
-$idutente_contr = risul_query($utenti,$num1,'idutenti');
+$idutente_contr = risul_query($utenti,$num2,'idutenti');
 if (!$prefissi_contr[$dir_salva."/".$nomi_contr_ut[$idutente_contr][$num_contr]]) {
 $nome_contratto = $nomi_contr_ut[$idutente_contr][$num_contr];
 $prefissi_contr[$dir_salva."/".$nome_contratto] = 1;
@@ -652,12 +618,59 @@ closedir($contr_dir);
 flock($filelock_contr,3);
 fclose($filelock_contr);
 unlink($dir_salva."/crea_contr.lock");
+} # fine if (@is_dir($dir_salva))
 } # fine for $num1
 } # fine if ($num_dirs_salva)
 
 } # fine else if ($num_periodo_interferenza == 0)
 
 
+$costi_importati = esegui_query("select * from $tablecosti_prec where datainserimento >= '$data_inizio_periodi' and  tipo_costo is not NULL order by idcosti");
+$num_costi_importati = numlin_query($costi_importati);
+$idcosti_corr = 0;
+for ($num1 = 0 ; $num1 < $num_costi_importati ; $num1++) {
+$idcosti_corr++;
+$idcosti_prec = risul_query($costi_importati,$num1,'idcosti');
+esegui_query("insert into $tablecosti select $col_tablecosti from $tablecosti_prec where idcosti = '$idcosti_prec' ");
+esegui_query("delete from $tablecosti_prec where idcosti = '$idcosti_prec' ");
+esegui_query("update $tablecosti set idcosti = '$idcosti_corr' where idcosti = '$idcosti_prec' ");
+} # fine for $num1
+$costo_cassa = 0;
+$data_lim = ($anno + 1)."-01-01 00:00:00";
+$costi_cassa = esegui_query("select * from $tablecosti where tipo_costo = 'e' and provenienza_costo = 'p' and datainserimento < '$data_lim' ");
+$num_costi_cassa = numlin_query($costi_cassa);
+for ($num2 = 0 ; $num2 < $num_costi_cassa ; $num2++) $costo_cassa = $costo_cassa + risul_query($costi_cassa,$num2,'val_costo');
+if ($costo_cassa) esegui_query("update $tablecosti set val_costo = '$costo_cassa' where idcosti = '0' ");
+$cassa_prec = array();
+$costi_non_importati = esegui_query("select * from $tablecosti_prec where tipo_costo is not NULL order by idcosti");
+$num_costi_non_importati = numlin_query($costi_non_importati);
+for ($num1 = 0 ; $num1 < $num_costi_non_importati ; $num1++) {
+$tipo_costo = risul_query($costi_non_importati,$num1,'tipo_costo');
+$val_costo = risul_query($costi_non_importati,$num1,'val_costo');
+$utente_costo = risul_query($costi_non_importati,$num1,'utente_inserimento');
+$nome_cassa = risul_query($costi_non_importati,$num1,'nome_cassa');
+if ($tipo_costo == "e") $cassa_prec[$utente_costo][$nome_cassa] = $cassa_prec[$utente_costo][$nome_cassa] + (double) $val_costo;
+else $cassa_prec[$utente_costo][$nome_cassa] = $cassa_prec[$utente_costo][$nome_cassa] - (double) $val_costo;
+} # fine for $num1
+$datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
+reset($cassa_prec);
+while (list($utente_costo,$casse) = each($cassa_prec)) {
+reset($casse);
+while (list($nome_cassa,$val_costo) = each($casse)) {
+$idcosti_corr++;
+$nome_utente = esegui_query("select * from $tableutenti where idutenti = '$utente_costo' ");
+if (numlin_query($nome_utente)) $nome_utente = risul_query($nome_utente,0,'nome_utente');
+else $nome_utente = "";
+$tipo_costo = "e";
+if ($val_costo < 0) {
+$tipo_costo = "s";
+$val_costo = (double) $val_costo * -1;
+} # fine if ($val_costo < 0)
+esegui_query("insert into $tablecosti (idcosti,nome_costo,val_costo,persona_costo,tipo_costo,datainserimento,hostinserimento,utente_inserimento) values ('$idcosti_corr','$anno_prec','$val_costo','".aggslashdb($nome_utente)."','$tipo_costo','$datainserimento','$HOSTNAME','$utente_costo') ");
+if ($nome_cassa != "@#principale#@") esegui_query("update $tablecosti set nome_cassa = '".aggslashdb($nome_cassa)."' where idcosti = '$idcosti_corr' ");
+} # fine while (list($nome_cassa,$val_costo) = each($casse))
+} # fine while (list($utente_costo,$casse) = each($cassa_prec))
+
 $colonne = "idntariffe,nomecostoagg,tipo_ca,valore_ca,valore_perc_ca,arrotonda_ca,tasseperc_ca,associasett_ca,numsett_ca,moltiplica_ca,periodipermessi_ca,beniinv_ca,appincompatibili_ca,variazione_ca,mostra_ca,categoria_ca,letto_ca,numlimite_ca,regoleassegna_ca,utente_inserimento";
 for ($num1 = 1 ; $num1 <= $num_tariffe_tab ; $num1++) {
 $nome_nuova_tariffa = "tariffa" . $num1;
