@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -215,9 +215,12 @@ $regione_maius = aggslashdb($regione_maius);
 esegui_query("update $tableclienti set regione = '$regione_maius' where idclienti = '$idclienti' ");
 } # fine if ($regione)
 if ($nomevia) {
+if (strcmp($via,"")) {
 if ($lingua_mex != "ita") include("./includes/lang/$lingua_mex/ordine_frasi.php");
-if ($ordine_strada == 2) $via = $nomevia . " " . $via;
-else $via = $via . " " . $nomevia;
+if ($ordine_strada == 2) $via = $nomevia." ".$via;
+else $via = $via." ".$nomevia;
+} # fine if (strcmp($via,""))
+else $via = $nomevia;
 $via_maius = trim(ucwords($via));
 $via_maius = aggslashdb($via_maius);
 esegui_query("update $tableclienti set via = '$via_maius' where idclienti = '$idclienti' ");
@@ -483,29 +486,34 @@ top.frames[ifrm].location.replace('$pag_relutenti?id_sessione=$id_sessione&anno=
 
 
 unset($liste_relutente);
-function mostra_lista_relutenti ($nome,$sel,$id_utente,$nomelista,$idlista,$idrelutenti,$tablelista,$tablerelutenti,$size="",$javascript="",$campo_opzionale="",$rel_inf_sing="",$id_rel_inf="",$rel_sup_sing="") {
+function mostra_lista_relutenti ($nome,$sel,$id_utente,$nomelista,$idlista,$idrelutenti,$tablelista,$tablerelutenti,$size="",$javascript="",$campo_opzionale="",$rel_inf_sing="",$id_rel_inf="",$rel_sup_sing="",$id_sup_sel="") {
+if (!$id_sup_sel) $id_sup_sel = 0;
 global $liste_relutente;
-if (!$liste_relutente[$nomelista]) {
-if (!$rel_sup_sing) $lista_utente = esegui_query("select distinct $tablelista.$nomelista from $tablerelutenti inner join $tablelista on $tablerelutenti.$idrelutenti = $tablelista.$idlista where $tablerelutenti.idutente = '$id_utente' order by $tablelista.$nomelista");
-else $lista_utente = esegui_query("select distinct $tablelista.$nomelista from $tablerelutenti inner join $tablelista on $tablerelutenti.$idrelutenti = $tablelista.$idlista where $tablerelutenti.idutente = '$id_utente' and $tablerelutenti.idsup is NULL order by $tablelista.$nomelista");
+if (!$liste_relutente[$id_sup_sel][$nomelista]) {
+if (!$rel_sup_sing and !$id_sup_sel) $lista_utente = esegui_query("select distinct $tablelista.$nomelista from $tablerelutenti inner join $tablelista on $tablerelutenti.$idrelutenti = $tablelista.$idlista where $tablerelutenti.idutente = '$id_utente' order by $tablelista.$nomelista");
+else {
+if ($id_sup_sel) $is_id = "= '$id_sup_sel'";
+else $is_id = "is NULL";
+$lista_utente = esegui_query("select distinct $tablelista.$nomelista from $tablerelutenti inner join $tablelista on $tablerelutenti.$idrelutenti = $tablelista.$idlista where $tablerelutenti.idutente = '$id_utente' and $tablerelutenti.idsup $is_id order by $tablelista.$nomelista");
+} # fine else if (!$rel_sup_sing and !$id_sup_sel)
 $num_lista_utente = numlin_query($lista_utente);
 if (!$num_lista_utente) {
 if (!$campo_opzionale) {
 if ($size) $size = " size=\"$size\"";
 else $size = "";
-$liste_relutente[$nomelista] = "<input type=\"text\" name=\"\"$size>";
+$liste_relutente[$id_sup_sel][$nomelista] = "<input type=\"text\" name=\"\"$size>";
 } # fine if (!$campo_opzionale)
 } # fine if (!$num_lista_utente)
 else {
-$liste_relutente[$nomelista] = "<select name=\"\">\n<option value=\"\">------</option>";
+$liste_relutente[$id_sup_sel][$nomelista] = "<select name=\"\">\n<option value=\"\">------</option>";
 for ($num1 = 0 ; $num1 < $num_lista_utente ; $num1++) {
 $opzione = risul_query($lista_utente,$num1,$nomelista,$tablelista);
-$liste_relutente[$nomelista] .= "<option value=\"$opzione\">$opzione</option>";
+$liste_relutente[$id_sup_sel][$nomelista] .= "<option value=\"$opzione\">$opzione</option>";
 } # fine for $num1
-$liste_relutente[$nomelista] .= "</select>";
+$liste_relutente[$id_sup_sel][$nomelista] .= "</select>";
 } # fine else if (!$num_lista_utente)
-} # fine if (!$liste_relutente[$nomelista])
-$lista_return = $liste_relutente[$nomelista];
+} # fine if (!$liste_relutente[$id_sup_sel][$nomelista])
+$lista_return = $liste_relutente[$id_sup_sel][$nomelista];
 if ($sel) {
 if (substr($lista_return,0,7) == "<select") $lista_return = str_replace("<option value=\"$sel\">","<option value=\"$sel\" selected>",$lista_return);
 else $lista_return = str_replace(" name=\"\""," name=\"\" value=\"$sel\"",$lista_return);
