@@ -23,7 +23,7 @@
 
 
 
-function inserisci_prenotazione ($inizioperiodo,$fineperiodo,$lista_app,$tipotariffa,$numpersone,$prenota_vicine,$idclienti,$conferma,$pagato,$caparra,$met_paga_caparra,$commissioni,$origine_prenota,$sconto,$giorno_stima_checkin,$ora_stima_checkin,$min_stima_checkin,$commento,&$stato,$anno,$PHPR_TAB_PRE,$ins_passato="",$id_utente_imp="",$id_prenota_imp="",$tariffe_sett_imp="",$ins_costi_agg="") {
+function inserisci_prenotazione ($inizioperiodo,$fineperiodo,$lista_app,$tipotariffa,$numpersone,$prenota_vicine,$idclienti,$conferma,$pagato,$caparra,$met_paga_caparra,$commissioni,$origine_prenota,$sconto,$giorno_stima_checkin,$ora_stima_checkin,$min_stima_checkin,$commento,&$stato,$anno,$PHPR_TAB_PRE,$ins_passato="",$id_utente_imp="",$id_prenota_imp="",$tariffe_sett_imp="",$ins_costi_agg="",$costo_letto_imposto="NO") {
 global $id_utente,$HOSTNAME;
 
 $PHPR_TAB_PRE = aggslashdb($PHPR_TAB_PRE);
@@ -55,10 +55,13 @@ $numappartamenti = numlin_query($appartamenti);
 $id_app_richiesti = 0;
 
 $dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
-if ($ins_costi_agg) {
+if ($ins_costi_agg or $costo_letto_imposto != "NO") {
 if (!function_exists('dati_costi_agg_ntariffe')) include("./includes/funzioni_costi_agg.php");
 $dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num'],"NO","",$tableappartamenti);
-} # fine if ($ins_costi_agg)
+} # fine if ($ins_costi_agg or $costo_letto_imposto != "NO")
+
+$app_eliminati_costi = array();
+
 
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 
@@ -127,14 +130,14 @@ $regole4 = esegui_query("select * from $tableregole where tariffa_per_persone =
 if (numlin_query($regole4) == 1) $numpersone[$n_t] = risul_query($regole4,0,'iddatainizio');
 } # fine if (!$numpersone[$n_t])
 
-if (!$numpersone) {
+if (!$numpersone[$n_t]) {
 if ($dati_tariffe[$tipotariffa[$n_t]]['moltiplica'] == "p") {
 $inserire = "NO";
 $mess_errore .= mex("Si deve inserire il numero delle persone per questa tariffa","clienti.php");
 if ($num_tipologie > 1) $mess_errore .= "(".mex("tipologia","clienti.php")." $n_t)";
 $mess_errore .= ".<br>";
 } # fine if ($dati_tariffe[$tipotariffa[$n_t]]['moltiplica'] == "p")
-} # fine if (!$numpersone)
+} # fine if (!$numpersone[$n_t])
 
 } # fine else if ($tariffa_sbagliata == "SI")
 
@@ -165,6 +168,37 @@ $mess_errore .= ".<br>";
 } # fine for $num1
 } # fine if ($lista_app[$n_t])
 
+# se il costo letto imposto ha appartamenti incompatibili
+if ($costo_letto_imposto != "NO" and $costo_letto_imposto[$n_t]['id'] and strcmp($dati_ca[$dati_ca['id'][$costo_letto_imposto[$n_t]['id']]]['appincompatibili'],"")) {
+$app_incomp_costi[$n_t] = ",".$dati_ca[$dati_ca['id'][$costo_letto_imposto[$n_t]['id']]]['appincompatibili'].",";
+$lista_app_corr = $lista_app[$n_t];
+$lista_app[$n_t] = "";
+if (strcmp($lista_app_corr,"")) $lista_app_corr = ",$lista_app_corr,";
+for ($num1 = 0 ; $num1 < $numappartamenti ; $num1++) {
+$idapp = risul_query($appartamenti,$num1,'idappartamenti');
+if (!$lista_app_corr or str_replace(",$idapp,","",$lista_app_corr) != $lista_app_corr) {
+if (str_replace(",$idapp,","",$app_incomp_costi[$n_t]) == $app_incomp_costi[$n_t]) $lista_app[$n_t] .= ",$idapp";
+else $app_eliminati_costi[$n_t] .= ",$idapp";
+} # fine if (!$lista_app_corr or str_replace(",$idapp,","",$lista_app_corr) != $lista_app_corr)
+} # fine for $num1
+if ($lista_app[$n_t]) {
+$lista_app[$n_t] = substr($lista_app[$n_t],1);
+$app_eliminati_costi[$n_t] = substr($app_eliminati_costi[$n_t],1);
+if (str_replace(",","",$lista_app[$n_t]) != $lista_app[$n_t]) $assegnazioneapp[$n_t] = "c";
+else $assegnazioneapp[$n_t] = "k";
+$app_richiesti_id[$n_t] = "";
+$vett_app = explode(",",$lista_app[$n_t]);
+$num_app = count($vett_app);
+for ($num1 = 0 ; $num1 < $num_app ; $num1++) $app_richiesti_id[$n_t][$vett_app[$num1]] = "SI";
+} # fine if ($lista_app[$n_t])
+else {
+$mess_errore .= mex("Non c'è nessun appartamento tra quelli richiesti che sia compatibile con i costi aggiuntivi selezionati",'unit.php');
+if ($num_tipologie > 1) $mess_errore .= " (".mex("tipologia","clienti.php")." $n_t)";
+$mess_errore .= ".<br>";
+$inserire = "NO";
+} # fine else if ($lista_app[$n_t])
+} # fine if ($costo_letto_imposto != "NO" and $costo_letto_imposto[$n_t]['id'] and strcmp($dati_ca[$dati_ca['id'][$costo_letto_imposto[$n_t]['id']]]['appincompatibili'],""))
+
 if ($numpersone[$n_t]) {
 if (controlla_num_pos($numpersone[$n_t]) == "NO") {
 $inserire = "NO";
@@ -328,7 +362,9 @@ if (!$risul_agg) $fatto_libera2 = "NO";
 } # fine if ($fatto_libera2 != "NO")
 if ($fatto_libera2 == "NO") {
 $inserire = "NO";
-$mess_errore .= mex("Nel periodo selezionato non è possibile ospitare il cliente negli appartamenti richiesti",'unit.php').".<br>";
+$mess_errore .= mex("Nel periodo selezionato non è possibile ospitare il cliente negli appartamenti richiesti",'unit.php');
+if ($app_incomp_costi) $mess_errore .= " ".mex("con i costi aggiuntivi selezionati",'clienti.php');
+$mess_errore .= ".<br>";
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 $mess_prenota .= mex("Prenotazione","prenota.php").mex("dal","prenota.php")." <b>".formatta_data($inizioperiodo_orig[$n_t],$stile_data)."</b> ".mex("al","prenota.php")." <b>".formatta_data($fineperiodo_orig[$n_t],$stile_data)."</b>";
 $mess_prenota .= " ".mex("a nome di","prenota.php")." <b>$cognome</b> ";
@@ -340,7 +376,7 @@ $mess_prenota .= ", ".mex("tariffa","prenota.php")." \"$nometariffa_vedi\".<br><
 } # fine if ($fatto_libera2 == "NO")
 else {
 $appartamento = $app_liberato;
-$mess_regola1 .= mex("Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>","clienti.php").":<br>";
+$mess_regola1 .= mex("Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>",'clienti.php').":<br>";
 for ($num1 = 0 ; $num1 < $num_app_agenzia ; $num1++) {
 $mot2 = risul_query($app_agenzia,$num1,'motivazione2');
 if ($mot2 != "x") {
@@ -422,7 +458,9 @@ liberasettimane($idinizioperiodo_vett,$idfineperiodo_vett,$limiti_var,$anno,$fat
 
 if ($fatto_libera == "NO") {
 $inserire = "NO";
-$mess_errore .= mex("Nel periodo selezionato non è possibile ospitare il cliente in un appartamento tra quelli richiesti",'unit.php').".<br>";
+$mess_errore .= mex("Nel periodo selezionato non è possibile ospitare il cliente in un appartamento tra quelli richiesti",'unit.php');
+if ($app_incomp_costi) $mess_errore .= " ".mex("con i costi aggiuntivi selezionati",'clienti.php');
+$mess_errore .= ".<br>";
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 $mess_prenota .= mex("Prenotazione","prenota.php").mex("dal","prenota.php")." <b>".formatta_data($inizioperiodo_orig[$n_t],$stile_data)."</b> ".mex("al","prenota.php")." <b>".formatta_data($fineperiodo_orig[$n_t],$stile_data)."</b>";
 $mess_prenota .= " ".mex("a nome di","prenota.php")." <b>$cognome</b> ";
@@ -533,6 +571,118 @@ $caparra[$n_t] = formatta_soldi($caparra[$n_t]);
 if (controlla_soldi($caparra[$n_t],"pos") == "NO") $caparra[$n_t] = "";
 if (!$caparra[$n_t]) $caparra[$n_t] = calcola_caparra($dati_tariffe,$tipotariffa[$n_t],$inizioperiodo[$n_t],$fineperiodo[$n_t],$costo_tariffa_tot,$lista_tariffe_sett);
 
+
+# calcolo costi nulli, non letto e senza inventario da associare alla tariffa, tutti come se fossero "se possibile". Oppure il costo imposto per letti aggiuntivi
+if ($ins_costi_agg or $costo_letto_imposto != "NO") {
+unset($num_letti_agg);
+unset($num_costi_presenti);
+$oggi_costo = date("Ymd",(time() + (C_DIFF_ORE * 3600)));
+for ($num_costo = 0 ; $num_costo < $dati_ca['num'] ; $num_costo++) {
+$associa_costo = "NO";
+$nummoltiplica_ca = "";
+if ($ins_costi_agg == "costi_nulli") {
+if (!$dati_ca[$num_costo]['valore'] and !$dati_ca[$num_costo]['valore_perc'] and $dati_ca[$num_costo]['letto'] != "s" and !$dati_ca[$num_costo]['tipo_beniinv']) {
+$associa_costo_tariffa = associa_costo_a_tariffa($dati_ca,$num_costo,$tipotariffa[$n_t],($fineperiodo[$n_t] - $inizioperiodo[$n_t] + 1));
+if ($associa_costo_tariffa == "SI") $associa_costo = "SI";
+if ($associa_costo_tariffa != "SI" and !$dati_ca[$num_costo]["incomp_".$tipotariffa[$n_t]]) {
+if ($dati_ca[$num_costo]['assegna_con_num_prenota'] and count($inizioperiodo) >= $dati_ca[$num_costo]['assegna_con_num_prenota']) $associa_costo = "SI";
+if ($dati_ca[$num_costo]['assegna_da_ini_prenota']) {
+$giorni_lim = substr($dati_ca[$num_costo]['assegna_da_ini_prenota'],1);
+$limite = date("Ymd",mktime(0,0,0,substr($inizioperiodo_orig[$n_t],5,2),(substr($inizioperiodo_orig[$n_t],8,2) - $giorni_lim),substr($inizioperiodo_orig[$n_t],0,4)));
+if (substr($dati_ca[$num_costo]['assegna_da_ini_prenota'],0,1) == ">" and $oggi_costo < $limite) $associa_costo = "SI";
+if (substr($dati_ca[$num_costo]['assegna_da_ini_prenota'],0,1) == "<" and $oggi_costo > $limite) $associa_costo = "SI";
+} # fine if ($dati_ca[$num_costo][assegna_da_ini_prenota])
+} # fine if ($associa_costo_tariffa != "SI" and...
+} # fine if (!$dati_ca[$num_costo]['valore'] and !$dati_ca[$num_costo]['valore_perc'] and...
+} # fine if ($ins_costi_agg == "costi_nulli")
+if ($costo_letto_imposto != "NO" and $costo_letto_imposto[$n_t]['id'] == $dati_ca[$num_costo]['id'] and $dati_ca[$num_costo]['letto'] == "s") {
+$associa_costo = "SI";
+$nummoltiplica_ca = $costo_letto_imposto[$n_t]['molt'];
+} # fine if ($costo_letto_imposto != "NO" and $costo_letto_imposto[$n_t]['id'] == $dati_ca[$num_costo]['id'] and...
+
+if ($associa_costo == "SI") {
+#if ($dati_ca[$num_costo][tipo_val] == "q" and $costo_totale_presente = "SI") $associa_costo = "NO";
+$settimane_costo = calcola_settimane_costo($tableperiodi,$dati_ca,$num_costo,$inizioperiodo[$n_t],$fineperiodo[$n_t],"","");
+calcola_moltiplica_costo($dati_ca,$num_costo,$moltiplica,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo,$nummoltiplica_ca,$numpersone[$n_t],$num_letti_agg);
+$num_costi_presenti_copia = $num_costi_presenti;
+$periodo_costo_trovato = trova_periodo_permesso_costo($dati_ca,$num_costo,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo);
+if ($periodo_costo_trovato == "NO") $associa_costo = "NO";
+else if (controlla_num_limite_costo($tablecostiprenota,$tableprenota,$dati_ca,$num_costo,$num_costi_presenti_copia,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo,$moltiplica) == "NO") $associa_costo = "NO";
+
+if ($associa_costo == "SI") {
+$num_costi_presenti = $num_costi_presenti_copia;
+$idcostiprenota = esegui_query("select max(idcostiprenota) from $tablecostiprenota");
+$idcostiprenota = risul_query($idcostiprenota,0,0) + 1;
+$tipo_ca = $dati_ca[$num_costo]['tipo'].$dati_ca[$num_costo]['tipo_val'];
+$valore_ca = $dati_ca[$num_costo]['valore'];
+$valore_perc_ca = $dati_ca[$num_costo]['valore_perc'];
+$prezzo_costo_tot = calcola_prezzo_totale_costo($dati_ca,$num_costo,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo,$moltiplica,$costo_tariffa,$lista_tariffe_sett,$costo_tariffa_tot,$caparra,$numpersone[$n_t]);
+$associasett_ca = $dati_ca[$num_costo]['associasett'];
+if ($dati_ca[$num_costo]['var_percentuale'] != "s" and $dati_ca[$num_costo]['tipo_val'] != "f") {
+$tipo_ca = $dati_ca[$num_costo]['tipo']."f";
+$moltiplica = 1;
+if ($dati_ca[$num_costo]['tipo'] == "s") {
+$settimane_costo = 1;
+$associasett_ca = "n";
+} # fine if ($dati_ca[$num_costo][tipo] == "s")
+$valore_ca = $prezzo_costo_tot;
+$valore_perc_ca = 0;
+} # fine if ($dati_ca[$num_costo][var_percentuale] != "s" and...
+if ($dati_ca[$num_costo]['var_moltiplica'] == "s") $varmoltiplica_ca = $dati_ca[$num_costo]['moltiplica'].$dati_ca[$num_costo]['molt_max'].$dati_ca[$num_costo]['molt_agg'].",".$dati_ca[$num_costo]['molt_max_num'];
+else $varmoltiplica_ca = "cx0,";
+if ($dati_ca[$num_costo]['var_numsett'] == "s") $varnumsett_ca = $dati_ca[$num_costo]['numsett_orig'];
+else $varnumsett_ca = "c";
+if ($dati_ca[$num_costo]['var_periodip'] == "s") $varperiodipermessi_ca = $dati_ca[$num_costo]['periodipermessi_orig'];
+else $varperiodipermessi_ca = "";
+$varbeniinv_ca = "";
+if ($dati_ca[$num_costo]['var_appi'] == "s") $varappincompatibili_ca = $dati_ca[$num_costo]['appincompatibili'];
+else $varappincompatibili_ca = "";
+if ($dati_ca[$num_costo]['var_tariffea'] == "s") $vartariffeassociate_ca = "p".$dati_ca[$num_costo][$tipotariffa[$n_t]];
+else $vartariffeassociate_ca = "";
+$vartariffeincomp_ca = "";
+if ($dati_ca[$num_costo]['var_tariffei'] == "s") {
+for ($numtariffa = 1 ; $numtariffa <= $dati_tariffe['num'] ; $numtariffa++) {
+if ($dati_ca[$num_costo]["incomp_tariffa".$numtariffa] == "i") $vartariffeincomp_ca .= ",".$numtariffa;
+} # fine for $numtariffa
+if ($vartariffeincomp_ca) $vartariffeincomp_ca = substr($vartariffeincomp_ca,1);
+} # fine if ($dati_ca[$num_costo][var_tariffei] == "s")
+if ($dati_ca[$num_costo]['var_comb'] == "s") $variazione_ca = $dati_ca[$num_costo]['combina'];
+else $variazione_ca = "n";
+$variazione_ca .= $dati_ca[$num_costo]['escludi_tot_perc'];
+esegui_query("insert into $tablecostiprenota (idcostiprenota,idprenota,tipo,nome,valore,associasett,settimane,moltiplica,letto,idntariffe,variazione,varmoltiplica,varnumsett,varperiodipermessi,varbeniinv,varappincompatibili,vartariffeassociate,vartariffeincomp,datainserimento,hostinserimento,utente_inserimento) values ('$idcostiprenota','$idprenota','$tipo_ca','".aggslashdb($dati_ca[$num_costo]['nome'])."','$valore_ca','$associasett_ca','$settimane_costo','$moltiplica','".$dati_ca[$num_costo]['letto']."','".$dati_ca[$num_costo]['id']."','$variazione_ca','$varmoltiplica_ca','$varnumsett_ca','$varperiodipermessi_ca','$varbeniinv_ca','$varappincompatibili_ca','$vartariffeassociate_ca','$vartariffeincomp_ca','$datainserimento','$HOSTNAME','$id_utente_ins')");
+if (substr($tipo_ca,1,1) != "f") esegui_query("update $tablecostiprenota set valore_perc = '$valore_perc_ca', arrotonda = '".$dati_ca[$num_costo]['arrotonda']."' where idcostiprenota = '$idcostiprenota'");
+if ($dati_ca[$num_costo]['tasseperc']) esegui_query("update $tablecostiprenota set tasseperc = '".$dati_ca[$num_costo]['tasseperc']."' where idcostiprenota = '$idcostiprenota'");
+if (strcmp($dati_ca[$num_costo]['categoria'],"")) esegui_query("update $tablecostiprenota set categoria = '".$dati_ca[$num_costo]['categoria']."' where idcostiprenota = '$idcostiprenota'");
+if ($prezzo_costo_tot) {
+$prezzo_costo_tot_p = punti_in_num($prezzo_costo_tot,$stile_soldi);
+$mess_prenota .= "$prezzo_costo_tot_p $Euro &nbsp;&nbsp;&nbsp;&nbsp;&nbsp; ";
+if ($dati_ca[$num_costo]['tipo'] == "u") $mess_prenota .= mex("Costo unico","prenota.php");
+if ($dati_ca[$num_costo]['tipo'] == "s") $mess_prenota .= mex("Costo $parola_settimanale","prenota.php");
+$mess_prenota .= " \"".$dati_ca[$num_costo]['nome']."\"";
+if ($associasett_ca == "s") {
+$moltiplica = explode(",",$moltiplica);
+$valnummoltiplica_ca = $moltiplica[1];
+for ($num2 = 2 ; $num2 < (count($moltiplica) - 1) ; $num2++) if ($moltiplica[$num2] != $valnummoltiplica_ca) $valnummoltiplica_ca = 1;
+} # fine if ($associasett_ca == "s")
+else $valnummoltiplica_ca = $moltiplica;
+if ($valnummoltiplica_ca != 1) $mess_prenota .= " (".mex("moltiplicato per","prenota.php")." $valnummoltiplica_ca)";
+$mess_prenota .= "<br>";
+$costo_tariffa_tot = (double) $costo_tariffa_tot + (double) $prezzo_costo_tot;
+} # fine if ($prezzo_costo_tot)
+} # fine if ($associa_costo == "SI")
+} # fine if ($associa_costo == "SI")
+} # fine for $num_costo
+} # fine if ($ins_costi_agg or $costo_letto_imposto != "NO")
+
+
+# Appartamenti eliminati dai costi aggiuntivi, verranno aggiunti di nuovo agli appartamenti
+# assegnabili quando si modifica la prenotazione (se il costo mantiene gli appartamenti 
+# incompatibili con la modifica della prenotazione, allora questi appartamenti verranno tolti 
+# di nuovo dal costo quando si modifica la prenotazione, finchè il costo rimarrà associato)
+if ($app_eliminati_costi[$n_t]) {
+esegui_query("update $tableprenota set incompatibilita = '".aggslashdb($app_eliminati_costi[$n_t])."' where idprenota = '$idprenota' ");
+} # fine if ($app_eliminati_costi[$n_t])
+
 $sconto[$n_t] = (double) formatta_soldi($sconto[$n_t]);
 if ($sconto[$n_t] and controlla_soldi($sconto[$n_t]) == "SI") {
 if ($sconto[$n_t] > $costo_tariffa_tot) $sconto[$n_t] = $costo_tariffa_tot;
@@ -590,82 +740,6 @@ if (!$caparra[$n_t] and $met_trovato == "NO") $mess_prenota .= "<br>";
 $mess_prenota .= mex("Commissioni","prenota.php").": <b>$commissioni_p</b> $Euro (".mex("resto commissioni","prenota.php").": $resto_comm_p $Euro).<br>";
 } # fine if ($commissioni[$n_t])
 
-
-# calcolo costi nulli, non letto e senza inventario da associare alla tariffa, tutti come se fossero "se possibile"
-if ($ins_costi_agg == "costi_nulli") {
-unset($num_letti_agg);
-unset($num_costi_presenti);
-$oggi_costo = date("Ymd",(time() + (C_DIFF_ORE * 3600)));
-for ($num_costo = 0 ; $num_costo < $dati_ca['num'] ; $num_costo++) {
-if (!$dati_ca[$num_costo]['valore'] and !$dati_ca[$num_costo]['valore_perc'] and $dati_ca[$num_costo]['letto'] != "s" and !$dati_ca[$num_costo]['tipo_beniinv']) {
-$associa_costo = "NO";
-$associa_costo_tariffa = associa_costo_a_tariffa($dati_ca,$num_costo,$tipotariffa[$n_t],($fineperiodo[$n_t] - $inizioperiodo[$n_t] + 1));
-if ($associa_costo_tariffa == "SI") $associa_costo = "SI";
-if ($associa_costo_tariffa != "SI" and !$dati_ca[$num_costo]["incomp_".$tipotariffa[$n_t]]) {
-if ($dati_ca[$num_costo]['assegna_con_num_prenota'] and count($inizioperiodo) >= $dati_ca[$num_costo]['assegna_con_num_prenota']) $associa_costo = "SI";
-if ($dati_ca[$num_costo]['assegna_da_ini_prenota']) {
-$giorni_lim = substr($dati_ca[$num_costo]['assegna_da_ini_prenota'],1);
-$limite = date("Ymd",mktime(0,0,0,substr($inizioperiodo_orig[$n_t],5,2),(substr($inizioperiodo_orig[$n_t],8,2) - $giorni_lim),substr($inizioperiodo_orig[$n_t],0,4)));
-if (substr($dati_ca[$num_costo]['assegna_da_ini_prenota'],0,1) == ">" and $oggi_costo < $limite) $associa_costo = "SI";
-if (substr($dati_ca[$num_costo]['assegna_da_ini_prenota'],0,1) == "<" and $oggi_costo > $limite) $associa_costo = "SI";
-} # fine if ($dati_ca[$num_costo][assegna_da_ini_prenota])
-} # fine if ($associa_costo_tariffa != "SI" and...
-if ($associa_costo == "SI") {
-#if ($dati_ca[$num_costo][tipo_val] == "q" and $costo_totale_presente = "SI") $associa_costo = "NO";
-$settimane_costo = calcola_settimane_costo($tableperiodi,$dati_ca,$num_costo,$inizioperiodo[$n_t],$fineperiodo[$n_t],"","");
-calcola_moltiplica_costo($dati_ca,$num_costo,$moltiplica,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo,"",$numpersone[$n_t],$num_letti_agg);
-$num_costi_presenti_copia = $num_costi_presenti;
-$periodo_costo_trovato = trova_periodo_permesso_costo($dati_ca,$num_costo,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo);
-if ($periodo_costo_trovato == "NO") $associa_costo = "NO";
-else if (controlla_num_limite_costo($tablecostiprenota,$tableprenota,$dati_ca,$num_costo,$num_costi_presenti_copia,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo,$moltiplica) == "NO") $associa_costo = "NO";
-
-if ($associa_costo == "SI") {
-$num_costi_presenti = $num_costi_presenti_copia;
-$idcostiprenota = esegui_query("select max(idcostiprenota) from $tablecostiprenota");
-$idcostiprenota = risul_query($idcostiprenota,0,0) + 1;
-$tipo_ca = $dati_ca[$num_costo]['tipo'].$dati_ca[$num_costo]['tipo_val'];
-$valore_ca = $dati_ca[$num_costo]['valore'];
-$valore_perc_ca = $dati_ca[$num_costo]['valore_perc'];
-$associasett_ca = $dati_ca[$num_costo]['associasett'];
-if ($dati_ca[$num_costo]['var_percentuale'] != "s" and $dati_ca[$num_costo]['tipo_val'] != "f") {
-$tipo_ca = $dati_ca[$num_costo]['tipo']."f";
-$moltiplica = 1;
-if ($dati_ca[$num_costo]['tipo'] == "s") {
-$settimane_costo = 1;
-$associasett_ca = "n";
-} # fine if ($dati_ca[$num_costo][tipo] == "s")
-} # fine if ($dati_ca[$num_costo][var_percentuale] != "s" and...
-if ($dati_ca[$num_costo]['var_moltiplica'] == "s") $varmoltiplica_ca = $dati_ca[$num_costo]['moltiplica'].$dati_ca[$num_costo]['molt_max'].$dati_ca[$num_costo]['molt_agg'].",".$dati_ca[$num_costo]['molt_max_num'];
-else $varmoltiplica_ca = "cx0,";
-if ($dati_ca[$num_costo]['var_numsett'] == "s") $varnumsett_ca = $dati_ca[$num_costo]['numsett_orig'];
-else $varnumsett_ca = "c";
-if ($dati_ca[$num_costo]['var_periodip'] == "s") $varperiodipermessi_ca = $dati_ca[$num_costo]['periodipermessi_orig'];
-else $varperiodipermessi_ca = "";
-$varbeniinv_ca = "";
-$varappincompatibili_ca = "";
-if ($dati_ca[$num_costo]['var_tariffea'] == "s") $vartariffeassociate_ca = "p".$dati_ca[$num_costo][$tipotariffa[$n_t]];
-else $vartariffeassociate_ca = "";
-$vartariffeincomp_ca = "";
-if ($dati_ca[$num_costo]['var_tariffei'] == "s") {
-for ($numtariffa = 1 ; $numtariffa <= $dati_tariffe['num'] ; $numtariffa++) {
-if ($dati_ca[$num_costo]["incomp_tariffa".$numtariffa] == "i") $vartariffeincomp_ca .= ",".$numtariffa;
-} # fine for $numtariffa
-if ($vartariffeincomp_ca) $vartariffeincomp_ca = substr($vartariffeincomp_ca,1);
-} # fine if ($dati_ca[$num_costo][var_tariffei] == "s")
-if ($dati_ca[$num_costo]['var_comb'] == "s") $variazione_ca = $dati_ca[$num_costo]['combina'];
-else $variazione_ca = "n";
-$variazione_ca .= $dati_ca[$num_costo]['escludi_tot_perc'];
-esegui_query("insert into $tablecostiprenota (idcostiprenota,idprenota,tipo,nome,valore,associasett,settimane,moltiplica,letto,idntariffe,variazione,varmoltiplica,varnumsett,varperiodipermessi,varbeniinv,varappincompatibili,vartariffeassociate,vartariffeincomp,datainserimento,hostinserimento,utente_inserimento) values ('$idcostiprenota','$idprenota','$tipo_ca','".aggslashdb($dati_ca[$num_costo]['nome'])."','$valore_ca','$associasett_ca','$settimane_costo','$moltiplica','".$dati_ca[$num_costo]['letto']."','".$dati_ca[$num_costo]['id']."','$variazione_ca','$varmoltiplica_ca','$varnumsett_ca','$varperiodipermessi_ca','$varbeniinv_ca','$varappincompatibili_ca','$vartariffeassociate_ca','$vartariffeincomp_ca','$datainserimento','$HOSTNAME','$id_utente_ins')");
-if (substr($tipo_ca,1,1) != "f") esegui_query("update $tablecostiprenota set valore_perc = '$valore_perc_ca', arrotonda = '".$dati_ca[$num_costo]['arrotonda']."' where idcostiprenota = '$idcostiprenota'");
-if ($dati_ca[$num_costo]['tasseperc']) esegui_query("update $tablecostiprenota set tasseperc = '".$dati_ca[$num_costo]['tasseperc']."' where idcostiprenota = '$idcostiprenota'");
-if (strcmp($dati_ca[$num_costo]['categoria'],"")) esegui_query("update $tablecostiprenota set categoria = '".$dati_ca[$num_costo]['categoria']."' where idcostiprenota = '$idcostiprenota'");
-} # fine if ($associa_costo == "SI")
-} # fine if ($associa_costo == "SI")
-} # fine if (!$dati_ca[$num_costo]['valore'] and !$dati_ca[$num_costo]['valore_perc'] and...
-} # fine for $num_costo
-} # fine if ($ins_costi_agg == "costi_nulli")
-
-
 if ($origine_prenota[$n_t] and $origini_prenota) {
 $orig_trovata = "NO";
 for ($num2 = 0 ; $num2 < count($origini_prenota) ; $num2++) {
