@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2011 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -35,16 +35,25 @@ $dati_tariffe['tariffa'.$num1]['caparra_percent'] = risul_query($righe_tariffe,1
 $dati_tariffe['tariffa'.$num1]['caparra_arrotond'] = risul_query($righe_tariffe,2,'tariffa'.$num1);
 $dati_tariffe['tariffa'.$num1]['moltiplica'] = risul_query($righe_tariffe,3,'tariffa'.$num1);
 $dati_tariffe['tariffa'.$num1]['tasse_percent'] = risul_query($righe_tariffe,4,'tariffa'.$num1);
-$importa_prezzi = risul_query($righe_tariffe,5,'tariffa'.$num1);
-if ($importa_prezzi) {
-$importa_prezzi = explode(";",$importa_prezzi);
-$dati_tariffe['tariffa'.$num1]['importa_prezzi'] = $importa_prezzi[0];
-$dati_tariffe['tariffa'.$num1]['parte_prezzo'] = $importa_prezzi[1];
-$dati_tariffe['tariffa'.$num1]['tipo_importa'] = $importa_prezzi[2];
-$dati_tariffe['tariffa'.$num1]['val_importa'] = $importa_prezzi[3];
-if ($importa_prezzi[2] == "p") $dati_tariffe['tariffa'.$num1]['arrotond_importa'] = $importa_prezzi[4];
-$dati_tariffe['tariffa'.$importa_prezzi[0]]['esporta_prezzi'] .= "$num1,";
-} # fine if ($importa_prezzi)
+$dati_tariffe['tariffa'.$num1]['imp_prezzi_int'] = risul_query($righe_tariffe,5,'tariffa'.$num1);
+if ($dati_tariffe['tariffa'.$num1]['imp_prezzi_int']) {
+$importa_prezzi_per = explode(">",$dati_tariffe['tariffa'.$num1]['imp_prezzi_int']);
+$dati_tariffe['tariffa'.$num1]['num_per_importa'] = count($importa_prezzi_per);
+for ($num2 = 0 ; $num2 < $dati_tariffe['tariffa'.$num1]['num_per_importa'] ; $num2++) {
+$importa_prezzi = explode(";",$importa_prezzi_per[$num2]);
+$dati_tariffe['tariffa'.$num1]['importa_prezzi'][$num2] = $importa_prezzi[0];
+$dati_tariffe['tariffa'.$num1]['parte_prezzo'][$num2] = $importa_prezzi[1];
+$dati_tariffe['tariffa'.$num1]['tipo_importa'][$num2] = $importa_prezzi[2];
+$dati_tariffe['tariffa'.$num1]['val_importa'][$num2] = $importa_prezzi[3];
+if ($importa_prezzi[2] == "p") $dati_tariffe['tariffa'.$num1]['arrotond_importa'][$num2] = $importa_prezzi[4];
+if ($importa_prezzi[5]) {
+$per_imp = explode("-",$importa_prezzi[5]);
+$dati_tariffe['tariffa'.$num1]['periodo_importa_i'][$num2] = $per_imp[0];
+$dati_tariffe['tariffa'.$num1]['periodo_importa_f'][$num2] = $per_imp[1];
+} # fine if ($importa_prezzi[5])
+if (!strstr(",".$dati_tariffe['tariffa'.$importa_prezzi[0]]['esporta_prezzi'],",$num1,")) $dati_tariffe['tariffa'.$importa_prezzi[0]]['esporta_prezzi'] .= "$num1,";
+} # fine for $num2
+} # fine if ($dati_tariffe['tariffa'.$num1]['imp_prezzi_int'])
 } # fine if (!$tariffa_sel or $tariffa_sel == $num1)
 } # fine for $num1
 
@@ -97,46 +106,6 @@ return $dati_tariffe;
 
 
 
-# Vecchia funzione (rimuoverla quando non è più usata da nessuna parte), da ripiazzare con dati_regole2
-function trova_app_regola2 ($tipotariffa,&$regole2,&$num_regole2,&$app_regola2_predef,&$id_periodo_corrente,$idinizioperiodo,$idfineperiodo,$tipo_periodi,$anno,$tableregole) {
-
-$app_regola2_predef = "";
-if (!$regole2) {
-$regole2 = esegui_query("select * from $tableregole where tariffa_per_app != ''");
-$num_regole2 = numlin_query($regole2);
-} # fine if (!$regole2)
-
-for ($num1 = 0 ; $num1 < $num_regole2 ; $num1 = $num1 + 1) {
-$tariffa_regola2 = risul_query($regole2,$num1,'tariffa_per_app');
-if ($tipotariffa == $tariffa_regola2) {
-$lista_app = risul_query($regole2,$num1,'motivazione');
-$lista_appb = risul_query($regole2,$num1,'motivazione2');
-if (strcmp($lista_appb,"")) {
-if (!$id_periodo_corrente) $id_periodo_corrente = calcola_id_periodo_corrente($anno);
-$ngiorni_reg2b = risul_query($regole2,$num1,'iddatainizio');
-if ($ngiorni_reg2b) $diff_giorni = $idinizioperiodo - $id_periodo_corrente + 1;
-else {
-$ngiorni_reg2b = risul_query($regole2,$num1,'iddatafine');
-$diff_giorni = $idfineperiodo - $id_periodo_corrente + 1;
-} # fine else if ($ngiorni_reg2b)
-if ($tipo_periodi == "s") $diff_giorni = $diff_giorni * 7;
-if ($diff_giorni < $ngiorni_reg2b) {
-$app_regola2_predef = $lista_app;
-$lista_app = $lista_appb;
-} # fine if ($diff_giorni < $ngiorni_reg2b)
-} # fine if (strcmp($lista_appb,""))
-break;
-} # fine if ($tipotariffa == $tariffa_regola2)
-} # fine for $num1
-
-return $lista_app;
-
-} # fine function trova_app_regola2
-
-
-
-
-# Nuova funzione alternativa a trova_app_regola2
 function dati_regole2 (&$dati_r2,&$app_regola2_predef,$tipotariffa,$idinizioperiodo,$idfineperiodo,&$id_periodo_corrente,$tipo_periodi,$anno,$tableregole) {
 
 if (!is_array($dati_r2)) {
@@ -330,70 +299,86 @@ esegui_query("update $tablenometariffe set $tariffa = '$opztariffa' where idntar
 } # fine if ($idperiodo == "opztariffa")
 else {
 
-$importa_percent = (double) $dati_tariffe[$tariffa]['val_importa'];
-$importa_arrotond = (double) $dati_tariffe[$tariffa]['arrotond_importa'];
-$tipo_percent = $dati_tariffe[$tariffa]['tipo_importa'];
-if ($tipo_percent == "s" and !$agg_vett[$tariffa]) {
+$num_ord_prec = -1;
+if (!$agg_vett[$tariffa]) $agg_vett[$tariffa] = array();
+for ($num1 = $ini_per ; $num1 <= $fine_per ; $num1++) {
+
+$num_ord = 0;
+for ($num2 = 1 ; $num2 < $dati_tariffe[$tariffa]['num_per_importa'] ; $num2++) {
+if ("tariffa".$dati_tariffe[$tariffa]['importa_prezzi'][$num2] == $tariffa_da and $dati_tariffe[$tariffa]['periodo_importa_f'][$num2] >= $num1 and $dati_tariffe[$tariffa]['periodo_importa_i'][$num2] <= $num1) {
+$num_ord = $num2;
+break;
+} # fine if ("tariffa".$dati_tariffe[$tariffa]['importa_prezzi'][$num2] == $tariffa_da and...
+} # fine for $num2
+if ($num_ord > 0 or "tariffa".$dati_tariffe[$tariffa]['importa_prezzi'][0] == $tariffa_da) {
+
+if ($num_ord != $num_ord_prec) {
+$importa_percent = (double) $dati_tariffe[$tariffa]['val_importa'][$num_ord];
+$importa_arrotond = (double) $dati_tariffe[$tariffa]['arrotond_importa'][$num_ord];
+$tipo_percent = $dati_tariffe[$tariffa]['tipo_importa'][$num_ord];
+if ($tipo_percent == "s" and !$agg_vett[$tariffa][$num_ord]) {
 $agg_int = floor($importa_percent);
 $resto_int = $importa_percent - (double) $agg_int;
 $agg_gio = floor($agg_int / 7);
-for ($num1 = 1 ; $num1 <= 7 ; $num1++) $agg_vett[$tariffa][$num1] = $agg_gio;
+for ($num2 = 1 ; $num2 <= 7 ; $num2++) $agg_vett[$tariffa][$num_ord][$num2] = $agg_gio;
 $resto = $agg_int - ($agg_gio * 7);
 if ($resto >= 1) {
-$agg_vett[$tariffa][1]++;
+$agg_vett[$tariffa][$num_ord][1]++;
 $resto--;
 } # fine if ($resto >= 1)
-for ($num1 = 7 ; $num1 > (7 - $resto) ; $num1--) $agg_vett[$tariffa][$num1]++;
-$agg_vett[$tariffa][1] += $resto_int;
-$num_agg[$tariffa]['s'] = 0;
-$num_agg[$tariffa]['p'] = 0;
-} # fine if ($tipo_percent == "s" and !$agg_vett[$tariffa])
+for ($num2 = 7 ; $num2 > (7 - $resto) ; $num2--) $agg_vett[$tariffa][$num_ord][$num2]++;
+$agg_vett[$tariffa][$num_ord][1] += $resto_int;
+$num_agg[$tariffa][$num_ord]['s'] = 0;
+$num_agg[$tariffa][$num_ord]['p'] = 0;
+} # fine if ($tipo_percent == "s" and !$agg_vett[$tariffa][$num_ord])
 if ($tipo_percent == "g") $perc = $importa_percent;
-
-for ($num1 = $ini_per ; $num1 <= $fine_per ; $num1++) {
+} # fine if ($num_ord != $num_ord_prec)
 
 if ((string) $prezzoperiodo != "NO") {
 if ($tipo_percent == "s") {
-$num_agg[$tariffa]['s']++;
-$perc = $agg_vett[$tariffa][$num_agg[$tariffa]['s']];
-if ($num_agg[$tariffa]['s'] == 7) $num_agg[$tariffa]['s'] = 0;
+$num_agg[$tariffa][$num_ord]['s']++;
+$perc = $agg_vett[$tariffa][$num_ord][$num_agg[$tariffa][$num_ord]['s']];
+if ($num_agg[$tariffa][$num_ord]['s'] == 7) $num_agg[$tariffa][$num_ord]['s'] = 0;
 } # fine if ($tipo_percent == "s")
 
 $prezzo_a = (double) $prezzoperiodo;
-if ($dati_tariffe[$tariffa]['parte_prezzo'] != "p") {
+if ($dati_tariffe[$tariffa]['parte_prezzo'][$num_ord] != "p") {
 if ($tipo_percent == "p") $perc = (double) (($prezzo_a / 100.0) * $importa_percent);
 if ($perc) {
 if ($tipo_percent == "p") $perc = (round(($perc / $importa_arrotond),0) * $importa_arrotond);
 $prezzo_a = $prezzo_a + $perc;
 } # fine if ($perc)
-} # fine if ($dati_tariffe[$tariffa]['parte_prezzo'] != "p")
+} # fine if ($dati_tariffe[$tariffa]['parte_prezzo'][$num_ord] != "p")
 if ($prezzo_a) esegui_query("update $tableperiodi set $tariffa = '$prezzo_a' where idperiodi = '$num1'");
 else esegui_query("update $tableperiodi set $tariffa = NULL where idperiodi = '$num1'");
 } # fine if ((string) $prezzoperiodo != "NO")
 
 if ((string) $prezzoperiodop != "NO") {
 if ($tipo_percent == "s") {
-$num_agg[$tariffa]['p']++;
-$perc = $agg_vett[$tariffa][$num_agg[$tariffa]['p']];
-if ($num_agg[$tariffa]['p'] == 7) $num_agg[$tariffa]['p'] = 0;
+$num_agg[$tariffa][$num_ord]['p']++;
+$perc = $agg_vett[$tariffa][$num_ord][$num_agg[$tariffa][$num_ord]['p']];
+if ($num_agg[$tariffa][$num_ord]['p'] == 7) $num_agg[$tariffa][$num_ord]['p'] = 0;
 } # fine if ($tipo_percent == "s")
 
 $prezzo_a_p = (double) $prezzoperiodop;
-if ($dati_tariffe[$tariffa]['parte_prezzo'] != "f") {
+if ($dati_tariffe[$tariffa]['parte_prezzo'][$num_ord] != "f") {
 if ($tipo_percent == "p") $perc = (double) (($prezzo_a_p / 100.0) * $importa_percent);
 if ($perc) {
 if ($tipo_percent == "p") $perc = (round(($perc / $importa_arrotond),0) * $importa_arrotond);
 $prezzo_a_p = $prezzo_a_p + $perc;
 } # fine if ($perc)
-} # fine if ($dati_tariffe[$tariffa]['parte_prezzo'] != "f")
+} # fine if ($dati_tariffe[$tariffa]['parte_prezzo'][$num_ord] != "f")
 if ($prezzo_a_p) esegui_query("update $tableperiodi set $tariffa"."p = '$prezzo_a_p' where idperiodi = '$num1'");
 else esegui_query("update $tableperiodi set $tariffa"."p = NULL where idperiodi = '$num1'");
 } # fine if ((string) $prezzoperiodop != "NO")
 
+$num_ord_prec = $num_ord;
+} # fine if ($num_ord > 0 or "tariffa".$dati_tariffe[$tariffa]['importa_prezzi'][0] == $tariffa_da)
 } # fine for $num1
 } # fine else if ($idperiodo == "opztariffa")
 } # fine for $num_tar
 } # fine if ($dati_tariffe[$tipotariffa]['esporta_prezzi'])
+
 } # fine function aggiorna_tariffe_esporta
 
 
