@@ -35,6 +35,8 @@ $t1dropin = "#05e105";
 $t1dropout = "#297929";
 
 
+if ($pag == "punto_vendita.php") $iscale = "0.8";
+else $iscale = "1.0";
 if (C_NASCONDI_MARCA == "SI") $titolo = "";
 if (defined('C_FILE_TITOLO_PERS') and C_FILE_TITOLO_PERS != "" and @is_file(C_FILE_TITOLO_PERS)) $titolo = trim(substr(implode("",file(C_FILE_TITOLO_PERS)),0,40))." - $titolo";
 echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
@@ -42,7 +44,7 @@ echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
 <html>
 <head>
 <meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\" >
-<meta name=\"viewport\" content=\"initial-scale=1.0\">
+<meta name=\"viewport\" content=\"initial-scale=$iscale\">
 <title> $titolo </title>";
 if ($pag == "visualizza_contratto.php" and $extra_head) echo $extra_head;
 if (defined('C_URL_FAVICON') and C_URL_FAVICON != "" and @is_file(C_URL_FAVICON)) echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"".C_URL_FAVICON."\">
