@@ -318,6 +318,8 @@ case "Codice promozionale applicato":  		$messaggio = "Promotional code applied"
 case "alcuni costi aggiuntivi con codice promozionale":	$messaggio = "some extra costs with promotional code"; break;
 case "non sono associati a tariffe, alcune loro caratteristiche potrebbero venir modificate se non compatibili":	$messaggio = "are not associated to any rate, some of their characteristics may be altered if not compatible"; break;
 case "Mostrare le date passate?":  		$messaggio = "Show past dates?"; break;
+case "titolo html":  				$messaggio = "html title"; break;
+case "titolo":  				$messaggio = "title"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
