@@ -51,6 +51,9 @@ case "configura e personalizza":		$messaggio = "configure and customize"; break;
 case "per cambiare il nome della valuta, abilitare la registrazione delle entrate, inserire i metodi di pagamento, ed impostare molte altre opzioni":	$messaggio = "page to change currency name, enable registration of check-in, insert payment methods, and set up much more options"; break;
 case "Inserisci il numero di tariffe, un nome per ciascuna di esse ed i prezzi corrispondenti dalla":	$messaggio = "Insert the number of rates, a name for each one of them and the corresponding prices from the"; break;
 case "questo programma":			$messaggio = "this program"; break;
+case "Nome delle unità singole da gestire":	$messaggio = "Name of single units to be managed"; break;
+case "Numero di unità singole da gestire":	$messaggio = "Number of single units to be managed"; break;
+case "non incluse nelle unità normali":		$messaggio = "not included in normal units"; break;
 case "":			$messaggio = ""; break;
 case "":			$messaggio = ""; break;
 
