@@ -57,6 +57,11 @@ case "privilegi e personalizzazioni":  		$messaggio = "privileges and customizat
 case "solo i privilegi":  			$messaggio = "only privileges"; break;
 case "solo le personalizzazioni":  		$messaggio = "only customizations"; break;
 case "Personalizzazioni importate":  		$messaggio = "Customizations imported"; break;
+case "privilegi, personalizzazioni e gruppi":	$messaggio = "privileges, customizations and groups"; break;
+case "privilegi e gruppi":  			$messaggio = "privileges and groups"; break;
+case "personalizzazioni e gruppi":  		$messaggio = "customizations and groups"; break;
+case "solo i gruppi":  				$messaggio = "only groups"; break;
+case "Gruppi importati":  			$messaggio = "Groups imported"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
