@@ -146,6 +146,9 @@ case "Il campo":  				$messaggio = "The field"; break;
 case "verrà tolto":  				$messaggio = "will be deleted"; break;
 case "verrà modificato":  			$messaggio = "will be modified"; break;
 case "verrà aggiunto":  			$messaggio = "will be added"; break;
+case "scaduta":  				$messaggio = "expired"; break;
+case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "You'll be able to view credit cards again after changing the password"; break;
+case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "You'll be able to view credit cards again after the administrator user changes the password"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
