@@ -401,6 +401,8 @@ case "Attenzione":  				$messaggio = "Warning"; break;
 case "i link per l'esportazione dei calendari in formato ical sono cambiati, ricordarsi di aggiornarli sui calendari esterni":	$messaggio = "the links to export calendars in ical format have changed, remember to update them on external calendars"; break;
 case "La tariffa":  				$messaggio = "Rate"; break;
 case "è ancora in uso nelle interconnessioni":	$messaggio = "is still in use in interconnections"; break;
+case "almeno 8 caratteri, con lettere e numeri o simboli":	$messaggio = "at least 8 characters, with letters and numbers or symbols"; break;
+case "diversa dalle ultime":  			$messaggio = "different from last"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
