@@ -344,6 +344,11 @@ case "non potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$me
 case "Creazione e modifica delle interconnessioni":	$messaggio = "Create and modify interconnections"; break;
 case "potrà creare e modificare le <b>interconnessioni</b>":	$messaggio = "will be able to create and modify <b>interconnections</b>"; break;
 case "non potrà più creare e modificare le <b>interconnessioni</b>":	$messaggio = "will not be able to create and modify <b>interconnections</b>"; break;
+case "Modifica dei documenti come API":  	$messaggio = "Modify documents as API"; break;
+case "potrà modificare i <b>documenti come API</b>":	$messaggio = "will be able to modify <b>documents as API</b>"; break;
+case "Attenzione":  				$messaggio = "Warning"; break;
+case "questo può consentire l'accesso ai dati di tutte le prenotazioni":	$messaggio = "this can allow access to data of all reservations"; break;
+case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "will not be able to modify <b>documents as API</b> anymore"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
