@@ -318,6 +318,8 @@ case "Codice promozionale applicato":  		$messaggio = "Código promicional aplic
 case "alcuni costi aggiuntivi con codice promozionale":	$messaggio = "algunos costes añadidos con código promicional"; break;
 case "non sono associati a tariffe, alcune loro caratteristiche potrebbero venir modificate se non compatibili":	$messaggio = "no están asociados a tarifas, algunas de sus características podrían ser modificadas si no son compatibles"; break;
 case "Mostrare le date passate?":  		$messaggio = "Enseñar las fechas pasadas?"; break;
+case "titolo html":  				$messaggio = "Título html"; break;
+case "titolo":  				$messaggio = "Título"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
