@@ -35,7 +35,7 @@ case "Inserisci o modifica i prezzi":  		$messaggio = "Insertar o modificar los
 case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Insertar o modificar las reglas de asignación"; break;
 case "Configura e personalizza":	$messaggio = "Configurar y personalizar"; break;
 case "richiedi l'anno":  			$messaggio = "Ir al año"; break;
-case "vai":  					$messaggio = "vé"; break;
+case "vai":  					$messaggio = "ir"; break;
 case "Non esiste l'anno ":  			$messaggio = "No existe el año "; break;
 case " nel database":  				$messaggio = " en la base de datos"; break;
 case "Crea l'anno":  				$messaggio = "Crear el año"; break;
@@ -122,6 +122,11 @@ case "Benvenuto a HOTELDRUID":  		$messaggio = "Bienvenido a HOTELDRUID"; break;
 case "Scegli la lingua":  			$messaggio = "Escoger el idioma"; break;
 case "crea il database":  			$messaggio = "crear la base de datos"; break;
 case "Promemoria":  				$messaggio = "Recordatorio"; break;
+case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "Este usuario no tiene los privilegios para crear nuevos años"; break;
+case "Avviso":  				$messaggio = "Aviso"; break;
+case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "el la base de datos hay todavía disponibles períodos solo por menos de"; break;
+case "mesi":  					$messaggio = "meses"; break;
+case "OK, ho capito":  				$messaggio = "OK, entendido"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
