@@ -6,11 +6,11 @@ case "Aggiornamento eseguito con successo":  	$messaggio = "Actualización ejecu
 case "Non si è potuto portare a termine l'<div style=\"display: inline; color: red;\">aggiornamento</div>":	$messaggio = "No se ha podido llevar a cabo la <div style=\"display: inline; color: red;\">actualización</div>"; break;
 case "OK":  					$messaggio = "OK"; break;
 case "<div style=\"display: inline; color: red;\"><b>ATTENZIONE</b></div>: premendo su <b>\"<i>Continua</i>\"</b> tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>":	$messaggio = "<div style=\"display: inline; color: red;\"><b>ATENCION</b></div>: al pulsar <b>\"<i>Continua</i>\"</b> todos los datos de la <i>actual base de datos</i> serán <b>borrados</b>"; break;
-case "Continua":  				$messaggio = "Continua"; break;
+case "Continua":  				$messaggio = "Continuar"; break;
 case "Subordinazione creata":  			$messaggio = "Subordinación creada"; break;
 case "Impossibile effettuare il collegamento, controllare i dati immessi":	$messaggio = "Imposible efectuar la conexión, controlar los datos insertados"; break;
 case "Subordinazione cancellata":  		$messaggio = "Subordinación eliminada"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Interconnessioni con sorgenti esterne di dati":	$messaggio = "Interconexiones con fuentes exteriores de datos"; break;
 case "Cancella":  				$messaggio = "Elimina"; break;
 case "la subordinazione":  			$messaggio = "la subordinación"; break;
@@ -19,7 +19,7 @@ case "Con la subordinazione non si potranno inserire nuovi dati o apportare modi
 case "Subordina questa installazione di hoteldruid a quella che si trova all'indirizzo":	$messaggio = "Subordina esta instalación de hoteldruid a la que se encuentra a la dirección"; break;
 case "Password":  				$messaggio = "Contraseña"; break;
 case "Commento da aggiungere al titolo di questa installazione":	$messaggio = "Comentario a añadir a esta instalación"; break;
-case "Crea la subordinazione":  		$messaggio = "Crea la subordinación"; break;
+case "Crea la subordinazione":  		$messaggio = "Crear la subordinación"; break;
 case "Usa compressione":  			$messaggio = "Utilizar compresión"; break;
 case "Utente per l'aggiornamento remoto delle interconnessioni":	$messaggio = "Usuario para la actualización remota de las interconexiones"; break;
 case "Utente per l'aggiornamento remoto modificato":	$messaggio = "Usuario para la actualización remota modificado"; break;
@@ -33,6 +33,9 @@ case "Non si è potuto stabilire la connessione":	$messaggio = "No se ha podido
 case "Non ho i permassi di scrittura sulla cartella dati":	$messaggio = "No tengo los permisos para escribir en el directorio dati"; break;
 case "Prova a mantenere i dati degli anni non presenti nell'installazione remota":	$messaggio = "Intentar mantener los datos de los años no presentes en la instalación remota"; break;
 case "nella pagina delle interconnessioni":  	$messaggio = "en la página de las interconexiones"; break;
+case "Modifica la regola di assegnazione":  	$messaggio = "Modificar la regla de asignación"; break;
+case "La prenotazione cancellata non era presente nel database":	$messaggio = "La reserva borrada no estaba presente en la base de datos"; break;
+case "gruppo":  				$messaggio = "grupo"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
