@@ -8,7 +8,7 @@ case "Quantità minima predefinita":  		$messaggio = "Cantidad mínima predefini
 case "Quantità attuale":  			$messaggio = "Cantidad actual"; break;
 case "Nuova quantità":  			$messaggio = "Nueva cantidad"; break;
 case "Modifica":  				$messaggio = "Modificar"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Modifica le quantità attuali":  		$messaggio = "Modificar las cantidades actuales"; break;
 case "aggiungi":  				$messaggio = "añadir"; break;
 case "cancella":  				$messaggio = "borrar"; break;
@@ -29,7 +29,7 @@ case "da":  					$messaggio = "desde"; break;
 case "magazzino":  				$messaggio = "almacén"; break;
 case "Nessun posto da cui ricaricare":  	$messaggio = "Ningún sitio desde donde recargar"; break;
 case "mancanti":  				$messaggio = "faltantes"; break;
-case "Continua":  				$messaggio = "Continua"; break;
+case "Continua":  				$messaggio = "Continuar"; break;
 case "richiesto_per registrare entrata":  	$messaggio = "necesario_para registrar entrada"; break;
 case "si":  					$messaggio = "si"; break;
 case "no":  					$messaggio = "no"; break;
