@@ -5,7 +5,7 @@ switch ($messaggio) {
 case "contiene prenotazione future, non si può cancellare":	$messaggio = "contiene reservas futuras, no se puede borrar"; break;
 case "SI":  					$messaggio = "SI"; break;
 case "NO":  					$messaggio = "NO"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "La casa verrà cambiata da":  		$messaggio = "La casa será cambiada de"; break;
 case "a":  					$messaggio = "a"; break;
 case "Il piano verrà cambiato da":  		$messaggio = "El piso será cambiado de"; break;
