@@ -86,6 +86,31 @@ case "Estensione con cui vedere e scaricare il documento":	$messaggio = "Extensi
 case "predefinita":  				$messaggio = "predefinida"; break;
 case "personalizzata":  			$messaggio = "personalizada"; break;
 case "Estensione cambiata":  			$messaggio = "Extensión cambiada"; break;
+case "Considera questo documento come una API":	$messaggio = "Considerar este documento como una API"; break;
+case "Il documento verrà considerato come una API":	$messaggio = "El documento será considerado como una API"; break;
+case "Il documento non verrà più considerato come una API":	$messaggio = "El documento ya no será considerado como una API"; break;
+case "Password":  				$messaggio = "Contraseña"; break;
+case "La password per la API del documento è stata cambiata":	$messaggio = "La contraseña para la API del documento ha sido cambiada"; break;
+case "Esempi di URL per chiamare il documento":	$messaggio = "Ejemplos de URL para llamar al documento"; break;
+case "Tutte le prenotazioni dell'anno":  	$messaggio = "Todas las reservas del año"; break;
+case "Mostra il documento come visto dall'utente":	$messaggio = "Enseñar el documento como visto por el usuario"; break;
+case "L'utente per la API del documento è stato cambiato":	$messaggio = "El usuario para la API del documento ha sido cambiado"; break;
+case "Notar":  					$messaggio = "Notar"; break;
+case "se la variabile":  			$messaggio = "si la variable"; break;
+case "non è presente nella URL allora verranno usate le prenotazioni dell'anno corrente":	$messaggio = "no está presente en la URL entonces se usarán las reservs del año corriente"; break;
+case "Tutte le prenotazioni presenti dal":  	$messaggio = "Todas las reservas presentes desde el"; break;
+case "al":  					$messaggio = "hasta el"; break;
+case "si possono usare anche le parole":  	$messaggio = "se pueden usar también las palabras"; break;
+case "come date":  				$messaggio = "como fechas"; break;
+case "e":  					$messaggio = "y"; break;
+case "Tutte le prenotazioni con numero dal":  	$messaggio = "Todas las reservas con números desde el"; break;
+case "Altri esempi dell'uso della variabile":  	$messaggio = "Otros ejemplos del uso de la variable"; break;
+case "Tutte le prenotazioni inserite dal":  	$messaggio = "Todas las reservas insertadas desde el"; break;
+case "Tutti gli arrivi del":  			$messaggio = "Todas las llegadas del"; break;
+case "Tutti le partenze del":  			$messaggio = "Todas las salidas del"; break;
+case "Tutti i clienti":  			$messaggio = "Todos los clientes"; break;
+case "escludendo gli ospiti":  			$messaggio = "excluyendo a los huéspdes"; break;
+case "inclusi gli ospiti":  			$messaggio = "incluidos los huéspdes"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
