@@ -2,8 +2,8 @@
 
 switch ($messaggio) {
 
-case "Modifica il costo aggiuntivo":  		$messaggio = "Modifica el coste añadido"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Modifica il costo aggiuntivo":  		$messaggio = "Modificar el coste añadido"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "tariffa":  				$messaggio = "tarifa"; break;
 case "Nome":  					$messaggio = "Nombre"; break;
 case "Cambia in":  				$messaggio = "Cambia a"; break;
