@@ -19,8 +19,8 @@ case "anno con 4 cifre":  			$messaggio = "año con 4 cifras"; break;
 case "Documento":  				$messaggio = "Documento"; break;
 case "scadenza":  				$messaggio = "expiración"; break;
 case "Altri ospiti":  				$messaggio = "Otros huéspedes"; break;
-case "Modifica gli ospiti":  			$messaggio = "Modifica los huéspedes"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Modifica gli ospiti":  			$messaggio = "Modificar los huéspedes"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Gli ospiti della prenotazione":  		$messaggio = "Los huéspedes de la reserva"; break;
 case "sono stati modificati":  			$messaggio = "han sido modificados"; break;
 case "nato":  					$messaggio = "nacido"; break;
