@@ -401,6 +401,8 @@ case "Attenzione":  				$messaggio = "Atención"; break;
 case "i link per l'esportazione dei calendari in formato ical sono cambiati, ricordarsi di aggiornarli sui calendari esterni":	$messaggio = "los enlaces para la exportación de los calendarios en formato ical han cambiado, recordarse de actualizarlos en los calendarios externos"; break;
 case "La tariffa":  				$messaggio = "La tarifa"; break;
 case "è ancora in uso nelle interconnessioni":	$messaggio = "está siendo todavía utilizada en las interconexiones"; break;
+case "almeno 8 caratteri, con lettere e numeri o simboli":	$messaggio = "por lo menos 8 caracteres, con letras y números o símbulos"; break;
+case "diversa dalle ultime":  			$messaggio = "distinta de las últimas"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
