@@ -2,7 +2,7 @@
 
 switch ($messaggio) {
 
-case "Inserisci una nuova prenotazione":  	$messaggio = "Inserta una nueva reserva"; break;
+case "Inserisci una nuova prenotazione":  	$messaggio = "Insertar una nueva reserva"; break;
 case "Cliente titolare":  			$messaggio = "Cliente titular"; break;
 case "cognome":  				$messaggio = "apellido"; break;
 case "nome":  					$messaggio = "nombre"; break;
@@ -25,8 +25,8 @@ case "costo aggiuntivo giornaliero":  		$messaggio = "coste añadido diario"; br
 case "nº di settimane da applicare":  		$messaggio = "nº de semanas a aplicar"; break;
 case "nº di giorni da applicare":  		$messaggio = "nº de días a aplicar"; break;
 case "Commento":  				$messaggio = "Comentario"; break;
-case "Inserisci la prenotazione":  		$messaggio = "Inserta la reserva"; break;
-case "Torna al menù principale":  		$messaggio = "Vuelve al menú principal"; break;
+case "Inserisci la prenotazione":  		$messaggio = "Insertar la reserva"; break;
+case "Torna al menù principale":  		$messaggio = "Volver al menú principal"; break;
 case " o spezzarla":  				$messaggio = " o dividirla"; break;
 case "Spezza la prenotazione in":  		$messaggio = "Divide la reserva en"; break;
 case "parti":  					$messaggio = "trozos"; break;
@@ -58,14 +58,14 @@ case "Caparra":  				$messaggio = "Fianza"; break;
 case "resto da pagare":  			$messaggio = "resto a pagar"; break;
 case "Commento":  				$messaggio = "Comentario"; break;
 case "inserita":  				$messaggio = "insertada"; break;
-case "Modifica la prenotazione":  		$messaggio = "Modifica la reserva"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Modifica la prenotazione":  		$messaggio = "Modificar la reserva"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Sconto":  				$messaggio = "Descuento"; break;
 case "É necessario inserire il cognome del cliente":	$messaggio = "Es necesario insertar el apellido del cliente"; break;
 case "confermata":  				$messaggio = "confirmada"; break;
 case "Confermata":  				$messaggio = "Confirmada"; break;
 case "Nº di prenotazioni di questa tipologia":	$messaggio = "Nº de reservas de esta tipología"; break;
-case "Aggiungi altre tipologie":  		$messaggio = "Añade otras tipologías"; break;
+case "Aggiungi altre tipologie":  		$messaggio = "Añadir otras tipologías"; break;
 case "Tipologia":  				$messaggio = "Tipología"; break;
 case "Nessuna nuova prenotazione è stata inserita":	$messaggio = "Ninguna nueva reserva ha sido insertada"; break;
 case "Transazione scaduta":  			$messaggio = "Transacción caducada"; break;
@@ -81,7 +81,7 @@ case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione"
 case "Origine":  				$messaggio = "Origen"; break;
 case "<b>Attenzione</b>: il prezzo totale":  	$messaggio = "<b>Atención</b>: el precio total"; break;
 case "non coincide con il prezzo remoto":  	$messaggio = "no coincide con el precio remoto"; break;
-case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modifica como grupo las reservas insertadas"; break;
+case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modificar como grupo las reservas insertadas"; break;
 case "prezzo totale":  				$messaggio = "precio total"; break;
 case "prezzo totale giornaliero":  		$messaggio = "precio total diario"; break;
 case "prezzo totale settimanale":  		$messaggio = "precio total semanal"; break;
