@@ -344,6 +344,11 @@ case "non potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$me
 case "Creazione e modifica delle interconnessioni":	$messaggio = "Creación y modificación de las interconexiones"; break;
 case "potrà creare e modificare le <b>interconnessioni</b>":	$messaggio = "podrá crear y modificar las <b>interconexiones</b>"; break;
 case "non potrà più creare e modificare le <b>interconnessioni</b>":	$messaggio = "ya no podrá crear y modificar las <b>interconexiones</b>"; break;
+case "Modifica dei documenti come API":  	$messaggio = "Modificar documentos como API"; break;
+case "potrà modificare i <b>documenti come API</b>":	$messaggio = "podrá modificar los <b>documentos como API</b>"; break;
+case "Attenzione":  				$messaggio = "Atención"; break;
+case "questo può consentire l'accesso ai dati di tutte le prenotazioni":	$messaggio = "esto podrá dar acceso a los datos de todas las reservas"; break;
+case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "ya no podrá modificar los <b>documentos como API</b>"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
