@@ -6,9 +6,9 @@ case "situazione alle":  			$messaggio = "situación a las"; break;
 case "del":  					$messaggio = "del"; break;
 case "Tabella prenotazioni del":  		$messaggio = "Tabla de reservas del"; break;
 case "ERRORE":  				$messaggio = "ERROR"; break;
-case "Torna al menù principale":  		$messaggio = "Vuelve al menú principal"; break;
-case "Visualizza la tabella per la stampa":  	$messaggio = "Mira la tabla para imprimir"; break;
-case "Visualizza la tabella con i giorni":  	$messaggio = "Mira la tabla con los días"; break;
+case "Torna al menù principale":  		$messaggio = "Volver al menú principal"; break;
+case "Visualizza la tabella per la stampa":  	$messaggio = "Ver la tabla para imprimir"; break;
+case "Visualizza la tabella con i giorni":  	$messaggio = "Ver la tabla con los días"; break;
 case "documento di tipo":  			$messaggio = "documento tipo"; break;
 case "visualizza":  				$messaggio = "Ver"; break;
 case "Prenotazione non confermata":  		$messaggio = "Reserva no confirmada"; break;
