@@ -201,7 +201,7 @@ case "associato_a_settimane_specifiche":  	$messaggio = "asociado_a_semanas_espe
 case "non_associato_a_settimane_specifiche":  	$messaggio = "no_asociado_a_semanas_específicas"; break;
 case "associato_a_giorni_specifici":  		$messaggio = "asociado_a_días_específicos"; break;
 case "non_associato_a_giorni_specifici":  	$messaggio = "no_asociado_a_días_específicos"; break;
-case "modifica con prenotazione":  		$messaggio = "modifica con reserva"; break;
+case "modifica con prenotazione":  		$messaggio = "modificar con reserva"; break;
 case "percentuale su caparra":  		$messaggio = "porcentaje de la fianza"; break;
 case "percentuale su resto caparra":  		$messaggio = "porcentaje del resto de la fianza"; break;
 case "Cancellati":  				$messaggio = "Borrados"; break;
