@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -56,13 +56,33 @@ $limiti_var['lim_prenota_temp'] = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 360
 if (!$dati_app) {
 $idapp = esegui_query("select idappartamenti,maxoccupanti,app_vicini from $tableappartamenti order by priorita");
 $numappartamenti = numlin_query($idapp);
+$grp_vicini = array();
 for ($num1 = 0 ; $num1 < $numappartamenti ; $num1++) {
 $numapp = risul_query($idapp,$num1,'idappartamenti');
 $maxocc = risul_query($idapp,$num1,'maxoccupanti');
 $dati_app['posizione'][$num1] = $numapp;
 $dati_app['maxocc'][$numapp] = $maxocc;
 $dati_app['vicini'][$numapp] = risul_query($idapp,$num1,'app_vicini');
-if ($dati_app['vicini'][$numapp]) $dati_app['vicini'][$numapp] .= ",$numapp";
+if ($dati_app['vicini'][$numapp]) {
+$dati_app['vicini'][$numapp] .= ",$numapp";
+$gruppo_corr = -1;
+$lst_vicini = explode(",",$dati_app['vicini'][$numapp]);
+for ($num2 = 0 ; $num2 < count($grp_vicini) ; $num2++) {
+for ($num3 = 0 ; $num3 < count($lst_vicini) ; $num3++) {
+if (strstr(",".$grp_vicini[$num2].",",",".$lst_vicini[$num3].",")) {
+if ($gruppo_corr < 0) {
+$gruppo_corr = $num2;
+$grp_vicini[$num2] .= ",".$dati_app['vicini'][$numapp];
+} # fine if ($gruppo_corr < 0)
+elseif ($gruppo_corr != $num2) {
+$grp_vicini[$gruppo_corr] .= ",".$grp_vicini[$num2];
+$grp_vicini[$num2] = "";
+} # fine elseif ($gruppo_corr != $num2)
+} # fine if (strstr(",".$grp_vicini[$num2].",",",".$lst_vicini[$num3].","))
+} # fine for $num3
+} # fine for $num2
+if ($gruppo_corr < 0) $grp_vicini[count($grp_vicini)] = $dati_app['vicini'][$numapp];
+} # fine if ($dati_app['vicini'][$numapp])
 else $dati_app['vicini'][$numapp] = "$numapp";
 } # fine for $num1
 asort ($dati_app['maxocc']);
@@ -72,6 +92,16 @@ $lista_tutti_app = ",";
 while (list($key, $val) = each($dati_app['posizione'])) $lista_tutti_app .= "$val,";
 $dati_app['lista'] = $lista_tutti_app;
 $dati_app['totapp'] = $numappartamenti;
+for ($num1 = 0 ; $num1 < count($grp_vicini) ; $num1++) {
+if ($grp_vicini[$num1]) {
+$lst_vicini = explode(",",$grp_vicini[$num1]);
+$val_vicini = array();
+for ($num2 = 0 ; $num2 < count($lst_vicini) ; $num2++) $val_vicini[$lst_vicini[$num2]] = 1;
+$val_vicini = array_keys($val_vicini);
+$dati_app['grp_vicini_num'][count($dati_app['grp_vicini_num'])] = count($val_vicini);
+$dati_app['grp_vicini'][count($dati_app['grp_vicini'])] = ",".implode(",",$val_vicini).",";
+} # fine if ($grp_vicini[$num1])
+} # fine for $num1
 } # fine if (!$dati_app)
 
 if ((string) $limiti_var['ini'] == "") $limiti_var['ini'] = ($limiti_var['n_fine'] + 1);
@@ -404,6 +434,9 @@ $prenota_in_app_sett[$app][$num1] = $idp;
 # $app_prenota_id[id_prenota] = "id_app"
 # $app_assegnabili_id[id_prenota] = {"id_app,id_app,...,id_app" | "v" | ""} (app. fisso se vuoto)
 # $app_assegnabili_id[0][id_prenota] = {"id_prenota,...,id_prenota" | ""} (nessuna prenota compagna se vuoto)
+#
+# Aggiunto dopo fuori da tab_a_var() :
+# $app_assegnabili_id[0][0][id_richiesto] = "id_app,...,id_app" (copia originale app_richiesti)
 
 
 
@@ -470,6 +503,127 @@ if ($tutti_occupati == "SI") $fatto = "SI";
 else $fatto = "NO";
 $num_da_liberare = 1;
 $num_da_liberare2 = 1;
+$app_non_liberabili = ",";
+
+
+# Se si cerca il primo di una serie di appartamenti vicini controllo che nel gruppo di appartamenti vicini, meno
+# quelli occupati da prenotazioni fisse o assegnabili solo nel gruppo, ci sia un numero maggiore o uguale a quelli
+# richiesti. Controllo anche che ci siano abbastanza appartamenti nei gruppi disponibili per i successivi gruppi
+# di appartamenti richiesti, rimuovendo anche qui gli appartamenti con prenotazioni assegnabili solo nei gruppi. 
+if ($app_richiesti_vett[',vicini,'] == "SI") {
+if (!$app_assegnabili_id[0][0]) {
+$app_assegnabili_id[0][0] = $app_richiesti_vett;
+$ass00 = 1;
+} # fine if (!$app_assegnabili_id[0][0])
+if (!$app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']]) {
+$app_controllati = ",";
+for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) if ($dati_app['vicini'][$numapp] == $numapp and (!$app_richiesti or $app_richiesti[$numapp] == "SI")) $app_non_liberabili .= "$numapp,";
+if ($app_richiesti_vett['id'] == 1 or $app_richiesti_vett[',succ_non_vicino,'][($app_richiesti_vett['id'] - 1)]) {
+$num_gruppo = 0;
+$num_vicini_tot = 0;
+$num_vicini_gruppo[0] = 1;
+$idinizio_corr = $idinizio;
+$idfine_corr = $idfine;
+for ($num1 = ($app_richiesti_vett['id'] + 1) ; $num1 <= $app_richiesti_vett[',numero,'] ; $num1++) {
+if ($idinizio_vett[$num1] < $idfine_corr and $idfine_vett[$num1] > $idinizio_corr) {
+if ($idinizio_vett[$num1] > $idinizio_corr) $idinizio_corr = $idinizio_vett[$num1];
+if ($idfine_vett[$num1] < $idfine_corr) $idfine_corr = $idfine_vett[$num1];
+$num_vicini_gruppo[$num_gruppo]++;
+} # fine if ($idinizio_vett[$num1] < $idfine_corr and $idfine_vett[$num1] > $idinizio_corr)
+if ($app_richiesti_vett[',succ_non_vicino,'][$num1] and $num1 != $app_richiesti_vett[',numero,']) {
+if ($num_vicini_gruppo[$num_gruppo] >= $num_vicini_gruppo[0]) $num_vicini_tot += $num_vicini_gruppo[$num_gruppo];
+$num_gruppo++;
+$num_vicini_gruppo[$num_gruppo] = 0;
+} # fine if ($app_richiesti_vett[',succ_non_vicino,'][$num1] and $num1 != $app_richiesti_vett[',numero,'])
+} # fine for $num1
+if ($num_vicini_gruppo[$num_gruppo] >= $num_vicini_gruppo[0]) $num_vicini_tot += $num_vicini_gruppo[$num_gruppo];
+$num_vicini = $num_vicini_gruppo[0];
+$num_vicini_disp_tot = 0;
+$prenota_ricontrolla_tot = array();
+$app_gruppi_disp = ",";
+$num_app_gruppi_disp = 0;
+for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
+$numapp = $dati_app['posizione'][$num1];
+if ((!$app_richiesti or $app_richiesti[$numapp] == "SI") and !strstr($app_controllati,",$numapp,") and !strstr($app_non_liberabili,",$numapp,")) {
+for ($num2 = 0 ; $num2 < count($dati_app['grp_vicini']) ; $num2++) {
+if (strstr($dati_app['grp_vicini'][$num2],",$numapp,")) {
+$num_vicini_disp = $dati_app['grp_vicini_num'][$num2];
+if ($num_vicini > $num_vicini_disp) $app_non_liberabili .= substr($dati_app['grp_vicini'][$num2],1);
+else {
+$grp_vicini = explode(",",substr($dati_app['grp_vicini'][$num2],1,-1));
+for ($num3 = 0 ; $num3 < $dati_app['grp_vicini_num'][$num2] ; $num3++) {
+$prenotainperiodo = prenota_in_app_e_periodo($grp_vicini[$num3],$idinizio_corr,$idfine_corr,$prenota_in_app_sett,$fine_prenota_id,$num_pp);
+for ($num4 = 1 ; $num4 <= $num_pp ; $num4++) {
+if (!$app_assegnabili_id[$prenotainperiodo[$num4]]) {
+$num_vicini_disp--;
+break;
+} # fine if (!$app_assegnabili_id[$prenotainperiodo[$num4]])
+elseif ($app_assegnabili_id[$prenotainperiodo[$num4]] != "v") {
+$vett_assegnabili = explode(",",$app_assegnabili_id[$prenotainperiodo[$num4]]);
+$num_assegnabili = count($vett_assegnabili);
+if ($num_assegnabili <= $dati_app['grp_vicini_num'][$num2]) {
+$contenuto = 1;
+for ($num5 = 0 ; $num5 < $num_assegnabili ; $num5++) {
+if (!strstr($dati_app['grp_vicini'][$num2],",".$vett_assegnabili[$num5].",")) {
+$contenuto = 0;
+break;
+} # fine if (!strstr($dati_app['grp_vicini'][$num2],",".$vett_assegnabili[$num5].","))
+} # fine for $num5
+if ($contenuto) {
+$num_vicini_disp--;
+$prenota_ricontrolla_tot[$grp_vicini[$num3]] = "";
+break;
+} # fine if ($contenuto)
+else $prenota_ricontrolla_tot[$grp_vicini[$num3]][$num4] = $vett_assegnabili;
+} # fine if ($num_assegnabili <= $dati_app['grp_vicini_num'][$num2])
+else $prenota_ricontrolla_tot[$grp_vicini[$num3]][$num4] = $vett_assegnabili;
+} # fine elseif ($app_assegnabili_id[$prenotainperiodo[$num4]] != "v")
+} # fine for $num4
+} # fine for $num3
+if ($num_vicini > $num_vicini_disp) $app_non_liberabili .= substr($dati_app['grp_vicini'][$num2],1);
+else {
+$num_vicini_disp_tot += $num_vicini_disp;
+$app_gruppi_disp .= substr($dati_app['grp_vicini'][$num2],1);
+$num_app_gruppi_disp += $dati_app['grp_vicini_num'][$num2];
+} # fine else if ($num_vicini > $num_vicini_disp)
+} # fine else if ($num_vicini > $num_vicini_disp)
+$app_controllati .= substr($dati_app['grp_vicini'][$num2],1);
+break;
+} # fine if (strstr($dati_app['grp_vicini'][$num2],",$numapp,"))
+} # fine for $num2
+} # fine if ((!$app_richiesti or $app_richiesti[$numapp] == "SI") and !strstr($app_controllati,",$numapp,"))
+} # fine for $num1
+if ($num_vicini_tot > $num_vicini_disp_tot) $app_non_liberabili .= substr($app_gruppi_disp,1);
+elseif ($num_vicini_tot > $num_vicini and $app_gruppi_disp) {
+for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
+$numapp = $dati_app['posizione'][$num1];
+if (@is_array($prenota_ricontrolla_tot[$numapp])) {
+while (list($num_pp,$vett_assegnabili) = each($prenota_ricontrolla_tot[$numapp])) {
+$num_assegnabili = count($vett_assegnabili);
+if ($num_assegnabili <= $num_app_gruppi_disp) {
+$contenuto = 1;
+for ($num2 = 0 ; $num2 < $num_assegnabili ; $num2++) {
+if (!strstr($app_gruppi_disp,",".$vett_assegnabili[$num2].",")) {
+$contenuto = 0;
+break;
+} # fine if (!strstr($dati_app['grp_vicini'][$num2],",".$vett_assegnabili[$num2].","))
+} # fine for $num2
+if ($contenuto) {
+$num_vicini_disp_tot--;
+break;
+} # fine if ($contenuto)
+} # fine if ($num_assegnabili <= $num_app_gruppi_disp)
+} # fine while (list($num_pp,$vett_assegnabili) = each($prenota_ricontrolla_tot[$numapp]))
+if ($num_vicini_tot > $num_vicini_disp_tot) {
+$app_non_liberabili .= substr($app_gruppi_disp,1);
+break;
+} # fine if ($num_vicini_tot > $num_vicini_disp_tot)
+} # fine if (@is_array($prenota_ricontrolla_tot[$numapp]))
+} # fine for $num1
+} # fine elseif ($num_vicini_tot > $num_vicini and $app_gruppi_disp)
+} # fine if ($app_richiesti_vett['id'] == 1 or $app_richiesti_vett[',succ_non_vicino,'][($app_richiesti_vett['id'] - 1)])
+} # fine if (!$app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']])
+} # fine if ($app_richiesti_vett[',vicini,'] == "SI")
 
 
 # cicli da ripetere per ogni appartamento fino a che $fatto = SI
@@ -479,7 +633,7 @@ if ($fatto != "SI") {
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $numapp = $dati_app['posizione'][$num1];
 if (!$app_richiesti or $app_richiesti[$numapp] == "SI") {
-if ($app_richiesti_vett[',vicini,'] != "SI" or $dati_app['vicini'][$numapp] != $numapp) {
+if (!strstr($app_non_liberabili,",$numapp,")) {
 $prenotainperiodo = prenota_in_app_e_periodo($numapp,$idinizio,$idfine,$prenota_in_app_sett,$fine_prenota_id,$num_pp);
 if (!$num_pp) {
 $appartamento = $numapp;
@@ -487,7 +641,7 @@ $fatto = "SI";
 if ($debug == "on") echo "LIBERATO1 $appartamento<br>";
 break;
 } # fine if (!$num_pp)
-} # fine if ($app_richiesti_vett[',vicini,'] != "SI" or $dati_app['vicini'][$numapp] != $numapp)
+} # fine if (!strstr($app_non_liberabili,",$numapp,"))
 } # fine if (!$app_richiesti or $app_richiesti[$numapp] == "SI")
 } # fine for $num1
 } # fine if ($fatto != "SI")
@@ -538,7 +692,7 @@ $tutti_liberabili = "SI";
 for ($num2 = 1 ; $num2 <= $num_pp ; $num2++) {
 $idprenotainperiodo = $prenotainperiodo[$num2];
 if ($app_assegnabili_id[$idprenotainperiodo] and $app_assegnabili_id[$idprenotainperiodo] != "v") {
-$vett_assegnabili = explode (",", $app_assegnabili_id[$idprenotainperiodo]);
+$vett_assegnabili = explode(",",$app_assegnabili_id[$idprenotainperiodo]);
 $num_assegnabili = count($vett_assegnabili);
 for ($num3 = 0 ; $num3 < $num_assegnabili ; $num3++) {
 $app_ = $vett_assegnabili[$num3];
@@ -554,9 +708,10 @@ $idfinep = $fine_prenota_id[$idprenotainperiodo];
 } # fine if (!$idfinep or $idfinep < $fine_prenota_id[$idprenotainperiodo])
 } # fine if ($app_assegnabili_id[$idprenotainperiodo])
 else $mobile = "NO";
-if ($app_richiesti_vett[',vicini,'] == "SI" and !$dati_app['vicini'][$numapp] == $numapp) $mobile = "NO";
 } # fine for $num2
 
+if (strstr($app_non_liberabili,",$numapp,")) $mobile = "NO";
+
 
 if ($mobile == "SI") {
 # Provo a spostare le prenotazioni dell'appartamento $numapp.
@@ -569,7 +724,7 @@ for ($num2 = 1 ; $num2 <= $num_pp ; $num2++) {
 $idprenotainperiodo = $prenotainperiodo[$num2];
 for ($num3 = 0 ; $num3 < $dati_app['totapp'] ; $num3++) {
 if ($num3 != $num1) {
-$numapp2 = $dati_app[posizione][$num3];
+$numapp2 = $dati_app['posizione'][$num3];
 if ($app_assegnabili_id[$idprenotainperiodo] == "v" or $app_assegnabili[$idprenotainperiodo][$numapp2] == "SI") {
 $prenotainperiodo2 = prenota_in_app_e_periodo($numapp2,$inizio_prenota_id[$idprenotainperiodo],$fine_prenota_id[$idprenotainperiodo],$prenota_in_app_sett,$fine_prenota_id,$num_pp2);
 if (!$num_pp2 and !$app_assegnabili_id[0][$idprenotainperiodo]) {
@@ -800,6 +955,8 @@ if ($app_assegnabili_id[0][$idprenotainperiodo]) {
 $idprenota_comp = explode(",",$app_assegnabili_id[0][$idprenotainperiodo]);
 $num_idprenota_comp = count($idprenota_comp);
 cancella_prenota_compagne($idprenota_comp,$num_idprenota_comp,$idinizioprenota2,$idfineprenota2,$ap_ric,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$n_app_prenota_id,$n_prenota_in_app_sett);
+$app_richiesti_orig = $app_assegnabili_id[0][0];
+$app_assegnabili_id[0][0] = "";
 } # fine if ($app_assegnabili_id[0][$idprenotainperiodo])
 
 $appartamento2 = "";
@@ -832,6 +989,7 @@ if ($app_assegnabili_id[0][$idprenotainperiodo]) {
 $inizio_prenota_id[$idprenotainperiodo] = $idinizioprenota2[1];
 $fine_prenota_id[$idprenotainperiodo] = $idfineprenota2[1];
 if ($fatto2 == "SI") ripristina_prenota_compagne($idprenota_comp,$num_idprenota_comp,$idinizioprenota2,$idfineprenota2,$appartamento2,$n_app_prenota_id,$n_prenota_in_app_sett,$fine_prenota_id,$profondita);
+$app_assegnabili_id[0][0] = $app_richiesti_orig;
 } # fine if ($app_assegnabili_id[0][$idprenotainperiodo])
 else {
 $inizio_prenota_id[$idprenotainperiodo] = $idinizioprenota2;
@@ -969,13 +1127,14 @@ $n_prenota_in_app_sett[$appartamento][$num1] = $id_prenota_lib;
 } # fine for $num1
 
 # Se gli app devono essere vicini mantengo l'app liberato fisso e provo i restanti da liberare
-if ($app_richiesti_vett[',vicini,'] == "SI") {
+if ($app_richiesti_vett[',vicini,'] == "SI" and !$app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']]) {
 $fatto = "NO";
 $lim_for = $app_richiesti_vett[',numero,'];
 if ($lim_for != ($app_richiesti_vett['id'] + 1) and $limiti_var['t_limite'] < time()) {
 $lim_for = ($app_richiesti_vett['id'] + 1);
+if (($limiti_var['t_limite'] + 20) < time()) $lim_for = 0;
 if ($debug == "on") echo "timeout<br>";
-} # fine if ($limiti_var['t_limite'] < time())
+} # fine if ($lim_for != ($app_richiesti_vett['id'] + 1) and $limiti_var['t_limite'] < time())
 for ($num1 = ($app_richiesti_vett['id'] + 1) ; $num1 <= $lim_for ; $num1++) {
 if ($provato[$idinizio_vett[$num1]][$idfine_vett[$num1]][$app_richiesti_vett[$num1]] != "SI") {
 $provato[$idinizio_vett[$num1]][$idfine_vett[$num1]][$app_richiesti_vett[$num1]] = "SI";
@@ -1025,13 +1184,13 @@ break;
 } # fine if ($provato[$idinizio_vett[$num1]][$idfine_vett[$num1]][$app_richiesti_vett[$num1]] != "SI")
 } # fine for $num1
 if ($fatto != "SI") $riprova_senza_app_liberato = $appartamento;
-} # fine if ($app_richiesti_vett[',vicini,'] == "SI")
+} # fine if ($app_richiesti_vett[',vicini,'] == "SI" and !$app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']])
 
 else {
 if ($app_richiesti_vett[$app_richiesti_vett['id']] == ",tutti,") $app_assegnabili_id[$id_prenota_lib] = "v";
 else if (str_replace(",","",$app_richiesti_vett[$app_richiesti_vett['id']]) != $app_richiesti_vett[$app_richiesti_vett['id']]) $app_assegnabili_id[$id_prenota_lib] = $app_richiesti_vett[$app_richiesti_vett['id']];
 liberasettimane($idinizio_vett,$idfine_vett,$limiti_var,$anno,$fatto,$appartamento_vett,$nuova_profondita,$app_richiesti_vett,$n_app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$n_prenota_in_app_sett,$dati_app,$nome_tab_prenota);
-} # fine elseif ($app_richiesti[',vicini,'] == "SI")
+} # fine else if ($app_richiesti[',vicini,'] == "SI" and !$app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']])
 
 if ($fatto == "SI") {
 $app_prenota_id = $n_app_prenota_id;
@@ -1056,7 +1215,7 @@ $appartamento = $appartamento_vett;
 
 
 # Se si era liberato un appartamento ma non se ne sono trovati altri vicini riprovo
-if ($riprova_senza_app_liberato) {
+if ($riprova_senza_app_liberato and ($limiti_var['t_limite'] + 20) >= time()) {
 $n_lista_app_ric = "";
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $numapp = $dati_app['posizione'][$num1];
@@ -1065,19 +1224,30 @@ if ($numapp != $riprova_senza_app_liberato and $riprova_app[$numapp] != "NO") $n
 $n_lista_app_ric = substr($n_lista_app_ric,0,-1);
 $app_richiesti_vett[$app_richiesti_vett['id']] = incrocia_app_richiesti($app_richiesti_vett[$app_richiesti_vett['id']],$n_lista_app_ric);
 if ((string) $app_richiesti_vett[$app_richiesti_vett['id']] != "") {
+for ($num1 = ($app_richiesti_vett['id'] + 1) ; $num1 <= $app_richiesti_vett[',numero,'] ; $num1++) {
+if ($app_assegnabili_id[0][0][$num1] == $app_assegnabili_id[0][0][$app_richiesti_vett['id']] and $idinizio_vett[$num1] == $idinizio and $idfine_vett[$num1] == $idfine and !$app_richiesti_vett[',succ_non_vicino,'][($num1 - 1)]) {
+$app_richiesti_vett[$num1] = $app_richiesti_vett[$app_richiesti_vett['id']];
+} # fine if ($app_assegnabili_id[0][0][$num1] == $app_assegnabili_id[0][0][$app_richiesti_vett['id']] and $idinizio_vett[$num1] == $idinizio and...
+else break;
+} # fine for $num1
 $nuova_profondita = $profondita;
 $nuova_profondita['attuale']++;
 $nuova_profondita['controllato_tutti_occupati'] = "NO";
 $n_app_prenota_id = $app_prenota_id;
 $n_prenota_in_app_sett = $prenota_in_app_sett;
+$app_richiesti_vett['id'] = $app_richiesti_vett['id'] - 1;
 if ($debug == "on") {
 global $passo;
 echo $passo;
 for ($i = 0 ; $i < $profondita['attuale'] ; $i++) echo "&nbsp;&nbsp;";
 echo "<b>".$profondita['attuale']."</b> <em>".date("H:i:s")."</em> riprova ".$app_richiesti_vett['id']." negli app ".$app_richiesti_vett[$app_richiesti_vett['id']]."<br>";
 } # fine if ($debug == "on")
-$app_richiesti_vett['id'] = $app_richiesti_vett['id'] - 1;
 liberasettimane($idinizio_vett,$idfine_vett,$limiti_var,$anno,$fatto,$appartamento_vett,$nuova_profondita,$app_richiesti_vett,$n_app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$n_prenota_in_app_sett,$dati_app,$nome_tab_prenota);
+if ($debug == "on") {
+echo $passo;
+for ($i = 0 ; $i < $profondita['attuale'] ; $i++) echo "&nbsp;&nbsp;";
+echo "<b>".$profondita['attuale']."</b> fatto riprova ".$app_richiesti_vett['id']."<br>";
+} # fine if ($debug == "on")
 if ($fatto == "SI") {
 $app_prenota_id = $n_app_prenota_id;
 $prenota_in_app_sett = $n_prenota_in_app_sett;
@@ -1085,13 +1255,14 @@ $appartamento = $appartamento_vett;
 } # fine if ($fatto == "SI")
 else aggiorna_app_aggiunti($limiti_var,$limiti_var_orig,$app_orig_prenota_id,$app_prenota_id,$inizio_prenota_id,$fine_prenota_id,$prenota_in_app_sett);
 } # fine if ((string) $app_richiesti_vett[$app_richiesti_vett['id']] != "")
-} # fine if ($riprova_senza_app_liberato)
+} # fine if ($riprova_senza_app_liberato and ($limiti_var['t_limite'] + 20) >= time())
 
 
 if ($primo_ciclo == "SI" and $fatto == "SI") {
 $risul_agg = aggiorna_tableprenota($app_prenota_id,$app_orig_prenota_id,$tableprenota);
 if (!$risul_agg) $fatto = "NO";
 } # fine if ($primo_ciclo == "SI" and $fatto == "SI")
+if ($ass00) $app_assegnabili_id[0][0] = "";
 
 } # fine function liberasettimane
 
