@@ -64,7 +64,8 @@ echo "<form method=\"post\" action=\"crea_modelli.php\"><div>
 <input type=\"hidden\" name=\"lingua_modello\" value=\"$lingua_modello\">
 <input type=\"hidden\" name=\"perc_cart_mod_sel\" value=\"$perc_cart_mod_sel\">
 
-<h5>".mext_cal("Pagina del calendario della disponibilità",$pag)."</h5><br><br>
+<div style=\"height: 4px;\"></div>
+<h5 id=\"h_vmon\"><span>".mext_cal("Pagina del calendario della disponibilità",$pag)."</span></h5><br><br>
 <table><tr><td valign=\"top\">
 ".mext_cal("Mostra le date",$pag)."</td><td>";
 #if (!$num_periodi_date or controlla_num_pos($num_periodi_date) == "NO") $num_periodi_date = 1;
@@ -286,7 +287,7 @@ $num_colori = count($colori_tema);
 for ($num2 = 1 ; $num2 <= $num_colori ; $num2++) {
 $colore_corr = $colori_tema[$num2]['default'];
 if ($sel and ${"colore_tema_".$num2}) $colore_corr = ${"colore_tema_".$num2};
-$js_opz_tema .= "".mex("Colore del tema",$pag)." \"".$template_theme_name[$num1]."\" ".mex("per",$pag)." \"".$colori_tema[$num2]['name']."\":\\
+$js_opz_tema .= "".mex("Colore del tema",$pag)." \"".mex($template_theme_name[$num1],$pag)."\" ".mex("per",$pag)." \"".$colori_tema[$num2]['name']."\":\\
  <input type=\"text\" name=\"colore_tema_$num2\" id=\"coltxt$num2\" size=\"8\" value=\"$colore_corr\" onchange=\"agg_colore_sel_txt($num2)\">\\
 <select id=\"colsel$num2\" onchange=\"agg_colore_sel($num2)\" style=\"width: 80px; background-color: $colore_corr\"><option value=\"$colore_corr\" style=\"background-color: $colore_corr\">&nbsp;<\/option>'+options_colori+'<\/select><br>";
 } # fine for $num2
@@ -295,7 +296,7 @@ $num_valori = count($valori_tema);
 for ($num2 = 1 ; $num2 <= $num_valori ; $num2++) {
 $valore_corr = $valori_tema[$num2]['default'];
 if ($sel and $modello_esistente == "SI") $valore_corr = ${"valore_tema_".$num2};
-$js_opz_tema .= "".mex("Valore del tema",$pag)." \"".$template_theme_name[$num1]."\" ".mex("per",$pag)." \"".$valori_tema[$num2]['name']."\":\\
+$js_opz_tema .= "".mex("Valore del tema",$pag)." \"".mex($template_theme_name[$num1],$pag)."\" ".mex("per",$pag)." \"".$valori_tema[$num2]['name']."\":\\
  <input type=\"text\" name=\"valore_tema_$num2\" id=\"valtema$num2\" size=\"24\" value=\"$valore_corr\"><br>";
 } # fine for $num2
 $js_opz_tema .= "<\/td><\/tr><\/table>';
@@ -396,13 +397,13 @@ for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) echo "<input type=\"hidden\
 } # fine elseif ($modello_esistente == "SI")
 
 echo "<br><div style=\"text-align: center;\"><input type=\"hidden\" name=\"$template_name\" value=\"SI\">
-<input class=\"sbutton\" type=\"submit\" value=\"".mext_cal("Crea la pagina con il calendario della disponibilità",$pag)."\">
+<button class=\"vmon\" type=\"submit\"><div>".mext_cal("Crea la pagina con il calendario della disponibilità",$pag)."</div></button>
 </div></div></form><br>
 <hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 <form method=\"post\" action=\"crea_modelli.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input class=\"sbutton\" type=\"submit\" name=\"indietro\" value=\"".mex("Torna indietro",$pag)."\">
+<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form><br></div>";
 
 
