@@ -707,7 +707,8 @@ else if (@\$HTTP_SERVER_VARS[\"PHP_SELF\"]) \$PHP_SELF = \$HTTP_SERVER_VARS[\"PH
 else echo \"".mex("La variabile \\\$PHP_SELF non è definita, si dovrà editare a mano questa pagina per inserirne il nome",$pag).".<br>\";
 } # fine if (!\$pag)
 
-define(C_PERCORSO_A_DATI,\"$cost_percorso_a_dati\");
+define('C_PERCORSO_A_DATI',\"$cost_percorso_a_dati\");
+define('C_PAGINA_WEB','1');
 
 \$anno = \$".mex("var_anno",$pag).";
 \$PHPR_DB_TYPE = \$".mex("var_tipo_db",$pag).";
