@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -265,9 +265,9 @@ echo "<div class=\"cal_title\">$apertura_tag_font
 $fr_Quadro_indicativo_disponibilita
 <a href=\"./$pag?id_data_inizio_tab_disp=".($id_data_inizio_tab_disp + $num_colonne_tab_disp)."\">".str_replace("->",htmlspecialchars("->"),$fr_freccia_destra)."</a>
 $chiusura_tag_font</div>
-<table class=\"tab_disp\" $stile_tabella_cal>
+<div class=\"tab_disp_cont\"><table class=\"tab_disp\" $stile_tabella_cal>
 $righe_tab_disp
-</table>";
+</table></div>";
 } # fine if ($righe_tab_disp)
 
 
