@@ -128,6 +128,8 @@ $fr_frase[98] = "fr_Abbiamo_ricevuto_la_sua_richiesta_di_prenotazione_ecc";
 $fr_frase[99] = "fr_Copia_della_richiesta_e_stata_inviata_a";
 $fr_frase[100] = "fr_posizioni_vicine";
 $fr_frase[101] = "fr_con_posizioni_vicine";
+$fr_frase[102] = "fr_Codice_promozionale";
+$fr_frase[103] = "fr_Codice_promozionale_applicato";
 
 
 $frase[0] = "in";
@@ -232,6 +234,8 @@ $frase[98] = "Abbiamo ricevuto la sua richiesta di prenotazione e risponderemo a
 $frase[99] = "Copia della richiesta è stata inviata a";
 $frase[100] = "posizioni vicine";
 $frase[101] = "con posizioni vicine";
+$frase[102] = "Codice promozionale";
+$frase[103] = "Codice promozionale applicato";
 
 $num_frasi = count($fr_frase);
 
