@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -92,6 +92,13 @@ echo "<input class=\"sbutton\" type=\"submit\" name=\"aggiungidatemenu\" value=\
 <select name=\"estendi_ultima_data\">
 <option value=\"SI\"$sel_SI>".mex("SI",$pag)."</option>
 <option value=\"NO\"$sel_NO>".mex("NO",$pag)."</option>
+</select><br>";
+if (!$mostra_date_passate or strtoupper($mostra_date_passate) == $SI or $mostra_date_passate == "SI") { $sel_SI = " selected"; $sel_NO = ""; }
+else { $sel_NO = " selected"; $sel_SI = ""; }
+echo "".mex("Mostrare le date passate?",$pag)."
+<select name=\"mostra_date_passate\">
+<option value=\"SI\"$sel_SI>".mex("SI",$pag)."</option>
+<option value=\"NO\"$sel_NO>".mex("NO",$pag)."</option>
 </select><br><br>";
 
 if (!$stile_soldi) {
