@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -81,6 +81,19 @@ else $num_intervallo++;
 } # fine if ($num_date_mancanti > 0)
 } # fine if ($estendi_ultima_data == "SI")
 
+if ($mostra_date_passate == "NO") {
+$oggi = date("Y-m-d",(time() + (C_DIFF_ORE * 3600)));
+$date_menu_periodi = explode("<option value=\"",$menu_periodi);
+$num_date_menu_periodi = (count($date_menu_periodi) - 2);
+$nuova_prima_data = "";
+for ($num1 = 1 ; $num1 < $num_date_menu_periodi ; $num1++) {
+$data_corr = substr($date_menu_periodi[$num1],0,10);
+if ($data_corr >= $oggi) break;
+else $nuova_prima_data = $data_corr;
+} # fine for $num1
+if ($nuova_prima_data) $menu_periodi = strstr(strstr($menu_periodi,$nuova_prima_data),"<option value=");
+} # fine if ($mostra_date_passate == "NO")
+
 unset($inizioperiodi);
 unset($fineperiodi);
 unset($inizioperiodi_id);
@@ -254,7 +267,7 @@ $fine_colonna_periodo[$num_colonne_periodi] = $datafine;
 $num_colonne_periodi++;
 } # fine for $num_p
 
-echo "<table class=\"rates\" $stile_tabella_tariffe>
+echo "<div class=\"rates_cont\"><table class=\"rates\" $stile_tabella_tariffe>
 <tr class=\"row_dates\"><td>&nbsp;</td>";
 if ($fr_dal) $fr_dal_br = $fr_dal."<br>";
 else $fr_dal_br = "";
@@ -307,7 +320,7 @@ echo "</tr>
 ";
 } # fine if ($tariffe_mostra[${"numtariffa".$num1}] == "SI")
 } # fine for $num1
-echo "</table>";
+echo "</table></div>";
 
 
 
