@@ -48,13 +48,21 @@ $template_theme_values[1][3]['default'] = mex2("Torna alla HOME",$pag,$lingua_mo
 $template_theme_values[1][4]['name'] = mex("URL file css",$pag);
 $template_theme_values[1][4]['default'] = "";
 $template_theme_values[1][4]['replace'] = "<link rel=\"stylesheet\" type=\"text/css\" href=\"[theme_value_4]\" media=\"all\">";
+$template_theme_values[1][5]['name'] = mex("titolo html",$pag);
+if ($dati_struttura[0]) $template_theme_values[1][5]['default'] = $dati_struttura[0]." - ".mext_rat("Tabella Tariffe",$pag,$lingua_modello);
+else $template_theme_values[1][5]['default'] = mext_rat("Tabella Tariffe",$pag,$lingua_modello);
+$template_theme_values[1][5]['null'] = "[theme_value_6]";
+$template_theme_values[1][6]['name'] = mex("titolo",$pag);
+$template_theme_values[1][6]['default'] = mext_rat("Tabella Tariffe",$pag,$lingua_modello);
+#rimuovere questo null dopo versione 2.2.2?
+$template_theme_values[1][6]['null'] = mext_rat("Tabella Tariffe",$pag,$lingua_modello);
 $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
         \"http://www.w3.org/TR/html4/strict.dtd\">
 <html>
 <head>
 <meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\" >
 <meta name=\"viewport\" content=\"initial-scale=1.0\">
-<title> $nome_file </title>
+<title>[theme_value_5]</title>
 <style type=\"text/css\">
  div.homebox { width: 100%; padding: 10px 0 10px 0; margin: 0; border-bottom: 2px solid [theme_color_1]; background-color: [theme_color_3]; }
  div.homebox a { padding-left: 20px }
@@ -73,8 +81,7 @@ $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN
 <body style=\"background-color: [theme_color_2]; color: [theme_color_1]; padding: 0; margin: 0;\">
 [theme_value_1]
 
-<div class=\"mainbox\"><big><big>
-".mext_rat("Tabella Tariffe",$pag,$lingua_modello)."</big></big>
+<div class=\"mainbox\"><big><big>[theme_value_6]</big></big>
 <br><br>";
 $template_theme_html_post[1] = "
 ";
