@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -44,17 +44,25 @@ $template_theme_values[1][2]['default'] = $dati_struttura[15];
 $template_theme_values[1][2]['replace'] = "<img style=\"text-decoration: none; border: 0px;\" src=\"[theme_value_2]\" alt=\"[theme_value_3]\">";
 $template_theme_values[1][2]['null'] = "[theme_value_3]";
 $template_theme_values[1][3]['name'] = "home";
-$template_theme_values[1][3]['default'] = "".mex2("Torna alla HOME",$pag,$lingua_modello)."";
+$template_theme_values[1][3]['default'] = mex2("Torna alla HOME",$pag,$lingua_modello);
 $template_theme_values[1][4]['name'] = mex("URL file css",$pag);
 $template_theme_values[1][4]['default'] = "";
 $template_theme_values[1][4]['replace'] = "<link rel=\"stylesheet\" type=\"text/css\" href=\"[theme_value_4]\" media=\"all\">";
+$template_theme_values[1][5]['name'] = mex("titolo html",$pag);
+if ($dati_struttura[0]) $template_theme_values[1][5]['default'] = $dati_struttura[0]." - ".mex2("Controlla la disponibilità",$pag,$lingua_modello);
+else $template_theme_values[1][5]['default'] = mex2("Controlla la disponibilità",$pag,$lingua_modello);
+$template_theme_values[1][5]['null'] = "[theme_value_6]";
+$template_theme_values[1][6]['name'] = mex("titolo",$pag);
+$template_theme_values[1][6]['default'] = mex2("Controlla la disponibilità",$pag,$lingua_modello);
+#rimuovere questo null dopo versione 2.2.2?
+$template_theme_values[1][6]['null'] = mex2("Controlla la disponibilità",$pag,$lingua_modello);
 $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
         \"http://www.w3.org/TR/html4/strict.dtd\">
 <html>
 <head>
 <meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\">
 <meta name=\"viewport\" content=\"initial-scale=1.0\">
-<title> $nome_file </title>
+<title>[theme_value_5]</title>
 <style type=\"text/css\">
  div.homebox { width: 100%; padding: 10px 0 10px 0; margin: 0; border-bottom: 2px solid [theme_color_1]; background-color: [theme_color_3]; }
  div.homebox a { padding-left: 20px }
@@ -83,8 +91,7 @@ $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN
 <body style=\"background-color: [theme_color_2]; color: [theme_color_1]; padding: 0; margin: 0;\">
 [theme_value_1]
 
-<div class=\"mainbox\"><big><big>
-".mex2("Controlla la disponibilità",$pag,$lingua_modello)."</big></big><br><br>
+<div class=\"mainbox\"><big><big>[theme_value_6]</big></big><br><br>
 
 <table class=\"formframe\" border=1 cellspacing=0 cellpadding=16>
 <tr><td>
