@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -68,7 +68,7 @@ break;
 if (@is_file("./COPYING")) $file_copying = "file <a href=\"COPYING\">COPYING</a>";
 else $file_copying = "<a href=\"http://www.gnu.org/licenses/agpl-3.0.html\">AGPLv3</a> License";
 echo "<div style=\"text-align: center;\"><h3>".mex("Benvenuto a HOTELDRUID",$pag).".</h3><br><br>
-HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2017 Marco M. F. De Santis<br>
+HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2018 Marco M. F. De Santis<br>
 HotelDruid comes with ABSOLUTELY NO WARRANTY; <br>for details see the $file_copying.<br>
 This is free software, and you are welcome to redistribute it<br>
  under certain conditions; see the $file_copying for details.<br>
@@ -479,11 +479,58 @@ $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
 $tablecostiprenota = $PHPR_TAB_PRE."costiprenota".$anno;
 $tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
 $tableclienti = $PHPR_TAB_PRE."clienti";
+$tableanni = $PHPR_TAB_PRE."anni";
+
+if ($id_utente == 1) {
+if ($canc_mess_periodi) {
+$tabelle_lock = array($tablepersonalizza);
+$altre_tab_lock = array($tableanni,$tableperiodi);
+$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+} # fine if ($canc_mess_periodi)
+else {
+$tabelle_lock = "";
+$altre_tab_lock = array($tableanni,$tableperiodi,$tablepersonalizza);
+$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+} # fine else if ($canc_mess_periodi)
+$mesi_avviso = 4;
+$limite_avviso_date = date("Y-m-d",mktime(0,0,0,((int) date("m") + $mesi_avviso),date("d"),date("Y")));
+$limite_avviso_date = esegui_query("select * from $tableperiodi where datafine > '$limite_avviso_date' limit 1 ");
+if (!numlin_query($limite_avviso_date)) {
+$anni_succ = esegui_query("select * from $tableanni where idanni > '$anno' ");
+if (!numlin_query($anni_succ)) {
+$visto = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'visto_messaggio_periodi' and idutente = '$id_utente' ");
+if (!numlin_query($visto)) {
+if ($canc_mess_periodi) esegui_query("insert into $tablepersonalizza (idpersonalizza,valpersonalizza,idutente) values ('visto_messaggio_periodi','1','$id_utente')");
+else {
+echo "<b class=\"colwarn\">".mex("Avviso",$pag)."</b>: ".mex("nel database sono ancora disponibili periodi solo per meno di",$pag)." $mesi_avviso ".mex("mesi",$pag).".
+<table style=\"margin-left: auto; margin-right: auto; margin-top: 6px;\"><tr><td>
+<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"canc_mess_periodi\" value=\"1\">
+<button class=\"canc\" type=\"submit\"><div>".mex("OK, ho capito",$pag)."</div></button>
+</div></form></td><td style=\"width: 10px;\"></td><td>
+<form accept-charset=\"utf-8\" method=\"post\" action=\"./visualizza_tabelle.php\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"tipo_tabella\" value=\"periodi\">
+<input type=\"hidden\" name=\"mostra_form_agg_per\" value=\"1\">
+<input type=\"hidden\" name=\"origine\" value=\"./creaprezzi.php\">
+<button class=\"amon\" type=\"submit\"><div>".mex("Aggiungi periodi","visualizza_tabelle.php")."</div></button>
+</div></form></td></tr></table>
+<div class=\"mm_sub7\"></div><hr style=\"width: 95%;\">";
+} # fine else if ($canc_mess_periodi) 
+} # fine if (!numlin_query($visto))
+} # fine if (!numlin_query($anni_succ))
+} # fine if (!numlin_query($limite_avviso_date))
+unlock_tabelle($tabelle_lock);
+} # fine if ($id_utente == 1)
+
 $attiva_checkin = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'attiva_checkin' and idutente = '$id_utente'");
 $attiva_checkin = risul_query($attiva_checkin,0,'valpersonalizza');
 if ($attiva_checkin == "SI") {
 $tabelle_lock = "";
-$altre_tab_lock = array("$tableprenota","$tableperiodi","$tablepersonalizza");
+$altre_tab_lock = array($tableprenota,$tableperiodi,$tablepersonalizza);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $stile_soldi = stile_soldi();
 if ($priv_vedi_tab_prenotazioni == "p" or $priv_vedi_tab_prenotazioni == "g") {
@@ -743,7 +790,10 @@ if ($tema[$id_utente] != "base") include("./themes/".$tema[$id_utente]."/php/hea
 else include("./includes/head.php");
 echo "$form_aggiorna_sub";
 
-if (controlla_anno($anno) == "NO" or $id_utente != 1 or $installazione_subordinata == "SI" or (C_CREA_ANNO_NON_ATTUALE == "NO" and $anno != $anno_corrente)) echo mex("Il formato dell'anno richiesto è sbagliato",$pag).".<br>";
+if (controlla_anno($anno) == "NO" or $id_utente != 1 or $installazione_subordinata == "SI" or (C_CREA_ANNO_NON_ATTUALE == "NO" and $anno != $anno_corrente)) {
+if (controlla_anno($anno) == "SI" and $id_utente != 1) echo mex("Questo utente non ha i privilegi per creare nuovi anni",$pag).".<br>";
+else echo mex("Il formato dell'anno richiesto è sbagliato",$pag).".<br>";
+} # fine if (controlla_anno($anno) == "NO" or $id_utente != 1 or $installazione_subordinata == "SI" or...
 else {
 
 echo "<br> ".mex("Non esiste l'anno ",$pag).$anno.mex(" nel database",$pag).". <br>";
