@@ -63,6 +63,25 @@ $id_utente = "a";
 $id_utente_azione_ic = "a";
 include(C_DATI_PATH."/lingua.php");
 $lingua_mex = $lingua[1];
+if (defined('C_URL_MOD_EXT_CARTE_CREDITO') and C_URL_MOD_EXT_CARTE_CREDITO != "") {
+$id_utente = "-1";
+$adesso = $anno.date("mdHis",(time() + (C_DIFF_ORE * 3600)));
+$versione_unica = prendi_numero_versione($tableversioni);
+list($usec, $sec) = explode(' ', microtime());
+mt_srand((float) $sec + ((float) $usec * 100000));
+$val_casuale = mt_rand(100000,999999);
+$id_sessione = $adesso.$val_casuale.$versione_unica;
+$ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
+if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
+$REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
+if ($_SERVER['REMOTE_PORT']) $REMOTE_PORT = $_SERVER['REMOTE_PORT'];
+$REMOTE_PORT = aggslashdb($REMOTE_PORT);
+if ($_SERVER['HTTP_USER_AGENT']) $HTTP_USER_AGENT = $_SERVER['HTTP_USER_AGENT'];
+$HTTP_USER_AGENT = aggslashdb($HTTP_USER_AGENT);
+if ($_SERVER['HTTPS'] == "on" or $_SERVER['SERVER_PORT'] == "443") $tipo_conn = "HTTPS";
+else $tipo_conn = "HTTP";
+esegui_query("insert into $tablesessioni (idsessioni,idutente,indirizzo_ip,tipo_conn,user_agent,ultimo_accesso) values ('$id_sessione','$id_utente','$REMOTE_ADDR','$tipo_conn','$HTTP_USER_AGENT','$ultimo_accesso')");
+} # fine if (defined('C_URL_MOD_EXT_CARTE_CREDITO') and C_URL_MOD_EXT_CARTE_CREDITO != "")
 #} # fine if (!numlin_query($id_utente_az))
 } # fine if (defined("C_UTENTE_AZIONE_IC") and C_UTENTE_AZIONE_IC != "" and $utente_azione_ic == C_UTENTE_AZIONE_IC)
 
@@ -258,7 +277,7 @@ include("./includes/interconnect/$mod_ext/functions_import.php");
 $funz_import_reservations = "import_reservations_".$interconnection_func_name;
 $id_utente_origi = $id_utente;
 $id_utente = 1;
-$testo = $funz_import_reservations("",$id_ric,$file_interconnessioni,$anno,$PHPR_TAB_PRE,1,$id_utente,$HOSTNAME);
+$testo = $funz_import_reservations("",$id_ric,$file_interconnessioni,$anno,$PHPR_TAB_PRE,2,$id_utente,$HOSTNAME);
 $id_utente = $id_utente_origi;
 echo $testo;
 } # fine if ($ic_present[$interconnection_name] == "SI" and (!$id_ric or...
@@ -287,16 +306,17 @@ if ($priv_crea_interconnessioni == "s") {
 
 
 $lista_tutti_app = "";
+$maxocc = array();
 $appartamenti = esegui_query("select * from $tableappartamenti order by idappartamenti");
 $num_appartamenti = numlin_query($appartamenti);
 for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
 $idapp = risul_query($appartamenti,$num1,'idappartamenti');
-$maxocc = risul_query($appartamenti,$num1,'maxoccupanti');
+$maxocc[$idapp] = risul_query($appartamenti,$num1,'maxoccupanti');
 $lista_tutti_app .= "$idapp,";
 } # fine for $num1
 $lista_tutti_app = substr($lista_tutti_app,0,-1);
 
-unset($lista_regola2);
+$lista_regola2 = array();
 $regole2 = esegui_query("select * from $tableregole where tariffa_per_app != ''");
 $num_regole2 = numlin_query($regole2);
 for ($num1 = 0 ; $num1 < $num_regole2 ; $num1++) {
@@ -318,6 +338,14 @@ $lista_regola2[$tariffa]['napp'] = substr($lista_regola2[$tariffa]['napp'],1);
 } # fine if (substr($lista_regola2[$tariffa]['napp'],0,1) == "v")
 } # fine for $num1
 
+$lista_regola4 = array();
+$regole4 = esegui_query("select * from $tableregole where tariffa_per_persone != '' order by tariffa_per_persone");
+$num_regole4 = numlin_query($regole4);
+for ($num1 = 0 ; $num1 < $num_regole4 ; $num1++) {
+$tariffa = risul_query($regole4,$num1,'tariffa_per_persone');
+$lista_regola4[$tariffa] = risul_query($regole4,$num1,'iddatainizio');
+} # fine for $num1
+
 
 
 if ($modifica_interconnessione == "SI") {
