@@ -358,7 +358,7 @@ $inserisci_mess = 0;
 for ($num2 = 0 ; $num2 < $num_trova_email_tm ; $num2++) {
 if (!$mittente_email_tm[$num2] or stristr($mittente,$mittente_email_tm[$num2])) {
 if (!strcmp($oggetto_email_tm[$num2],"") or stristr($oggetto,$oggetto_email_tm[$num2])) {
-if ($therad_email_tm[$num2] == "tutti" or (!$risposta_a and !$riferimento and substr($oggetto,0,4) != "Re: ")) {
+if ($therad_email_tm[$num2] == "tutti" or (!$risposta_a and !$riferimento and substr($oggetto,0,4) != "Re: " and substr($oggetto,0,3) != "R: ")) {
 $inserisci_mess = 1;
 $mess_scaricati++;
 break;
@@ -395,13 +395,18 @@ for ($num2 = 0 ; $num2 < count($eml_cc) ; $num2++) $mittente .= ",".$eml_cc[$num
 $testo = imap_utf8(imap_qprint(imap_body($email_conn,$mess[$num1],FT_PEEK)));
 #if (@get_magic_quotes_gpc()) $testo = stripslashes($testo);
 if (strlen($testo) > 30 and preg_replace("|[a-z0-9+/=]|i","",str_replace("\n","",str_replace("\r","",trim($testo)))) == "") $testo = imap_utf8(base64_decode($testo));
-if ((stristr($testo,"Content-Type: multipart/alternative;") or stristr($testo,"This is a multi-part message in MIME format")) and stristr($testo,"Content-Type: text/plain;")) {
+if ((stristr($testo,"Content-Type: multipart/alternative;") or stristr($testo,"This is a multi-part message in MIME format") or stristr(stristr($testo,"Content-Type: "),"Content-Type: ")) and stristr($testo,"Content-Type: text/plain;")) {
 if (stristr($testo,"------=_Part")) $testo = explode("------=_Part",$testo);
 else $testo = explode("Content-Type: ",$testo);
 for ($num2 = 0 ; $num2 < count($testo) ; $num2++) {
 if (stristr("Content-Type: ".$testo[$num2],"Content-Type: text/plain;")) {
 $testo = str_replace("\r","\n",str_replace("\r\n","\n",$testo[$num2]));
-if (strstr($testo,"\n\n")) $testo = (strstr($testo,"\n\n"));
+if (stristr($testo,"Content-Transfer-Encoding: base64")) {
+$testo = explode("==",trim(strstr($testo,"\n\n")));
+$testo = $testo[0]."==";
+$testo = imap_utf8(base64_decode($testo));
+} # fine if (stristr($testo[$num2],"Content-Transfer-Encoding: base64"))
+while (strstr($testo,"\n\n\n")) $testo = str_replace("\n\n\n","\n\n",$testo);
 break;
 } # fine if (stristr("Content-Type: ".$testo[$num2],"Content-Type: text/plain;"))
 } # fine for $num2
@@ -453,24 +458,45 @@ $lingua_mex = $lingue[$num2];
 $fr_arrivo = mex("arrivo",$pag);
 $fr_partenza = mex("partenza",$pag);
 $fr_date = mex("date",$pag);
+$fr_periodo = mex("periodo",$pag);
 $fr_persone = mex("persone",$pag);
 $lingua_mex = $lingua_orig;
 if (!$arrivo_trovato and !$arrivo_cercato[$fr_arrivo]) {
 $arrivo_cercato[$fr_arrivo] = 1;
 # strano syntax error se si rimuove "." (dovuto a riconoscimento array?)
 $arrivo = preg_split("/$fr_arrivo"."[^0-9a-z]/i",$testo);
-if (!$arrivo[1]) $arrivo = preg_split("/$fr_date"."[^0-9a-z]/i",$testo);
 if ($arrivo[1]) {
 $arrivo = preg_split("/$fr_partenza"."[^0-9a-z]/i",substr($testo,strlen($arrivo[0])));
-$arrivo = trova_prima_data(substr($arrivo[0],0,40),$stile_data,$lingue[$num2]);
+$arrivo = trova_prima_data(substr($arrivo[0],0,40),$stile_data,$lingue[$num2],$lung_resto);
 if ($arrivo) $arrivo_trovato = 1;
 } # fine if ($arrivo[1])
+if (!$arrivo_trovato) {
+$arrivo_r = preg_split("/$fr_date"."[^0-9a-z]/i",$testo);
+if ($arrivo_r[1]) {
+$arrivo = preg_split("/$fr_partenza"."[^0-9a-z]/i",substr($testo,strlen($arrivo_r[0])));
+$arrivo = trova_prima_data(substr($arrivo[0],0,40),$stile_data,$lingue[$num2],$lung_resto);
+if ($arrivo) $arrivo_trovato = 1;
+} # fine if ($arrivo_r[1])
+if (!$arrivo_trovato) {
+$arrivo_r = preg_split("/$fr_periodo"."[^0-9a-z]/i",$testo);
+if ($arrivo_r[1]) {
+$arrivo = preg_split("/$fr_partenza"."[^0-9a-z]/i",substr($testo,strlen($arrivo_r[0])));
+$arrivo = trova_prima_data(substr($arrivo[0],0,40),$stile_data,$lingue[$num2],$lung_resto);
+if ($arrivo) $arrivo_trovato = 1;
+} # fine if ($arrivo_r[1])
+} # fine if (!$arrivo_trovato)
+if ($arrivo_trovato and !$partenza_trovata) {
+$partenza = substr($testo,((int) $lung_resto + strlen($arrivo_r[0])));
+$partenza = trova_prima_data(substr($partenza,0,40),$stile_data,$lingue[$num2],$lung_resto);
+if ($partenza) $partenza_trovata = 1;
+} # fine if ($arrivo_trovato and !$partenza_trovata)
+} # fine if (!$arrivo_trovato)
 } # fine if (!$arrivo_trovato and !$arrivo_cercato[$fr_arrivo])
 if (!$partenza_trovata and !$partenza_cercata[$fr_partenza]) {
 $partenza_cercata[$fr_partenza] = 1;
 $partenza = preg_split("/$fr_partenza"."[^0-9a-z]/i",$testo);
 if ($partenza[1]) {
-$partenza = trova_prima_data(substr($testo,strlen($partenza[0]),40),$stile_data,$lingue[$num2]);
+$partenza = trova_prima_data(substr($testo,strlen($partenza[0]),40),$stile_data,$lingue[$num2],$lung_prima_data);
 if ($partenza and $partenza != $arrivo) $partenza_trovata = 1;
 } # fine if ($partenza[1])
 } # fine if (!$partenza_trovata and !$partenza_cercata[$fr_partenza])
@@ -937,12 +963,21 @@ $tasto_prenota .= "<input type=\"hidden\" name=\"giorno_stima_checkin$n_t\" valu
 $ncostiagg = 0;
 for ($num2 = 0 ; $num2 < $dati_ca['num'] ; $num2++) {
 if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$num2]['id']] == "SI") {
+if ($dati_ca[$num2]['combina'] != "s" and $dati_ca[$num2]['raggruppa'] != "s") {
 $ncostiagg++;
 if ($costo_presente[$n_t][$dati_ca[$num2]['id']] == "SI") {
 $tasto_prenota .= "<input type=\"hidden\" name=\"costoagg$ncostiagg"."_$n_t\" value=\"SI\">
 <input type=\"hidden\" name=\"numsettimane$ncostiagg"."_$n_t\" value=\"".$numsettimane[$n_t][$dati_ca[$num2]['id']]."\">
 <input type=\"hidden\" name=\"nummoltiplica_ca$ncostiagg"."_$n_t\" value=\"".$nummoltiplica_ca[$n_t][$dati_ca[$num2]['id']]."\">";
 } # fine if ($costo_presente[$dati_ca[$num2]['id']] == "SI")
+} # fine if ($dati_ca[$num2]['combina'] != "s" and $dati_ca[$num2]['raggruppa'] != "s")
+else {
+if ($costo_presente[$n_t][$dati_ca[$num2]['id']] == "SI") {
+$tasto_prenota .= "<input type=\"hidden\" name=\"gr_idcostoagg".$dati_ca[$num2]['id']."_$n_t\" value=\"SI\">
+<input type=\"hidden\" name=\"gr_numsettimane".$dati_ca[$num2]['id']."_$n_t\" value=\"".$numsettimane[$n_t][$dati_ca[$num2]['id']]."\">
+<input type=\"hidden\" name=\"gr_nummoltiplica_ca".$dati_ca[$num2]['id']."_$n_t\" value=\"".$nummoltiplica_ca[$n_t][$dati_ca[$num2]['id']]."\">";
+} # fine if ($costo_presente[$dati_ca[$num2]['id']] == "SI")
+} # fine else if ($dati_ca[$num2]['combina'] != "s" and $dati_ca[$num2]['raggruppa'] != "s")
 } # fine if ($attiva_costi_agg_consentiti == "n" or...
 } # fine for $num2
 } # fine for $n_t
