@@ -521,12 +521,12 @@ $idregole = risul_query($regole2,$num3,'idregole');
 $lista_app = ",".risul_query($regole2,$num3,'motivazione').",";
 if (str_replace(",$idappartamenti,","",$lista_app) != $lista_app) {
 $lista_app = substr(str_replace(",$idappartamenti,",",$n_nome_app,",$lista_app),1,-1);
-esegui_query("update $tableregole set motivazione = '".aggslashdb($lista_app)."' where idregole = '$idregole' ");
+esegui_query("update $tableregole_cambia set motivazione = '".aggslashdb($lista_app)."' where idregole = '$idregole' ");
 } # fine (str_replace(",$idappartamenti,","",$lista_app) != $lista_app)
 $lista_app2 = ",".risul_query($regole2,$num3,'motivazione2').",";
 if (str_replace(",$idappartamenti,","",$lista_app2) != $lista_app2) {
 $lista_app2 = substr(str_replace(",$idappartamenti,",",$n_nome_app,",$lista_app2),1,-1);
-esegui_query("update $tableregole set motivazione2 = '".aggslashdb($lista_app2)."' where idregole = '$idregole' ");
+esegui_query("update $tableregole_cambia set motivazione2 = '".aggslashdb($lista_app2)."' where idregole = '$idregole' ");
 } # fine (str_replace(",$idappartamenti,","",$lista_app2) != $lista_app2)
 } # fine for $num3
 } # fine for $num2
@@ -869,7 +869,7 @@ for ($num1 = 1 ; $num1 <= $num_foto ; $num1++) {
 $url_foto = risul_query($foto,($num1 - 1),'testo');
 $numfoto = risul_query($foto,($num1 - 1),'numero');
 echo "<table><tr><td valign=\"top\">$num1.</td><td>
-<a href=\"$url_foto\"><img style=\"border: 0px none ; text-decoration: none;\" src=\"$url_foto\" alt=\"".htmlspecialchars($url_foto)."\"></a>
+<a href=\"$url_foto\"><img class=\"dphoto\" style=\"border: 0px none ; text-decoration: none;\" src=\"$url_foto\" alt=\"".htmlspecialchars($url_foto)."\"></a>
 </td><td style=\"width: 20px;\"></td><td>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div class=\"linhbox\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
