@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -169,7 +169,7 @@ for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 $altre_tab_lock[$num_lock] = $PHPR_TAB_PRE."soldi".risul_query($anni,$num1,'idanni');
 $num_lock++;
 } # fine for $num1
-$tabelle_lock = array("$tableclienti");
+$tabelle_lock = array($tableclienti,$tablerelclienti);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $cliente_esistente = esegui_query("select cognome,idclienti_compagni from $tableclienti where idclienti = '$idclienti' ");
 if (numlin_query($cliente_esistente) == 1) {
@@ -220,6 +220,11 @@ esegui_query("update $tableclienti set idclienti_compagni = '$idclienti_compagni
 } # fine for $num1
 } # fine if ($clienti_compagni)
 esegui_query("delete from $tableclienti where idclienti = '$idclienti' ");
+esegui_query("delete from $tablerelclienti where idclienti = '$idclienti' ");
+if (defined('C_URL_MOD_EXT_CARTE_CREDITO') and C_URL_MOD_EXT_CARTE_CREDITO != "") {
+if (substr(C_URL_MOD_EXT_CARTE_CREDITO,0,17) == "https://localhost") $ext_html = file(C_URL_MOD_EXT_CARTE_CREDITO."modifica_cliente.php?id_sessione=$id_sessione&idclienti=$idclienti&cancella_cliente=SI",false,stream_context_create(array("ssl" => array("verify_peer" => true,"allow_self_signed" => true))));
+else $ext_html = @file(C_URL_MOD_EXT_CARTE_CREDITO."modifica_cliente.php?id_sessione=$id_sessione&idclienti=$idclienti&cancella_cliente=SI");
+} # fine if (defined('C_URL_MOD_EXT_CARTE_CREDITO') and C_URL_MOD_EXT_CARTE_CREDITO != "")
 echo mex("Cliente cancellato",$pag)."!<br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"".htmlspecialchars($origine)."\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -790,10 +795,33 @@ if ($vedi_cc) {
 if (function_exists('openssl_pkey_new')) {
 if ($_SERVER["HTTPS"] == "on" or $_SERVER["SERVER_PORT"] == "443" or $_SERVER['SERVER_NAME'] == "localhost") {
 
-$cert_cc = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'cert_cc' and idutente = '1'");
+$cert_cc = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'cert_cc' and idutente = '1'");
 if (numlin_query($cert_cc)) {
 $mostra_form_modifica_cliente = "NO";
 
+
+$pass_scaduta = 0;
+if (defined('C_GIORNI_SCADENZA_PASS_CC') and C_GIORNI_SCADENZA_PASS_CC > 0) {
+$creazione_pass = risul_query($cert_cc,0,'valpersonalizza_num');
+$limite_pass_vecchie = date("YmdH",(time() - (C_GIORNI_SCADENZA_PASS_CC * 86400) + (C_DIFF_ORE * 3600)));
+if ($limite_pass_vecchie > $creazione_pass) {
+$pass_scaduta = 1;
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./personalizza.php\" target=\"_top\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"id_utente_mod\" value=\"$id_utente_mod\">
+<input type=\"hidden\" name=\"aggiorna_qualcosa\" value=\"SI\">
+<input type=\"hidden\" name=\"cambia_pass_cc\" value=\"1\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
+".ucfirst(mex("password per la visualizzazione dei dati delle carte di credito",'personalizza.php'))." <b class=\"colwarn\">".mex("scaduta",$pag)."</b>. ";
+if ($id_utente == 1) echo mex("Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password",$pag).". <button class=\"edtm\" type=\"submit\"><div>".ucfirst(mex("cambia la password",'personalizza.php'))."</div></button>";
+else echo mex("Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password",$pag).".";
+echo "</div></form><br><br>";
+} # fine if ($limite_pass_vecchie > $creazione_pass)
+} # fine if (defined('C_GIORNI_SCADENZA_PASS_CC') and C_GIORNI_SCADENZA_PASS_CC > 0)
+if (!$pass_scaduta) {
+
+
 $gest_cvc = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'gest_cvc' and idutente = '1'");
 $gest_cvc = risul_query($gest_cvc,0,'valpersonalizza');
 
@@ -991,6 +1019,8 @@ else echo "".ucfirst(mex("password errata",$pag)).".<br>";
 } # fine else if (!$pass_cc)
 } # fine else if ($tipo_transazione == "mo_cc")
 
+
+} # fine if (!$pass_scaduta)
 echo "<br><br><div style=\"text-align: center;\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -1087,18 +1117,31 @@ $d_campi_pers['esist'][$d_campi_pers[$num1]['nome']] = 1;
 echo "<table cellspacing=0 cellpadding=0 border=0 width=\"97%\">
 <tr><td align=\"right\" style=\"font-size: 80%;\">";
 $pass_cc = 0;
+if (defined('C_URL_MOD_EXT_CARTE_CREDITO') and C_URL_MOD_EXT_CARTE_CREDITO != "") {
+$action_cc = C_URL_MOD_EXT_CARTE_CREDITO.$pag;
+$d_cliente = "<input type=\"hidden\" name=\"d_cognome\" value=\"".htmlspecialchars($d_cognome)."\">
+<input type=\"hidden\" name=\"d_nome\" value=\"".htmlspecialchars($d_nome)."\">";
+if (substr(C_URL_MOD_EXT_CARTE_CREDITO,0,17) == "https://localhost") $ext_html = file(C_URL_MOD_EXT_CARTE_CREDITO."personalizza.php?id_sessione=$id_sessione&stato_cc=1",false,stream_context_create(array("ssl" => array("verify_peer" => true,"allow_self_signed" => true))));
+else $ext_html = @file(C_URL_MOD_EXT_CARTE_CREDITO."personalizza.php?id_sessione=$id_sessione&stato_cc=1");
+if ($ext_html and strstr(implode("",$ext_html),"pass_cc_attiva")) $pass_cc = 1;
+} # fine if (defined('C_URL_MOD_EXT_CARTE_CREDITO') and C_URL_MOD_EXT_CARTE_CREDITO != "")
+else {
+$action_cc = $pag;
+$d_cliente = "";
 if (function_exists('openssl_pkey_new')) {
 $cert_cc = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'cert_cc' and idutente = '1'");
 if (numlin_query($cert_cc)) $pass_cc = 1;
 } # fine if (function_exists('openssl_pkey_new'))
+} # fine else if (defined('C_URL_MOD_EXT_CARTE_CREDITO') and C_URL_MOD_EXT_CARTE_CREDITO != "")
 if ($pass_cc) {
-echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$action_cc\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idclienti\" value=\"$idclienti\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
 <input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
-<input type=\"hidden\" name=\"vedi_cc\" value=\"SI\">";
+<input type=\"hidden\" name=\"vedi_cc\" value=\"SI\">
+$d_cliente";
 } # fine if ($pass_cc)
 echo "<small>".ucfirst(mex("data inserimento",$pag)).": ".str_replace("--","",formatta_data($d_data_inserimento_vedi,$stile_data))."</small>";
 if ($pass_cc) {
