@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -35,6 +35,7 @@ $tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
 $tableanni = $PHPR_TAB_PRE."anni";
 $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 $tablecontratti = $PHPR_TAB_PRE."contratti";
+$tableutenti = $PHPR_TAB_PRE."utenti";
 
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
@@ -51,6 +52,7 @@ $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where id
 $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
 if (substr($priv_mod_pers,0,1) != "s") $modifica_pers = "NO";
 $priv_mod_doc = substr($priv_mod_pers,2,1);
+$priv_mod_doc_api = substr($priv_mod_pers,4,1);
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 if ($attiva_contratti_consentiti == "s") {
@@ -63,11 +65,18 @@ for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_
 else {
 $anno_utente_attivato = "SI";
 $priv_mod_doc = "s";
+$priv_mod_doc_api = "s";
 $attiva_contratti_consentiti = "n";
 } # fine else if ($id_utente != 1)
 
 if ($anno_utente_attivato == "SI" and $priv_mod_doc == "s" and $modifica_pers != "NO" and ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[(integer) $num_contratto] == "SI")) {
 
+if ($priv_mod_doc_api != "s") {
+$api_esistente = esegui_query("select * from $tablecontratti where numero = '".aggslashdb($num_contratto)."' and tipo = 'api'");
+if (numlin_query($api_esistente)) $priv_mod_doc = "n";
+} # fine if ($priv_mod_doc_api != "s")
+if ($priv_mod_doc == "s") {
+
 
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
@@ -343,6 +352,61 @@ echo "".mex("I file verranno salvati con il nome",$pag)." \"$nome_file_salva\".<
 unlock_tabelle($tabelle_lock);
 } # fine if ($cambia_nome_file)
 
+if ($priv_mod_doc_api == "s" and ($cambia_cons_api or strcmp($pass_api,"") or $id_utente_api)) {
+$tabelle_lock = array($tablecontratti);
+$altre_tab_lock = array($tableutenti);
+$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+$tipo_contratto = esegui_query("select tipo from $tablecontratti where numero = '$num_contratto' and tipo $LIKE 'contr%'");
+$tipo_contratto = risul_query($tipo_contratto,0,'tipo');
+if ($tipo_contratto == "contrrtf" or $tipo_contratto == "contrhtm" or $tipo_contratto == "contrtxt") {
+$api_esistente = esegui_query("select testo from $tablecontratti where numero = '$num_contratto' and tipo = 'api' ");
+if (strcmp($pass_api,"") or $id_utente_api) {
+if (numlin_query($api_esistente)) {
+$pass_api_esist = risul_query($api_esistente,0,'testo');
+$id_utente_api_esist = explode(";",$pass_api_esist);
+$id_utente_api_esist = $id_utente_api_esist[0];
+$pass_api_esist = substr($pass_api_esist,(strlen($id_utente_api_esist) + 1));
+if (strcmp($pass_api,"")) {
+$mostra_form_iniziale = "NO";
+if (@get_magic_quotes_gpc()) $pass_api = stripslashes($pass_api);
+$pass_api = aggslashdb($pass_api);
+esegui_query("update $tablecontratti set testo = '$id_utente_api_esist;$pass_api' where numero = '$num_contratto' and tipo = 'api' ");
+echo mex("La password per la API del documento è stata cambiata",$pag).".<br>";
+} # fine if (strcmp($pass_api,""))
+if ($id_utente_api and ($id_utente == 1 or $id_utente_api == $id_utente)) {
+$utente_esistente = esegui_query("select nome_utente from $tableutenti where idutenti = '".aggslashdb($id_utente_api)."' ");
+if (numlin_query($utente_esistente)) {
+$mostra_form_iniziale = "NO";
+esegui_query("update $tablecontratti set testo = '$id_utente_api;$pass_api_esist' where numero = '$num_contratto' and tipo = 'api' ");
+echo mex("L'utente per la API del documento è stato cambiato",$pag).".<br>";
+} # fine if (numlin_query($utente_esistente))
+} # fine if ($id_utente_api and ($id_utente == 1 or $id_utente_api == $id_utente))
+} # fine if (numlin_query($api_esistente))
+} # fine if (strcmp($pass_api,"") or $id_utente_api)
+else {
+if ($cons_api == "SI") {
+if (!numlin_query($api_esistente)) {
+$mostra_form_iniziale = "NO";
+$valori = "23456789ABCDEFGHJKLMNPQRSTUVWXZabcdefghijkmnpqrstuvwxyz";
+srand((double)microtime() * 1000000);
+unset($pass_generata);
+for ($num1 = 0 ; $num1 < 8 ; $num1++) $pass_generata .= substr($valori,rand(0,54),1);
+esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_contratto','api','1;$pass_generata')");
+echo "".mex("Il documento verrà considerato come una API",$pag)." $dir_salva.<br>";
+} # fine if (!numlin_query($api_esistente))
+} # fine if ($cons_api == "SI")
+else {
+if (numlin_query($api_esistente)) {
+$mostra_form_iniziale = "NO";
+esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'api' ");
+echo mex("Il documento non verrà più considerato come una API",$pag).".<br>";
+} # fine if (numlin_query($api_esistente))
+} # fine else if ($cons_api == "SI")
+} # fine else if (strcmp($pass_api,"") or $id_utente_api)
+} # fine if ($tipo_contratto == "contrrtf" or..
+unlock_tabelle($tabelle_lock);
+} # fine if ($priv_mod_doc_api == "s" and ($cambia_cons_api or strcmp($pass_api,"") or $id_utente_api))
+
 if ($cambia_intestazione_pers) {
 $tipo_contratto = esegui_query("select tipo from $tablecontratti where numero = '$num_contratto' and tipo $LIKE 'contr%'");
 $tipo_contratto = risul_query($tipo_contratto,0,'tipo');
@@ -825,6 +889,7 @@ echo "</label><input type=\"text\" name=\"nuova_dir_salva\" size=\"20\" value=\"
 </div></form>";
 
 if ($checked) {
+$salv_contr = 1;
 echo "<table cellspacing=\"0\" cellpadding=\"0\"><tr><td style=\"width: 50px;\"></td><td>";
 
 $compress = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'compress' ");
@@ -943,8 +1008,114 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 </td></tr></table></div></form>
 </td></tr></table>";
 } # fine if ($checked)
-
+else $salv_contr = 0;
 echo "<br>";
+
+
+if ($priv_mod_doc_api == "s") {
+$api_esistente = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'api'");
+if (numlin_query($api_esistente)) $checked = " checked";
+else $checked = "";
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"num_contratto\" value=\"$num_contratto\">
+<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
+<label><input type=\"checkbox\" id=\"capi\" name=\"cons_api\" value=\"SI\"$checked>
+".mex("Considera questo documento come una API",$pag)."</label>
+<input class=\"sbutton\" type=\"submit\" name=\"cambia_cons_api\" value=\"".mex("Cambia",$pag)."\">
+</div></form>";
+if ($checked) {
+$pass_api = risul_query($api_esistente,0,'testo');
+$id_utente_api = explode(";",$pass_api);
+$id_utente_api = $id_utente_api[0];
+$pass_api = substr($pass_api,(strlen($id_utente_api) + 1));
+echo "<table cellspacing=\"0\" cellpadding=\"0\"><tr><td style=\"width: 50px;\"></td><td>
+<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div style=\"padding-top: 6px;\">
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"num_contratto\" value=\"$num_contratto\">
+<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
+".mex("Password",$pag).": <input type=\"text\" name=\"pass_api\" size=\"12\" maxlength=\"60\" value=\"$pass_api\">
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("Cambia",$pag)."\">
+</div></form>
+<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div style=\"padding-top: 6px;\">
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"num_contratto\" value=\"$num_contratto\">
+<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
+".mex("Mostra il documento come visto dall'utente",$pag).": <select name=\"id_utente_api\">";
+$lista_utenti = esegui_query("select idutenti,nome_utente from $tableutenti order by idutenti");
+for ($num1 = 0 ; $num1 < numlin_query($lista_utenti) ; $num1++) {
+$id = risul_query($lista_utenti,$num1,'idutenti');
+if ($id_utente == 1 or $id == $id_utente or $id == $id_utente_api) {
+$nome = risul_query($lista_utenti,$num1,'nome_utente');
+if ($id == $id_utente_api) $sel = " selected";
+else $sel = "";
+echo "<option value=\"$id\"$sel>$nome</option>";
+} # fine if ($id_utente == 1 or $id == $id_utente or $id == $id_utente_api)
+} # fine for $num1
+echo "</select>
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("Cambia",$pag)."\">
+</div></form>";
+if ($salv_contr) echo "<div style=\"padding-top: 6px;\"><em class=\"colblu\">".mex("Nota",$pag)."</em>: ".mex("i documenti esistenti non verranno mai sovrascritti, ogni volta che si chiama la API verrà salvato un nuovo documento",$pag).".</div>";
+$link_api = "";
+if (defined('C_FILE_DOMINIO') and C_FILE_DOMINIO != "" and C_NASCONDI_MARCA != "SI") {
+$altri_domini = @file(C_FILE_DOMINIO);
+if ($altri_domini) {
+$link_api = "https://".trim($altri_domini[0])."/";
+if (defined('C_DOMINIO_ADMIN_DIR') and C_DOMINIO_ADMIN_DIR != "") $link_api .= C_DOMINIO_ADMIN_DIR."/";
+} # fine if ($altri_domini)
+} # fine if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and C_NASCONDI_MARCA != "SI")
+if (!$link_api) {
+if (@$SERVER_NAME or @$_SERVER['SERVER_NAME'] or @$HTTP_SERVER_VARS['SERVER_NAME']) {
+if (@$PHP_SELF or @$_SERVER['PHP_SELF']) {
+if ($_SERVER['SERVER_NAME']) $SERVER_NAME = $_SERVER['SERVER_NAME'];
+elseif ($HTTP_SERVER_VARS['SERVER_NAME']) $SERVER_NAME = $HTTP_SERVER_VARS['SERVER_NAME'];
+if ($_SERVER['PHP_SELF']) $PHP_SELF = $_SERVER['PHP_SELF'];
+if (substr($PHP_SELF,0,1) != "/") $PHP_SELF = "/".$PHP_SELF;
+$link_api = "https://".$SERVER_NAME.$PHP_SELF;
+if (substr($link_api,(strlen($pag) * -1)) == $pag) $link_api = substr($link_api,0,(strlen($pag) * -1));
+if (substr($link_api,-4) == ".php") {
+$url_vett1 = explode("/",$link_api);
+$link_api = substr($link_api,0,(strlen($url_vett1[(count($url_vett1) - 1)]) * -1));
+} # fine if (substr($link_api,-4) == ".php")
+} # fine if (@$PHP_SELF or @$_SERVER['PHP_SELF'])
+} # fine if (@$SERVER_NAME or @$_SERVER['SERVER_NAME'] or...
+} # fine if (!$link_api)
+$link_api .= "api.php";
+$sec_oggi = time() + (C_DIFF_ORE * 3600);
+$oggi = date("Y-m-d",$sec_oggi);
+$dopodomani = date("Y-m-d",($sec_oggi + 172800));
+$altroieri = date("Y-m-d",($sec_oggi - 172800));
+$link1 = "$link_api?doc=$num_contratto&pass=$pass_api&res_year=$anno";
+$link2 = "$link_api?doc=$num_contratto&pass=$pass_api&res_from=$oggi&res_to=$dopodomani";
+$link3 = "$link_api?doc=$num_contratto&pass=$pass_api&res_num=2-5";
+$link4 = "$link_api?doc=$num_contratto&pass=$pass_api&res_ins_from=$altroieri&res_ins_to=$oggi";
+$link5 = "$link_api?doc=$num_contratto&pass=$pass_api&res_arr=$oggi";
+$link6 = "$link_api?doc=$num_contratto&pass=$pass_api&res_dep=today";
+$link7 = "$link_api?doc=$num_contratto&pass=$pass_api&clients=all";
+$link8 = "$link_api?doc=$num_contratto&pass=$pass_api&clients=guests";
+echo "<div style=\"padding-top: 4px;\"></div>
+<table class=\"rbox\" cellspacing=0 cellpadding=0><tr><td>
+<div style=\"padding-top: 4px;\"><em>".mex("Esempi di URL per chiamare il documento",$pag)."</em>:</div>
+<div style=\"padding-top: 4px;\">".mex("Tutte le prenotazioni dell'anno",$pag)." $anno: <input type=\"text\" readonly onClick=\"this.select();\" value=\"$link1\" size=\"".(strlen($link1) + 1)."\"></div>
+<div style=\"padding-top: 6px;\"><em>".mex("Nota",$pag)."</em>: ".mex("se la variabile",$pag)." <em>res_year</em> ".mex("non è presente nella URL allora verranno usate le prenotazioni dell'anno corrente",$pag).".</div>
+<div style=\"padding-top: 6px;\">".mex("Tutte le prenotazioni presenti dal",$pag)." ".formatta_data($oggi,$stile_data)." ".mex("al",$pag)." ".formatta_data($dopodomani,$stile_data).": <input type=\"text\" readonly onClick=\"this.select();\" value=\"$link2\" size=\"".(strlen($link2) + 1)."\"></div>
+<div style=\"padding-top: 6px;\"><em>".mex("Nota",$pag)."</em>: ".mex("si possono usare anche le parole",$pag)." <em>today</em>, <em>tomorrow</em> ".mex("e",$pag)." <em>yesterday</em> ".mex("come date",$pag).".</div>
+<div style=\"padding-top: 6px;\">".mex("Tutte le prenotazioni con numero dal",$pag)." 2 ".mex("al",$pag)." 5: <input type=\"text\" readonly onClick=\"this.select();\" value=\"$link3\" size=\"".(strlen($link3) + 1)."\"></div>
+<div style=\"padding-top: 6px;\">".mex("Altri esempi dell'uso della variabile",$pag)." <em>res_num</em>: <em>res_num=3</em> / <em>res_num=3-</em> / <em>res_num=3,7</em> / <em>res_num=3,6-9</em></div>
+<div style=\"padding-top: 6px;\">".mex("Tutte le prenotazioni inserite dal",$pag)." ".formatta_data($altroieri,$stile_data)." ".mex("al",$pag)." ".formatta_data($oggi,$stile_data).": <input type=\"text\" readonly onClick=\"this.select();\" value=\"$link4\" size=\"".(strlen($link4) + 1)."\"></div>
+<div style=\"padding-top: 6px;\">".mex("Tutti gli arrivi del",$pag)." ".formatta_data($oggi,$stile_data).": <input type=\"text\" readonly onClick=\"this.select();\" value=\"$link5\" size=\"".(strlen($link5) + 1)."\"></div>
+<div style=\"padding-top: 6px;\">".mex("Tutti le partenze del",$pag)." ".formatta_data($oggi,$stile_data).": <input type=\"text\" readonly onClick=\"this.select();\" value=\"$link6\" size=\"".(strlen($link6) + 1)."\"></div>
+<div style=\"padding-top: 6px;\">".mex("Tutti i clienti",$pag)." (".mex("escludendo gli ospiti",$pag)."): <input type=\"text\" readonly onClick=\"this.select();\" value=\"$link7\" size=\"".(strlen($link7) + 1)."\"></div>
+<div style=\"padding-top: 6px;\">".mex("Tutti i clienti",$pag)." (".mex("inclusi gli ospiti",$pag)."): <input type=\"text\" readonly onClick=\"this.select();\" value=\"$link8\" size=\"".(strlen($link8) + 1)."\"></div>
+</td></tr></table>
+</td></tr></table>";
+} # fine if ($checked)
+echo "<br>";
+} # fine if ($priv_mod_doc_api == "s")
+
 } # fine if ($tipo_contratto == "rtf" or $tipo_contratto == "htm" or...
 
 
@@ -1346,6 +1517,7 @@ if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$t
 else include("./includes/foot.php");
 
 
+} # fine if ($priv_mod_doc == "s")
 } # fine if ($anno_utente_attivato == "SI" and $priv_mod_doc == "s" and...
 } # fine if ($id_utente)
 
