@@ -838,6 +838,7 @@ else { $checked_p = " checked"; $checked_t = ""; }
 ".mex("considerare l'intero costo come tasse",'creaprezzi.php')."</label>
 </td></tr>
 
+
 <tr><td style=\"height: 2px;\"></td></tr>
 <tr><td valign=\"top\">
 <small>5. </small>".mex("Assegna automaticamente con le tariffe",$pag).":</td><td>
@@ -853,7 +854,37 @@ else elem_valminmax2.innerHTML = ' ".mex("e",$pag)." <input type=\"text\" name=\
 </script>
 ";
 $default_tipo_associa = "p";
-for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) if ($dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa]) $default_tipo_associa = $dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa];
+$default_minmax = substr($dati_ca[$num_costo]['tariffa1'],0,1);
+$default_valminmax = substr($dati_ca[$num_costo]['tariffa1'],1);
+if ($default_minmax == "|") {
+$default_valminmax = explode("<",$default_valminmax);
+$default_valminmax2 = $default_valminmax[1];
+$default_valminmax = $default_valminmax[0];
+} # fine if ($default_minmax == "|") 
+else $default_valminmax2 = "";
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+if ($dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa]) $default_tipo_associa = $dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa];
+$minmax = substr($dati_ca[$num_costo]["tariffa".$numtariffa],0,1);
+if ($minmax and $default_minmax != $minmax) $default_minmax = "";
+if ($default_minmax) {
+$valminmax = substr($dati_ca[$num_costo]["tariffa".$numtariffa],1);
+if ($default_minmax == "|") {
+$valminmax = explode("<",$valminmax);
+$valminmax2 = $valminmax[1];
+$valminmax = $valminmax[0];
+} # fine if ($default_minmax == "|")
+if (($valminmax and $valminmax != $default_valminmax) or ($valminmax2 and $valminmax2 != $default_valminmax2)) {
+$default_minmax = "";
+$default_valminmax = "";
+$default_valminmax2 = "";
+} # fine if (($valminmax and $valminmax != $default_valminmax) or ($valminmax2 and $valminmax2 != $default_valminmax2))
+} # fine if ($default_minmax)
+else {
+$default_valminmax = "";
+$default_valminmax2 = "";
+} # fine else if ($default_minmax)
+} # fine for $numtariffa
+
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
 if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI") {
 $tariffa = "tariffa".$numtariffa;
@@ -868,16 +899,18 @@ else { $checked = ""; $b = ""; $b_slash = ""; }
 echo "<table cellspacing=0 cellpadding=0><tr><td valign=\"middle\"><label>
 <input type=\"checkbox\" name=\"sel$tariffa\" value=\"s\"$checked>$b"."$nometariffa_vedi$b_slash</label></td>";
 echo "<td>&nbsp;(<select name=\"minmax$tariffa\" id=\"minmax$tariffa\" onchange=\"agg_sel_giorni_associa_tariffa('$tariffa','')\">";
-if (!${"minmax".$tariffa}) $selected = " selected";
+$minmax = substr($dati_ca[$num_costo]["tariffa".$numtariffa],0,1);
+if (!$minmax and $default_minmax) $minmax = $default_minmax;
+if (!$minmax) $selected = " selected";
 else $selected = "";
 echo "<option value=\"\"$selected>----</option>";
-if (substr($dati_ca[$num_costo]["tariffa".$numtariffa],0,1) == ">") $selected = " selected";
+if ($minmax == ">") $selected = " selected";
 else $selected = "";
 echo "<option value=\"min\"$selected>".mex("minimo",$pag)."</option>";
-if (substr($dati_ca[$num_costo]["tariffa".$numtariffa],0,1) == "<") $selected = " selected";
+if ($minmax == "<") $selected = " selected";
 else $selected = "";
 echo "<option value=\"max\"$selected>".mex("massimo",$pag)."</option>";
-if (substr($dati_ca[$num_costo]["tariffa".$numtariffa],0,1) == "=") $selected = " selected";
+if ($minmax == "=") $selected = " selected";
 else $selected = "";
 echo "<option value=\"eq\"$selected>".mex("esattamente",$pag)."</option>
 </select>";
@@ -887,6 +920,8 @@ $valminmax = explode("<",$valminmax);
 $valminmax2 = $valminmax[1];
 $valminmax = $valminmax[0];
 } # fine if (substr($dati_ca[$num_costo]["tariffa".$numtariffa],0,1) == "|")
+if (!$valminmax and $default_valminmax) $valminmax = $default_valminmax;
+if (!$valminmax2 and $default_valminmax2) $valminmax2 = $default_valminmax2;
 echo "<input type=\"text\" name=\"valminmax$tariffa\" value=\"$valminmax\" size=\"3\">
 <span id=\"valminmax2$tariffa\"></span>".mex("$parola_settimane",$pag).")
 <script type=\"text/javascript\">
@@ -897,7 +932,7 @@ n_opt_sel_corr.text = '".mex("tra",$pag)."';
 n_opt_sel_corr.value = 'tra';
 sel_corr.add(n_opt_sel_corr,null);
 ";
-if (substr($dati_ca[$num_costo]["tariffa".$numtariffa],0,1) == "|") echo "sel_corr.selectedIndex = 4;
+if ($minmax == "|") echo "sel_corr.selectedIndex = 4;
 agg_sel_giorni_associa_tariffa('$tariffa','$valminmax2');
 ";
 echo "-->
@@ -920,6 +955,7 @@ echo "</tr><tr><td style=\"height: 5px;\"></td></tr></table>";
 } # fine for $numtariffa
 echo "</td></tr>
 
+
 <tr><td colspan=\"2\"><small>6. ";
 if ($dati_ca[$num_costo]['assegna_da_ini_prenota']) $checked = " checked";
 else $checked = "";
