@@ -50,6 +50,7 @@ $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where id
 $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
 if (substr($priv_mod_pers,0,1) != "s") $modifica_pers = "NO";
 $priv_mod_doc = substr($priv_mod_pers,2,1);
+$priv_mod_doc_api = substr($priv_mod_pers,4,1);
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 if ($attiva_contratti_consentiti == "s") {
@@ -62,6 +63,7 @@ for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_
 else {
 $anno_utente_attivato = "SI";
 $priv_mod_doc = "s";
+$priv_mod_doc_api = "s";
 $attiva_contratti_consentiti = "n";
 } # fine else if ($id_utente != 1)
 
@@ -82,6 +84,10 @@ if ($attiva_contratti_consentiti != "n" and $contratti_consentiti_vett[$contr_co
 if (strcmp($contr_cond,"")) {
 $contr_cond_esist = esegui_query("select numero from $tablecontratti where numero = '".aggslashdb($contr_cond)."' and tipo $LIKE 'contr%' ");
 if (numlin_query($contr_cond_esist) != 1) $contr_cond = "";
+elseif ($priv_mod_doc_api != "s") {
+$api_esistente = esegui_query("select * from $tablecontratti where numero = '".aggslashdb($contr_cond)."' and tipo = 'api'");
+if (numlin_query($api_esistente)) $contr_cond = "";
+} # fine elseif ($priv_mod_doc_api != "s")
 } # fine if (strcmp($contr_cond,""))
 
 unset($trad_var);
@@ -507,14 +513,18 @@ if ($azione == "set") {
 if ($oper_str != "=" and $oper_str != ".=") $continua = "NO";
 controlla_var_allora($var_allora,$continua,$contr_cond);
 if ($tipo_val_allora != "txt" and $tipo_val_allora != "var") $continua = "NO";
-if ($tipo_val_allora == "txt") $val_allora = controlla_testo_input($val_allora_txt);
+if ($tipo_val_allora == "txt") {
+$val_allora = controlla_testo_input($val_allora_txt);
+$oper_allora_sel = "";
+} # fine if ($tipo_val_allora == "txt")
 else $val_allora = controlla_var_se($val_allora_sel,$continua,$var_predef,$num_var_predef,$contr_cond);
+if ($oper_allora_sel != "" and $oper_allora_sel != "low" and $oper_allora_sel != "upp" and $oper_allora_sel != "url" and $oper_allora_sel != "asc" and $oper_allora_sel != "eas" and $oper_allora_sel != "md5") $continua = "NO";
 if ($tipo_val_sost1 != "txt" and $tipo_val_sost1 != "var") $continua = "NO";
 if ($tipo_val_sost1 == "txt") $val_sost1 = controlla_testo_input($val_sost1_txt);
 else $val_sost1 = controlla_var_se($val_sost1_sel,$continua,$var_predef,$num_var_predef,$contr_cond);
 if ($tipo_val_sost2 == "txt") $val_sost2 = controlla_testo_input($val_sost2_txt);
 else $val_sost2 = controlla_var_se($val_sost2_sel,$continua,$var_predef,$num_var_predef,$contr_cond);
-$testo .= "set#%?$var_allora#%?$oper_str#%?$tipo_val_allora#%?$val_allora#%?$tipo_val_sost1#%?$val_sost1#%?$tipo_val_sost2#%?$val_sost2";
+$testo .= "set#%?$var_allora#%?$oper_str#%?$tipo_val_allora#%?$val_allora#%?$tipo_val_sost1#%?$val_sost1#%?$tipo_val_sost2#%?$val_sost2#%?$oper_allora_sel";
 } # fine if ($azione == "set")
 if ($azione == "trunc") {
 controlla_var_allora($var_trunc,$continua,$contr_cond);
@@ -790,6 +800,12 @@ $opt_contr = "<option value=\"\"$sel>".mex("a tutti i documenti",$pag)."</option
 for ($num1 = 0 ; $num1 < $num_contratti ; $num1++) {
 $num_contr = risul_query($contratti,$num1,'numero');
 if ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$num_contr] == "SI") {
+$mod_doc_corr = 1;
+if ($priv_mod_doc_api != "s") {
+$api_esistente = esegui_query("select * from $tablecontratti where numero = '".aggslashdb($num_contr)."' and tipo = 'api'");
+if (numlin_query($api_esistente)) $mod_doc_corr = 0;
+} # fine if ($priv_mod_doc_api != "s")
+if ($mod_doc_corr) {
 if ($contr_cond == $num_contr) {
 $sel = " selected";
 $frase_cond_contr = mex("al documento",$pag)." $num_contr";
@@ -800,6 +816,7 @@ else $sel = "";
 $opt_contr .= "<option value=\"$num_contr\"$sel>".mex("al documento",$pag)." $num_contr";
 if ($nome_contratto[$num_contr]) $opt_contr .= " (".$nome_contratto[$num_contr].")";
 $opt_contr .= "</option>";
+} # fine if ($mod_doc_corr)
 } # fine if ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$num_contr] == "SI")
 } # fine for $num1
 echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
@@ -945,7 +962,15 @@ if ($azione[0] == "set") {
 $str_cond .= mex("porre",$pag)." [".$nome_var[$azione[1]]."] ";
 if ($azione[2] == "=") $str_cond .= mex("uguale a",$pag);
 if ($azione[2] == ".=") $str_cond .= mex("concatenato con",$pag);
-if ($azione[3] == "var") $str_cond .= " [".mex2($azione[4])."]";
+if ($azione[3] == "var") {
+$str_cond .= " [".mex2($azione[4])."]";
+if ($azione[9] == "low") $str_cond .= " ".mex("in minuscole",$pag);
+if ($azione[9] == "upp") $str_cond .= " ".mex("in maiuscole",$pag);
+if ($azione[9] == "url") $str_cond .= " ".mex("codificato per URL",$pag);
+if ($azione[9] == "asc") $str_cond .= " ".mex("codificato in ASCII",$pag);
+if ($azione[9] == "eas") $str_cond .= " ".mex("in ASCII esteso",$pag);
+if ($azione[9] == "md5") $str_cond .= " ".mex("codificato con MD5",$pag);
+} # fine if ($azione[3] == "var")
 else $str_cond .= " \"".htmlspecialchars($azione[4])."\"";
 if (strcmp($azione[6],"")) {
 $str_cond .= " ".mex("sostituendo",$pag)." ";
@@ -967,6 +992,7 @@ else $val_sost1_txt = htmlspecialchars($azione[6]);
 $tipo_val_sost2 = $azione[7];
 if ($azione[7] == "var") $val_sost2_sel = $azione[8];
 else $val_sost2_txt = htmlspecialchars($azione[8]);
+$oper_allora_sel = $azione[9];
 } # fine if ($num_cond_mod == $num_cond)
 } # fine if ($azione[0] == "set")
 
@@ -1366,6 +1392,20 @@ if ($tipo_val_sost1 == "var") { $chk_var_s1 = " checked"; $chk_txt_s1 = ""; }
 else { $chk_var_s1 = ""; $chk_txt_s1 = " checked"; }
 if ($tipo_val_sost2 == "var") { $chk_var_s2 = " checked"; $chk_txt_s2 = ""; }
 else { $chk_var_s2 = ""; $chk_txt_s2 = " checked"; }
+$sel_oper_no = "";
+$sel_oper_low = "";
+$sel_oper_upp = "";
+$sel_oper_url = "";
+$sel_oper_asc = "";
+$sel_oper_eas = "";
+$sel_oper_md5 = "";
+if (!$oper_allora_sel) $sel_oper_no = " selected";
+if ($oper_allora_sel == "low") $sel_oper_low = " selected";
+if ($oper_allora_sel == "upp") $sel_oper_upp = " selected";
+if ($oper_allora_sel == "url") $sel_oper_url = " selected";
+if ($oper_allora_sel == "asc") $sel_oper_asc = " selected";
+if ($oper_allora_sel == "eas") $sel_oper_eas = " selected";
+if ($oper_allora_sel == "md5") $sel_oper_md5 = " selected";
 echo "<table onclick=\"document.getElementById('az_set').checked='1'\"><tr><td>
 <input type=\"radio\" id=\"az_set\" name=\"azione\" value=\"set\"$chk_az>
 </td><td><select name=\"oper_str\">
@@ -1381,6 +1421,14 @@ echo "<table onclick=\"document.getElementById('az_set').checked='1'\"><tr><td>
 </td></tr><tr><td><input type=\"radio\" id=\"val_all_sel\" name=\"tipo_val_allora\" value=\"var\"$chk_var></td><td>
 <select name=\"val_allora_sel\" onfocus=\"document.getElementById('val_all_sel').checked='1'\">
 ".str_replace("\"$val_allora_sel\">","\"$val_allora_sel\" selected>",$option_var_predef)."
+</select><select name=\"oper_allora_sel\" onfocus=\"document.getElementById('val_all_sel').checked='1'\">
+<option value=\"\"$sel_oper_no></option>
+<option value=\"low\"$sel_oper_low>".mex("in minuscole",$pag)."</option>
+<option value=\"upp\"$sel_oper_upp>".mex("in maiuscole",$pag)."</option>
+<option value=\"url\"$sel_oper_url>".mex("codificato per URL",$pag)."</option>
+<option value=\"asc\"$sel_oper_asc>".mex("codificato in ASCII",$pag)."</option>
+<option value=\"eas\"$sel_oper_eas>".mex("in ASCII esteso",$pag)."</option>
+<option value=\"md5\"$sel_oper_md5>".mex("codificato con MD5",$pag)."</option>
 </select></td></tr></table></td><td>
 (".str_replace(" ","&nbsp;",mex("sostituendo",$pag))."</td><td>
 <b style=\"font-size: 260%;\">{</b></td><td>
