@@ -91,6 +91,8 @@ $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
 $periodi = esegui_query("select * from $tableperiodi order by idperiodi");
 $dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
+$dati_r2 = "";
+dati_regole2($dati_r2,$app_regola2_predef,"","","",$id_periodo_corrente,$tipo_periodi,$anno,$tableregole);
 unlock_tabelle($tabelle_lock);
 
 $numero_tariffe = $dati_tariffe['num'];
@@ -262,6 +264,10 @@ for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
 if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI") {
 $tar_corr = (string) risul_query($periodi,($sett_in_per - 1),$tariffa[$num1]);
 $tarp_corr = (string) risul_query($periodi,($sett_in_per - 1),$tariffa[$num1]."p");
+if ($dati_r2['napp'][$tariffa[$num1]] > 1) {
+$tar_corr = (string) ((double) $tar_corr * (double) $dati_r2['napp'][$tariffa[$num1]]);
+$tarp_corr = (string) ((double) $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num1]]);
+} # fine if ($dati_r2['napp'][$tariffa[$num1]] > 1)
 if ($sett_in_per == 1 or (!strcmp($tar_corr,"") and !strcmp($tarp_corr,""))) {
 if ($sett_in_per == 1) $chiusa_colonna_periodo[$num1][0] = "";
 $tariffa_colonna_periodo[$num1][0] = $tar_corr;
@@ -291,6 +297,10 @@ for ($num2 = 1 ; $num2 <= $num_tariffe_mostra ; $num2++) {
 if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num2}] == "SI") {
 $tar_corr = (string) risul_query($periodi,$num1,$tariffa[$num2]);
 $tarp_corr = (string) risul_query($periodi,$num1,$tariffa[$num2]."p");
+if ($dati_r2['napp'][$tariffa[$num2]] > 1) {
+$tar_corr = (string) ((double) $tar_corr * (double) $dati_r2['napp'][$tariffa[$num2]]);
+$tarp_corr = (string) ((double) $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num2]]);
+} # fine if ($dati_r2['napp'][$tariffa[$num2]] > 1)
 if ($sett_in_per == 1 or (!strcmp($tar_corr,"") and !strcmp($tarp_corr,""))) {
 ${$tariffa[$num2]} = $tar_corr;
 ${$tariffa[$num2]."p"} = $tarp_corr;
@@ -454,7 +464,7 @@ for ($num1 = 1 ; $num1 <= $num_foto ; $num1++) {
 $url_foto = risul_query($foto,($num1 - 1),'testo');
 $numfoto = risul_query($foto,($num1 - 1),'numero');
 echo "<table><tr><td valign=\"top\">$num1.</td><td>
-<a href=\"$url_foto\"><img style=\"border: 0px none ; text-decoration: none;\" src=\"$url_foto\" alt=\"".htmlspecialchars($url_foto)."\"></a>
+<a href=\"$url_foto\"><img class=\"dphoto\" style=\"border: 0px none ; text-decoration: none;\" src=\"$url_foto\" alt=\"".htmlspecialchars($url_foto)."\"></a>
 </td><td style=\"width: 20px;\"></td><td>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div class=\"linhbox\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
