@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -226,13 +226,15 @@ $sessione_anno_var = "id_sessione=$id_sessione";
 if (substr($id_sessione,0,4) != $anno) $sessione_anno_var .= "&amp;anno=$anno";
 } # fine if ($id_sessione)
 else $sessione_anno_var = "anno=$anno";
+if ($mobile_device and strstr($_SERVER['HTTP_USER_AGENT'],'(iP')) $selfref = " href=\"#\"";
+else $selfref = "";
 
 echo "<td>
 <table class=\"nav\" cellspacing=\"0\" cellpadding=\"0\"><tr><td>
 <a class=\"nav\" id=\"nb_men\" href=\"./inizio.php?$sessione_anno_var\">&nbsp;<b>".mex("MENU","head.php")."</b>&nbsp;</a></td><td>";
 if ($priv_ins_nuove_prenota == "s" or $priv_ins_spese == "s" or $priv_ins_entrate == "s" or $inserimento_nuovi_clienti != "NO" or ($modifica_clienti != "NO" and $vedi_clienti != "NO")) {
 echo "|</td><td><div class=\"drop nb_ins\"><ul>
-<li><a class=\"nonav\" id=\"nb_ins\" href=\"#\">&nbsp;<b>".mex("INSERIRE","head.php").":</b>&nbsp;</a>";
+<li><a class=\"nonav\" id=\"nb_ins\"$selfref>&nbsp;<b>".mex("INSERIRE","head.php").":</b>&nbsp;</a>";
 if ($priv_ins_spese == "s" or $priv_ins_entrate == "s" or $priv_mod_tariffe != "n" or $priv_ins_costi_agg != "n" or ($id_utente == 1 and $installazione_subordinata != "SI") or ($priv_mod_prenotazioni != "n" and $priv_mod_costi_agg == "s") or $inserimento_nuovi_clienti != "NO" or ($modifica_clienti != "NO" and $vedi_clienti != "NO") or ($mobile_device and $priv_ins_nuove_prenota == "s")) {
 echo "<ul>";
 if ($mobile_device and $priv_ins_nuove_prenota == "s") echo "<li><a id=\"nb_ires\" href=\"./prenota.php?$sessione_anno_var\">&nbsp;<b>".mex("PRENOTAZIONE","head.php")."</b>&nbsp;</a></li>";
@@ -263,7 +265,7 @@ $lt = "<b style=\"color: red; text-decoration: none;\">&lt;</b>";
 } # fine if (numlin_query($messaggi) > 0)
 } # fine if ($priv_vedi_messaggi == "s" and $numconnessione)
 echo "|</td><td><div class=\"drop nb_tab\"><ul>
-<li><a class=\"nonav\" id=\"nb_tab\" href=\"#\">&nbsp;<b>".mex("TABELLE","head.php")."$star:</b>&nbsp;</a>";
+<li><a class=\"nonav\" id=\"nb_tab\"$selfref>&nbsp;<b>".mex("TABELLE","head.php")."$star:</b>&nbsp;</a>";
 if ($priv_vedi_beni_inv == "n" and $priv_vedi_inv_mag == "n" and $priv_vedi_inv_app == "n") $priv_vedi_tab_inventario = "n";
 if ($priv_vedi_tab_costi != "n" or $priv_vedi_tab_regole != "n" or $priv_vedi_tab_doc != "n" or $priv_vedi_tab_stat != "n" or $priv_vedi_tab_inventario != "n" or $priv_vedi_messaggi == "s" or $priv_vedi_tab_appartamenti != "n" or ($mobile_device and ($priv_vedi_tab_mesi != "n" or $vedi_clienti != "NO"))) {
 echo "<ul>";
@@ -295,7 +297,7 @@ echo "</ul></li></ul></div></td><td>";
 } # fine if ($priv_vedi_tab_mesi != "n" and !$mobile_device)
 if ($priv_vedi_tab_prenotazioni != "n") {
 echo "</td><td><div class=\"drop nb_res\"><ul onmouseover=\"focus_elem('ressearch')\" onmouseout=\"blur_elem('ressearch')\"><li>";
-if ($mobile_device) echo "<a class=\"nonav\" id=\"nb_res\" href=\"#\">";
+if ($mobile_device) echo "<a class=\"nonav\" id=\"nb_res\"$selfref>";
 else echo "<a class=\"nav\" id=\"nb_res\" href=\"./visualizza_tabelle.php?$sessione_anno_var&amp;tipo_tabella=prenotazioni\">";
 echo "&nbsp;<b>".mex("PRENOTAZIONI","head.php")."</b>&nbsp;</a><ul>
 <li><a id=\"nb_rall\" href=\"./visualizza_tabelle.php?$sessione_anno_var&amp;tipo_tabella=prenotazioni&amp;sel_tab_prenota=tutte\">&nbsp;<b>".mex("TUTTE","head.php")."</b>&nbsp;</a></li>
