@@ -133,7 +133,7 @@ function crea_cal_mese (ncal,mese,anno) {
 var n_giorni_l = 0;
 var giorni_l = new Array();
 var n1 = 0;
-d = new Date(anno,mese,1);
+d = new Date(anno,mese,1,2);
 anno = d.getFullYear();
 mese = d.getMonth();
 giorno = d.getDay() * -1;
@@ -150,7 +150,7 @@ var testo_cal = ' '+mesi[mese]+'&nbsp;'+anno+'<br>\
 <td><button type="button" class= "calbutton" onclick="crea_cal_mese(\''+ncal+'\',\''+mese+'\',\''+(anno + 1)+'\')">&gt;&gt;</button></td>\
 </tr></table><table>\
 <tr><td>'+giorni['1']+'</td><td>'+giorni['2']+'</td><td>'+giorni['3']+'</td><td>'+giorni['4']+'</td><td>'+giorni['5']+'</td><td>'+giorni['6']+'</td><td>'+giorni['0']+'</td></tr>';
-d = new Date(anno,mese,giorno);
+d = new Date(anno,mese,giorno,2);
 mese = d.getMonth();
 anno = d.getFullYear();
 giorno = d.getDate();
@@ -163,7 +163,7 @@ n_giorni_l = n_giorni_l + 1;
 }
 else testo_cal += '<td></td>';
 giorno = giorno + 1;
-d = new Date(anno,mese,giorno);
+d = new Date(anno,mese,giorno,2);
 mese = d.getMonth();
 anno = d.getFullYear();
 giorno = d.getDate();
